# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/protobuf/unittest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import unittest_import_pb2 as google_dot_protobuf_dot_unittest__import__pb2
try:
  google_dot_protobuf_dot_unittest__import__public__pb2 = google_dot_protobuf_dot_unittest__import__pb2.google_dot_protobuf_dot_unittest__import__public__pb2
except AttributeError:
  google_dot_protobuf_dot_unittest__import__public__pb2 = google_dot_protobuf_dot_unittest__import__pb2.google.protobuf.unittest_import_public_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/protobuf/unittest.proto',
  package='protobuf_unittest',
  syntax='proto2',
  serialized_options=b'B\rUnittestProtoH\001\200\001\001\210\001\001\220\001\001\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1egoogle/protobuf/unittest.proto\x12\x11protobuf_unittest\x1a%google/protobuf/unittest_import.proto\"\xed\x18\n\x0cTestAllTypes\x12\x16\n\x0eoptional_int32\x18\x01 \x01(\x05\x12\x16\n\x0eoptional_int64\x18\x02 \x01(\x03\x12\x17\n\x0foptional_uint32\x18\x03 \x01(\r\x12\x17\n\x0foptional_uint64\x18\x04 \x01(\x04\x12\x17\n\x0foptional_sint32\x18\x05 \x01(\x11\x12\x17\n\x0foptional_sint64\x18\x06 \x01(\x12\x12\x18\n\x10optional_fixed32\x18\x07 \x01(\x07\x12\x18\n\x10optional_fixed64\x18\x08 \x01(\x06\x12\x19\n\x11optional_sfixed32\x18\t \x01(\x0f\x12\x19\n\x11optional_sfixed64\x18\n \x01(\x10\x12\x16\n\x0eoptional_float\x18\x0b \x01(\x02\x12\x17\n\x0foptional_double\x18\x0c \x01(\x01\x12\x15\n\roptional_bool\x18\r \x01(\x08\x12\x17\n\x0foptional_string\x18\x0e \x01(\t\x12\x16\n\x0eoptional_bytes\x18\x0f \x01(\x0c\x12\x44\n\roptionalgroup\x18\x10 \x01(\n2-.protobuf_unittest.TestAllTypes.OptionalGroup\x12N\n\x17optional_nested_message\x18\x12 \x01(\x0b\x32-.protobuf_unittest.TestAllTypes.NestedMessage\x12\x43\n\x18optional_foreign_message\x18\x13 \x01(\x0b\x32!.protobuf_unittest.ForeignMessage\x12H\n\x17optional_import_message\x18\x14 \x01(\x0b\x32\'.protobuf_unittest_import.ImportMessage\x12H\n\x14optional_nested_enum\x18\x15 \x01(\x0e\x32*.protobuf_unittest.TestAllTypes.NestedEnum\x12=\n\x15optional_foreign_enum\x18\x16 \x01(\x0e\x32\x1e.protobuf_unittest.ForeignEnum\x12\x42\n\x14optional_import_enum\x18\x17 \x01(\x0e\x32$.protobuf_unittest_import.ImportEnum\x12!\n\x15optional_string_piece\x18\x18 \x01(\tB\x02\x08\x02\x12\x19\n\roptional_cord\x18\x19 \x01(\tB\x02\x08\x01\x12U\n\x1eoptional_public_import_message\x18\x1a \x01(\x0b\x32-.protobuf_unittest_import.PublicImportMessage\x12P\n\x15optional_lazy_message\x18\x1b \x01(\x0b\x32-.protobuf_unittest.TestAllTypes.NestedMessageB\x02(\x01\x12\x16\n\x0erepeated_int32\x18\x1f \x03(\x05\x12\x16\n\x0erepeated_int64\x18  \x03(\x03\x12\x17\n\x0frepeated_uint32\x18! \x03(\r\x12\x17\n\x0frepeated_uint64\x18\" \x03(\x04\x12\x17\n\x0frepeated_sint32\x18# \x03(\x11\x12\x17\n\x0frepeated_sint64\x18$ \x03(\x12\x12\x18\n\x10repeated_fixed32\x18% \x03(\x07\x12\x18\n\x10repeated_fixed64\x18& \x03(\x06\x12\x19\n\x11repeated_sfixed32\x18\' \x03(\x0f\x12\x19\n\x11repeated_sfixed64\x18( \x03(\x10\x12\x16\n\x0erepeated_float\x18) \x03(\x02\x12\x17\n\x0frepeated_double\x18* \x03(\x01\x12\x15\n\rrepeated_bool\x18+ \x03(\x08\x12\x17\n\x0frepeated_string\x18, \x03(\t\x12\x16\n\x0erepeated_bytes\x18- \x03(\x0c\x12\x44\n\rrepeatedgroup\x18. \x03(\n2-.protobuf_unittest.TestAllTypes.RepeatedGroup\x12N\n\x17repeated_nested_message\x18\x30 \x03(\x0b\x32-.protobuf_unittest.TestAllTypes.NestedMessage\x12\x43\n\x18repeated_foreign_message\x18\x31 \x03(\x0b\x32!.protobuf_unittest.ForeignMessage\x12H\n\x17repeated_import_message\x18\x32 \x03(\x0b\x32\'.protobuf_unittest_import.ImportMessage\x12H\n\x14repeated_nested_enum\x18\x33 \x03(\x0e\x32*.protobuf_unittest.TestAllTypes.NestedEnum\x12=\n\x15repeated_foreign_enum\x18\x34 \x03(\x0e\x32\x1e.protobuf_unittest.ForeignEnum\x12\x42\n\x14repeated_import_enum\x18\x35 \x03(\x0e\x32$.protobuf_unittest_import.ImportEnum\x12!\n\x15repeated_string_piece\x18\x36 \x03(\tB\x02\x08\x02\x12\x19\n\rrepeated_cord\x18\x37 \x03(\tB\x02\x08\x01\x12P\n\x15repeated_lazy_message\x18\x39 \x03(\x0b\x32-.protobuf_unittest.TestAllTypes.NestedMessageB\x02(\x01\x12\x19\n\rdefault_int32\x18= \x01(\x05:\x02\x34\x31\x12\x19\n\rdefault_int64\x18> \x01(\x03:\x02\x34\x32\x12\x1a\n\x0e\x64\x65\x66\x61ult_uint32\x18? \x01(\r:\x02\x34\x33\x12\x1a\n\x0e\x64\x65\x66\x61ult_uint64\x18@ \x01(\x04:\x02\x34\x34\x12\x1b\n\x0e\x64\x65\x66\x61ult_sint32\x18\x41 \x01(\x11:\x03-45\x12\x1a\n\x0e\x64\x65\x66\x61ult_sint64\x18\x42 \x01(\x12:\x02\x34\x36\x12\x1b\n\x0f\x64\x65\x66\x61ult_fixed32\x18\x43 \x01(\x07:\x02\x34\x37\x12\x1b\n\x0f\x64\x65\x66\x61ult_fixed64\x18\x44 \x01(\x06:\x02\x34\x38\x12\x1c\n\x10\x64\x65\x66\x61ult_sfixed32\x18\x45 \x01(\x0f:\x02\x34\x39\x12\x1d\n\x10\x64\x65\x66\x61ult_sfixed64\x18\x46 \x01(\x10:\x03-50\x12\x1b\n\rdefault_float\x18G \x01(\x02:\x04\x35\x31.5\x12\x1d\n\x0e\x64\x65\x66\x61ult_double\x18H \x01(\x01:\x05\x35\x32\x30\x30\x30\x12\x1a\n\x0c\x64\x65\x66\x61ult_bool\x18I \x01(\x08:\x04true\x12\x1d\n\x0e\x64\x65\x66\x61ult_string\x18J \x01(\t:\x05hello\x12\x1c\n\rdefault_bytes\x18K \x01(\x0c:\x05world\x12L\n\x13\x64\x65\x66\x61ult_nested_enum\x18Q \x01(\x0e\x32*.protobuf_unittest.TestAllTypes.NestedEnum:\x03\x42\x41R\x12I\n\x14\x64\x65\x66\x61ult_foreign_enum\x18R \x01(\x0e\x32\x1e.protobuf_unittest.ForeignEnum:\x0b\x46OREIGN_BAR\x12M\n\x13\x64\x65\x66\x61ult_import_enum\x18S \x01(\x0e\x32$.protobuf_unittest_import.ImportEnum:\nIMPORT_BAR\x12%\n\x14\x64\x65\x66\x61ult_string_piece\x18T \x01(\t:\x03\x61\x62\x63\x42\x02\x08\x02\x12\x1d\n\x0c\x64\x65\x66\x61ult_cord\x18U \x01(\t:\x03\x31\x32\x33\x42\x02\x08\x01\x12\x16\n\x0coneof_uint32\x18o \x01(\rH\x00\x12M\n\x14oneof_nested_message\x18p \x01(\x0b\x32-.protobuf_unittest.TestAllTypes.NestedMessageH\x00\x12\x16\n\x0coneof_string\x18q \x01(\tH\x00\x12\x15\n\x0boneof_bytes\x18r \x01(\x0cH\x00\x1a\x1b\n\rNestedMessage\x12\n\n\x02\x62\x62\x18\x01 \x01(\x05\x1a\x1a\n\rOptionalGroup\x12\t\n\x01\x61\x18\x11 \x01(\x05\x1a\x1a\n\rRepeatedGroup\x12\t\n\x01\x61\x18/ \x01(\x05\"9\n\nNestedEnum\x12\x07\n\x03\x46OO\x10\x01\x12\x07\n\x03\x42\x41R\x10\x02\x12\x07\n\x03\x42\x41Z\x10\x03\x12\x10\n\x03NEG\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x42\r\n\x0boneof_field\"\xbb\x01\n\x12NestedTestAllTypes\x12\x34\n\x05\x63hild\x18\x01 \x01(\x0b\x32%.protobuf_unittest.NestedTestAllTypes\x12\x30\n\x07payload\x18\x02 \x01(\x0b\x32\x1f.protobuf_unittest.TestAllTypes\x12=\n\x0erepeated_child\x18\x03 \x03(\x0b\x32%.protobuf_unittest.NestedTestAllTypes\"m\n\x14TestDeprecatedFields\x12\x1c\n\x10\x64\x65precated_int32\x18\x01 \x01(\x05\x42\x02\x18\x01\x12\'\n\x19\x64\x65precated_int32_in_oneof\x18\x02 \x01(\x05\x42\x02\x18\x01H\x00\x42\x0e\n\x0coneof_fields\"\x1b\n\x15TestDeprecatedMessage:\x02\x18\x01\"&\n\x0e\x46oreignMessage\x12\t\n\x01\x63\x18\x01 \x01(\x05\x12\t\n\x01\x64\x18\x02 \x01(\x05\"0\n\x12TestReservedFieldsJ\x04\x08\x02\x10\x03J\x04\x08\x0f\x10\x10J\x04\x08\t\x10\x0cR\x03\x62\x61rR\x03\x62\x61z\"\x1d\n\x11TestAllExtensions*\x08\x08\x01\x10\x80\x80\x80\x80\x02\"$\n\x17OptionalGroup_extension\x12\t\n\x01\x61\x18\x11 \x01(\x05\"$\n\x17RepeatedGroup_extension\x12\t\n\x01\x61\x18/ \x01(\x05\"\xa9\x01\n\tTestGroup\x12\x41\n\roptionalgroup\x18\x10 \x01(\n2*.protobuf_unittest.TestGroup.OptionalGroup\x12=\n\x15optional_foreign_enum\x18\x16 \x01(\x0e\x32\x1e.protobuf_unittest.ForeignEnum\x1a\x1a\n\rOptionalGroup\x12\t\n\x01\x61\x18\x11 \x01(\x05\"\x1e\n\x12TestGroupExtension*\x08\x08\x01\x10\x80\x80\x80\x80\x02\"\xb7\x03\n\x13TestNestedExtension\x1a$\n\x17OptionalGroup_extension\x12\t\n\x01\x61\x18\x11 \x01(\x05\x32\x39\n\x04test\x12$.protobuf_unittest.TestAllExtensions\x18\xea\x07 \x01(\t:\x04test2F\n\x17nested_string_extension\x12$.protobuf_unittest.TestAllExtensions\x18\xeb\x07 \x01(\t2\x86\x01\n\x17optionalgroup_extension\x12%.protobuf_unittest.TestGroupExtension\x18\x10 \x01(\n2>.protobuf_unittest.TestNestedExtension.OptionalGroup_extension2n\n\x1foptional_foreign_enum_extension\x12%.protobuf_unittest.TestGroupExtension\x18\x16 \x01(\x0e\x32\x1e.protobuf_unittest.ForeignEnum\"\xd5\x05\n\x0cTestRequired\x12\t\n\x01\x61\x18\x01 \x02(\x05\x12\x0e\n\x06\x64ummy2\x18\x02 \x01(\x05\x12\t\n\x01\x62\x18\x03 \x02(\x05\x12\x0e\n\x06\x64ummy4\x18\x04 \x01(\x05\x12\x0e\n\x06\x64ummy5\x18\x05 \x01(\x05\x12\x0e\n\x06\x64ummy6\x18\x06 \x01(\x05\x12\x0e\n\x06\x64ummy7\x18\x07 \x01(\x05\x12\x0e\n\x06\x64ummy8\x18\x08 \x01(\x05\x12\x0e\n\x06\x64ummy9\x18\t \x01(\x05\x12\x0f\n\x07\x64ummy10\x18\n \x01(\x05\x12\x0f\n\x07\x64ummy11\x18\x0b \x01(\x05\x12\x0f\n\x07\x64ummy12\x18\x0c \x01(\x05\x12\x0f\n\x07\x64ummy13\x18\r \x01(\x05\x12\x0f\n\x07\x64ummy14\x18\x0e \x01(\x05\x12\x0f\n\x07\x64ummy15\x18\x0f \x01(\x05\x12\x0f\n\x07\x64ummy16\x18\x10 \x01(\x05\x12\x0f\n\x07\x64ummy17\x18\x11 \x01(\x05\x12\x0f\n\x07\x64ummy18\x18\x12 \x01(\x05\x12\x0f\n\x07\x64ummy19\x18\x13 \x01(\x05\x12\x0f\n\x07\x64ummy20\x18\x14 \x01(\x05\x12\x0f\n\x07\x64ummy21\x18\x15 \x01(\x05\x12\x0f\n\x07\x64ummy22\x18\x16 \x01(\x05\x12\x0f\n\x07\x64ummy23\x18\x17 \x01(\x05\x12\x0f\n\x07\x64ummy24\x18\x18 \x01(\x05\x12\x0f\n\x07\x64ummy25\x18\x19 \x01(\x05\x12\x0f\n\x07\x64ummy26\x18\x1a \x01(\x05\x12\x0f\n\x07\x64ummy27\x18\x1b \x01(\x05\x12\x0f\n\x07\x64ummy28\x18\x1c \x01(\x05\x12\x0f\n\x07\x64ummy29\x18\x1d \x01(\x05\x12\x0f\n\x07\x64ummy30\x18\x1e \x01(\x05\x12\x0f\n\x07\x64ummy31\x18\x1f \x01(\x05\x12\x0f\n\x07\x64ummy32\x18  \x01(\x05\x12\t\n\x01\x63\x18! \x02(\x05\x32V\n\x06single\x12$.protobuf_unittest.TestAllExtensions\x18\xe8\x07 \x01(\x0b\x32\x1f.protobuf_unittest.TestRequired2U\n\x05multi\x12$.protobuf_unittest.TestAllExtensions\x18\xe9\x07 \x03(\x0b\x32\x1f.protobuf_unittest.TestRequired\"\x9a\x01\n\x13TestRequiredForeign\x12\x39\n\x10optional_message\x18\x01 \x01(\x0b\x32\x1f.protobuf_unittest.TestRequired\x12\x39\n\x10repeated_message\x18\x02 \x03(\x0b\x32\x1f.protobuf_unittest.TestRequired\x12\r\n\x05\x64ummy\x18\x03 \x01(\x05\"\xc6\x01\n\x13TestRequiredMessage\x12\x39\n\x10optional_message\x18\x01 \x01(\x0b\x32\x1f.protobuf_unittest.TestRequired\x12\x39\n\x10repeated_message\x18\x02 \x03(\x0b\x32\x1f.protobuf_unittest.TestRequired\x12\x39\n\x10required_message\x18\x03 \x02(\x0b\x32\x1f.protobuf_unittest.TestRequired\"Z\n\x11TestForeignNested\x12\x45\n\x0e\x66oreign_nested\x18\x01 \x01(\x0b\x32-.protobuf_unittest.TestAllTypes.NestedMessage\"\x12\n\x10TestEmptyMessage\"*\n\x1eTestEmptyMessageWithExtensions*\x08\x08\x01\x10\x80\x80\x80\x80\x02\"Y\n\x17TestPickleNestedMessage\x1a>\n\rNestedMessage\x12\n\n\x02\x62\x62\x18\x01 \x01(\x05\x1a!\n\x13NestedNestedMessage\x12\n\n\x02\x63\x63\x18\x01 \x01(\x05\"7\n\x1bTestMultipleExtensionRanges*\x04\x08*\x10+*\x06\x08\xaf \x10\x94!*\n\x08\x80\x80\x04\x10\x80\x80\x80\x80\x02\"4\n\x18TestReallyLargeTagNumber\x12\t\n\x01\x61\x18\x01 \x01(\x05\x12\r\n\x02\x62\x62\x18\xff\xff\xff\x7f \x01(\x05\"U\n\x14TestRecursiveMessage\x12\x32\n\x01\x61\x18\x01 \x01(\x0b\x32\'.protobuf_unittest.TestRecursiveMessage\x12\t\n\x01i\x18\x02 \x01(\x05\"\xe1\x02\n\x14TestMutualRecursionA\x12\x33\n\x02\x62\x62\x18\x01 \x01(\x0b\x32\'.protobuf_unittest.TestMutualRecursionB\x12\x42\n\x08subgroup\x18\x02 \x01(\n20.protobuf_unittest.TestMutualRecursionA.SubGroup\x1a@\n\nSubMessage\x12\x32\n\x01\x62\x18\x01 \x01(\x0b\x32\'.protobuf_unittest.TestMutualRecursionB\x1a\x8d\x01\n\x08SubGroup\x12G\n\x0bsub_message\x18\x03 \x01(\x0b\x32\x32.protobuf_unittest.TestMutualRecursionA.SubMessage\x12\x38\n\x0fnot_in_this_scc\x18\x04 \x01(\x0b\x32\x1f.protobuf_unittest.TestAllTypes\"b\n\x14TestMutualRecursionB\x12\x32\n\x01\x61\x18\x01 \x01(\x0b\x32\'.protobuf_unittest.TestMutualRecursionA\x12\x16\n\x0eoptional_int32\x18\x02 \x01(\x05\"\xca\x01\n\x11TestIsInitialized\x12\x44\n\x0bsub_message\x18\x01 \x01(\x0b\x32/.protobuf_unittest.TestIsInitialized.SubMessage\x1ao\n\nSubMessage\x12J\n\x08subgroup\x18\x01 \x01(\n28.protobuf_unittest.TestIsInitialized.SubMessage.SubGroup\x1a\x15\n\x08SubGroup\x12\t\n\x01i\x18\x02 \x02(\x05\"\xb3\x01\n\x12TestDupFieldNumber\x12\t\n\x01\x61\x18\x01 \x01(\x05\x12\x36\n\x03\x66oo\x18\x02 \x01(\n2).protobuf_unittest.TestDupFieldNumber.Foo\x12\x36\n\x03\x62\x61r\x18\x03 \x01(\n2).protobuf_unittest.TestDupFieldNumber.Bar\x1a\x10\n\x03\x46oo\x12\t\n\x01\x61\x18\x01 \x01(\x05\x1a\x10\n\x03\x42\x61r\x12\t\n\x01\x61\x18\x01 \x01(\x05\"L\n\x10TestEagerMessage\x12\x38\n\x0bsub_message\x18\x01 \x01(\x0b\x32\x1f.protobuf_unittest.TestAllTypesB\x02(\x00\"K\n\x0fTestLazyMessage\x12\x38\n\x0bsub_message\x18\x01 \x01(\x0b\x32\x1f.protobuf_unittest.TestAllTypesB\x02(\x01\"\x80\x02\n\x18TestNestedMessageHasBits\x12Z\n\x17optional_nested_message\x18\x01 \x01(\x0b\x32\x39.protobuf_unittest.TestNestedMessageHasBits.NestedMessage\x1a\x87\x01\n\rNestedMessage\x12$\n\x1cnestedmessage_repeated_int32\x18\x01 \x03(\x05\x12P\n%nestedmessage_repeated_foreignmessage\x18\x02 \x03(\x0b\x32!.protobuf_unittest.ForeignMessage\"\xe5\x03\n\x17TestCamelCaseFieldNames\x12\x16\n\x0ePrimitiveField\x18\x01 \x01(\x05\x12\x13\n\x0bStringField\x18\x02 \x01(\t\x12\x31\n\tEnumField\x18\x03 \x01(\x0e\x32\x1e.protobuf_unittest.ForeignEnum\x12\x37\n\x0cMessageField\x18\x04 \x01(\x0b\x32!.protobuf_unittest.ForeignMessage\x12\x1c\n\x10StringPieceField\x18\x05 \x01(\tB\x02\x08\x02\x12\x15\n\tCordField\x18\x06 \x01(\tB\x02\x08\x01\x12\x1e\n\x16RepeatedPrimitiveField\x18\x07 \x03(\x05\x12\x1b\n\x13RepeatedStringField\x18\x08 \x03(\t\x12\x39\n\x11RepeatedEnumField\x18\t \x03(\x0e\x32\x1e.protobuf_unittest.ForeignEnum\x12?\n\x14RepeatedMessageField\x18\n \x03(\x0b\x32!.protobuf_unittest.ForeignMessage\x12$\n\x18RepeatedStringPieceField\x18\x0b \x03(\tB\x02\x08\x02\x12\x1d\n\x11RepeatedCordField\x18\x0c \x03(\tB\x02\x08\x01\"\xd5\x01\n\x12TestFieldOrderings\x12\x11\n\tmy_string\x18\x0b \x01(\t\x12\x0e\n\x06my_int\x18\x01 \x01(\x03\x12\x10\n\x08my_float\x18\x65 \x01(\x02\x12U\n\x17optional_nested_message\x18\xc8\x01 \x01(\x0b\x32\x33.protobuf_unittest.TestFieldOrderings.NestedMessage\x1a\'\n\rNestedMessage\x12\n\n\x02oo\x18\x02 \x01(\x03\x12\n\n\x02\x62\x62\x18\x01 \x01(\x05*\x04\x08\x02\x10\x0b*\x04\x08\x0c\x10\x65\"\x9c\x01\n\x17TestExtensionOrderings1\x12\x11\n\tmy_string\x18\x01 \x01(\t2n\n\x13test_ext_orderings1\x12%.protobuf_unittest.TestFieldOrderings\x18\r \x01(\x0b\x32*.protobuf_unittest.TestExtensionOrderings1\"\xd4\x02\n\x17TestExtensionOrderings2\x12\x11\n\tmy_string\x18\x01 \x01(\t\x1a\xb5\x01\n\x17TestExtensionOrderings3\x12\x11\n\tmy_string\x18\x01 \x01(\t2\x86\x01\n\x13test_ext_orderings3\x12%.protobuf_unittest.TestFieldOrderings\x18\x0e \x01(\x0b\x32\x42.protobuf_unittest.TestExtensionOrderings2.TestExtensionOrderings32n\n\x13test_ext_orderings2\x12%.protobuf_unittest.TestFieldOrderings\x18\x0c \x01(\x0b\x32*.protobuf_unittest.TestExtensionOrderings2\"\xb6\x07\n\x18TestExtremeDefaultValues\x12?\n\rescaped_bytes\x18\x01 \x01(\x0c:(\\000\\001\\007\\010\\014\\n\\r\\t\\013\\\\\\\'\\\"\\376\x12 \n\x0clarge_uint32\x18\x02 \x01(\r:\n4294967295\x12*\n\x0clarge_uint64\x18\x03 \x01(\x04:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\x12 \n\x0bsmall_int32\x18\x04 \x01(\x05:\x0b-2147483647\x12)\n\x0bsmall_int64\x18\x05 \x01(\x03:\x14-9223372036854775807\x12\'\n\x12really_small_int32\x18\x15 \x01(\x05:\x0b-2147483648\x12\x30\n\x12really_small_int64\x18\x16 \x01(\x03:\x14-9223372036854775808\x12\x18\n\x0butf8_string\x18\x06 \x01(\t:\x03\xe1\x88\xb4\x12\x15\n\nzero_float\x18\x07 \x01(\x02:\x01\x30\x12\x14\n\tone_float\x18\x08 \x01(\x02:\x01\x31\x12\x18\n\x0bsmall_float\x18\t \x01(\x02:\x03\x31.5\x12\x1e\n\x12negative_one_float\x18\n \x01(\x02:\x02-1\x12\x1c\n\x0enegative_float\x18\x0b \x01(\x02:\x04-1.5\x12\x1a\n\x0blarge_float\x18\x0c \x01(\x02:\x05\x32\x65+08\x12$\n\x14small_negative_float\x18\r \x01(\x02:\x06-8e-28\x12\x17\n\ninf_double\x18\x0e \x01(\x01:\x03inf\x12\x1c\n\x0eneg_inf_double\x18\x0f \x01(\x01:\x04-inf\x12\x17\n\nnan_double\x18\x10 \x01(\x01:\x03nan\x12\x16\n\tinf_float\x18\x11 \x01(\x02:\x03inf\x12\x1b\n\rneg_inf_float\x18\x12 \x01(\x02:\x04-inf\x12\x16\n\tnan_float\x18\x13 \x01(\x02:\x03nan\x12+\n\x0c\x63pp_trigraph\x18\x14 \x01(\t:\x15? ? ?? ?? ??? ??/ ??-\x12 \n\x10string_with_zero\x18\x17 \x01(\t:\x06hel\x00lo\x12\"\n\x0f\x62ytes_with_zero\x18\x18 \x01(\x0c:\twor\\000ld\x12(\n\x16string_piece_with_zero\x18\x19 \x01(\t:\x04\x61\x62\x00\x63\x42\x02\x08\x02\x12 \n\x0e\x63ord_with_zero\x18\x1a \x01(\t:\x04\x31\x32\x00\x33\x42\x02\x08\x01\x12&\n\x12replacement_string\x18\x1b \x01(\t:\n${unknown}\"K\n\x11SparseEnumMessage\x12\x36\n\x0bsparse_enum\x18\x01 \x01(\x0e\x32!.protobuf_unittest.TestSparseEnum\"\x19\n\tOneString\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"\x1a\n\nMoreString\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\t\"\x18\n\x08OneBytes\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x19\n\tMoreBytes\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x0c\"\x1c\n\x0cInt32Message\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x05\"\x1d\n\rUint32Message\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\r\"\x1c\n\x0cInt64Message\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x03\"\x1d\n\rUint64Message\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x04\"\x1b\n\x0b\x42oolMessage\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x08\"\xd0\x01\n\tTestOneof\x12\x11\n\x07\x66oo_int\x18\x01 \x01(\x05H\x00\x12\x14\n\nfoo_string\x18\x02 \x01(\tH\x00\x12\x36\n\x0b\x66oo_message\x18\x03 \x01(\x0b\x32\x1f.protobuf_unittest.TestAllTypesH\x00\x12\x39\n\x08\x66oogroup\x18\x04 \x01(\n2%.protobuf_unittest.TestOneof.FooGroupH\x00\x1a \n\x08\x46ooGroup\x12\t\n\x01\x61\x18\x05 \x01(\x05\x12\t\n\x01\x62\x18\x06 \x01(\tB\x05\n\x03\x66oo\"\xe7\x01\n\x1cTestOneofBackwardsCompatible\x12\x0f\n\x07\x66oo_int\x18\x01 \x01(\x05\x12\x12\n\nfoo_string\x18\x02 \x01(\t\x12\x34\n\x0b\x66oo_message\x18\x03 \x01(\x0b\x32\x1f.protobuf_unittest.TestAllTypes\x12J\n\x08\x66oogroup\x18\x04 \x01(\n28.protobuf_unittest.TestOneofBackwardsCompatible.FooGroup\x1a \n\x08\x46ooGroup\x12\t\n\x01\x61\x18\x05 \x01(\x05\x12\t\n\x01\x62\x18\x06 \x01(\t\"\x9e\x06\n\nTestOneof2\x12\x11\n\x07\x66oo_int\x18\x01 \x01(\x05H\x00\x12\x14\n\nfoo_string\x18\x02 \x01(\tH\x00\x12\x16\n\x08\x66oo_cord\x18\x03 \x01(\tB\x02\x08\x01H\x00\x12\x1e\n\x10\x66oo_string_piece\x18\x04 \x01(\tB\x02\x08\x02H\x00\x12\x13\n\tfoo_bytes\x18\x05 \x01(\x0cH\x00\x12<\n\x08\x66oo_enum\x18\x06 \x01(\x0e\x32(.protobuf_unittest.TestOneof2.NestedEnumH\x00\x12\x42\n\x0b\x66oo_message\x18\x07 \x01(\x0b\x32+.protobuf_unittest.TestOneof2.NestedMessageH\x00\x12:\n\x08\x66oogroup\x18\x08 \x01(\n2&.protobuf_unittest.TestOneof2.FooGroupH\x00\x12K\n\x10\x66oo_lazy_message\x18\x0b \x01(\x0b\x32+.protobuf_unittest.TestOneof2.NestedMessageB\x02(\x01H\x00\x12\x14\n\x07\x62\x61r_int\x18\x0c \x01(\x05:\x01\x35H\x01\x12\x1c\n\nbar_string\x18\r \x01(\t:\x06STRINGH\x01\x12\x1c\n\x08\x62\x61r_cord\x18\x0e \x01(\t:\x04\x43ORDB\x02\x08\x01H\x01\x12&\n\x10\x62\x61r_string_piece\x18\x0f \x01(\t:\x06SPIECEB\x02\x08\x02H\x01\x12\x1a\n\tbar_bytes\x18\x10 \x01(\x0c:\x05\x42YTESH\x01\x12\x41\n\x08\x62\x61r_enum\x18\x11 \x01(\x0e\x32(.protobuf_unittest.TestOneof2.NestedEnum:\x03\x42\x41RH\x01\x12\x0f\n\x07\x62\x61z_int\x18\x12 \x01(\x05\x12\x17\n\nbaz_string\x18\x13 \x01(\t:\x03\x42\x41Z\x1a \n\x08\x46ooGroup\x12\t\n\x01\x61\x18\t \x01(\x05\x12\t\n\x01\x62\x18\n \x01(\t\x1a\x33\n\rNestedMessage\x12\x0f\n\x07qux_int\x18\x01 \x01(\x03\x12\x11\n\tcorge_int\x18\x02 \x03(\x05\"\'\n\nNestedEnum\x12\x07\n\x03\x46OO\x10\x01\x12\x07\n\x03\x42\x41R\x10\x02\x12\x07\n\x03\x42\x41Z\x10\x03\x42\x05\n\x03\x66ooB\x05\n\x03\x62\x61r\"\xb8\x01\n\x11TestRequiredOneof\x12\x11\n\x07\x66oo_int\x18\x01 \x01(\x05H\x00\x12\x14\n\nfoo_string\x18\x02 \x01(\tH\x00\x12I\n\x0b\x66oo_message\x18\x03 \x01(\x0b\x32\x32.protobuf_unittest.TestRequiredOneof.NestedMessageH\x00\x1a(\n\rNestedMessage\x12\x17\n\x0frequired_double\x18\x01 \x02(\x01\x42\x05\n\x03\x66oo\"\xaa\x03\n\x0fTestPackedTypes\x12\x18\n\x0cpacked_int32\x18Z \x03(\x05\x42\x02\x10\x01\x12\x18\n\x0cpacked_int64\x18[ \x03(\x03\x42\x02\x10\x01\x12\x19\n\rpacked_uint32\x18\\ \x03(\rB\x02\x10\x01\x12\x19\n\rpacked_uint64\x18] \x03(\x04\x42\x02\x10\x01\x12\x19\n\rpacked_sint32\x18^ \x03(\x11\x42\x02\x10\x01\x12\x19\n\rpacked_sint64\x18_ \x03(\x12\x42\x02\x10\x01\x12\x1a\n\x0epacked_fixed32\x18` \x03(\x07\x42\x02\x10\x01\x12\x1a\n\x0epacked_fixed64\x18\x61 \x03(\x06\x42\x02\x10\x01\x12\x1b\n\x0fpacked_sfixed32\x18\x62 \x03(\x0f\x42\x02\x10\x01\x12\x1b\n\x0fpacked_sfixed64\x18\x63 \x03(\x10\x42\x02\x10\x01\x12\x18\n\x0cpacked_float\x18\x64 \x03(\x02\x42\x02\x10\x01\x12\x19\n\rpacked_double\x18\x65 \x03(\x01\x42\x02\x10\x01\x12\x17\n\x0bpacked_bool\x18\x66 \x03(\x08\x42\x02\x10\x01\x12\x37\n\x0bpacked_enum\x18g \x03(\x0e\x32\x1e.protobuf_unittest.ForeignEnumB\x02\x10\x01\"\xc8\x03\n\x11TestUnpackedTypes\x12\x1a\n\x0eunpacked_int32\x18Z \x03(\x05\x42\x02\x10\x00\x12\x1a\n\x0eunpacked_int64\x18[ \x03(\x03\x42\x02\x10\x00\x12\x1b\n\x0funpacked_uint32\x18\\ \x03(\rB\x02\x10\x00\x12\x1b\n\x0funpacked_uint64\x18] \x03(\x04\x42\x02\x10\x00\x12\x1b\n\x0funpacked_sint32\x18^ \x03(\x11\x42\x02\x10\x00\x12\x1b\n\x0funpacked_sint64\x18_ \x03(\x12\x42\x02\x10\x00\x12\x1c\n\x10unpacked_fixed32\x18` \x03(\x07\x42\x02\x10\x00\x12\x1c\n\x10unpacked_fixed64\x18\x61 \x03(\x06\x42\x02\x10\x00\x12\x1d\n\x11unpacked_sfixed32\x18\x62 \x03(\x0f\x42\x02\x10\x00\x12\x1d\n\x11unpacked_sfixed64\x18\x63 \x03(\x10\x42\x02\x10\x00\x12\x1a\n\x0eunpacked_float\x18\x64 \x03(\x02\x42\x02\x10\x00\x12\x1b\n\x0funpacked_double\x18\x65 \x03(\x01\x42\x02\x10\x00\x12\x19\n\runpacked_bool\x18\x66 \x03(\x08\x42\x02\x10\x00\x12\x39\n\runpacked_enum\x18g \x03(\x0e\x32\x1e.protobuf_unittest.ForeignEnumB\x02\x10\x00\" \n\x14TestPackedExtensions*\x08\x08\x01\x10\x80\x80\x80\x80\x02\"\"\n\x16TestUnpackedExtensions*\x08\x08\x01\x10\x80\x80\x80\x80\x02\"\x99\x04\n\x15TestDynamicExtensions\x12\x19\n\x10scalar_extension\x18\xd0\x0f \x01(\x07\x12\x37\n\x0e\x65num_extension\x18\xd1\x0f \x01(\x0e\x32\x1e.protobuf_unittest.ForeignEnum\x12Y\n\x16\x64ynamic_enum_extension\x18\xd2\x0f \x01(\x0e\x32\x38.protobuf_unittest.TestDynamicExtensions.DynamicEnumType\x12=\n\x11message_extension\x18\xd3\x0f \x01(\x0b\x32!.protobuf_unittest.ForeignMessage\x12_\n\x19\x64ynamic_message_extension\x18\xd4\x0f \x01(\x0b\x32;.protobuf_unittest.TestDynamicExtensions.DynamicMessageType\x12\x1b\n\x12repeated_extension\x18\xd5\x0f \x03(\t\x12\x1d\n\x10packed_extension\x18\xd6\x0f \x03(\x11\x42\x02\x10\x01\x1a,\n\x12\x44ynamicMessageType\x12\x16\n\rdynamic_field\x18\xb4\x10 \x01(\x05\"G\n\x0f\x44ynamicEnumType\x12\x10\n\x0b\x44YNAMIC_FOO\x10\x98\x11\x12\x10\n\x0b\x44YNAMIC_BAR\x10\x99\x11\x12\x10\n\x0b\x44YNAMIC_BAZ\x10\x9a\x11\"\xc0\x01\n#TestRepeatedScalarDifferentTagSizes\x12\x18\n\x10repeated_fixed32\x18\x0c \x03(\x07\x12\x16\n\x0erepeated_int32\x18\r \x03(\x05\x12\x19\n\x10repeated_fixed64\x18\xfe\x0f \x03(\x06\x12\x17\n\x0erepeated_int64\x18\xff\x0f \x03(\x03\x12\x18\n\x0erepeated_float\x18\xfe\xff\x0f \x03(\x02\x12\x19\n\x0frepeated_uint64\x18\xff\xff\x0f \x03(\x04\"\xf7\t\n\x10TestParsingMerge\x12;\n\x12required_all_types\x18\x01 \x02(\x0b\x32\x1f.protobuf_unittest.TestAllTypes\x12;\n\x12optional_all_types\x18\x02 \x01(\x0b\x32\x1f.protobuf_unittest.TestAllTypes\x12;\n\x12repeated_all_types\x18\x03 \x03(\x0b\x32\x1f.protobuf_unittest.TestAllTypes\x12H\n\roptionalgroup\x18\n \x01(\n21.protobuf_unittest.TestParsingMerge.OptionalGroup\x12H\n\rrepeatedgroup\x18\x14 \x03(\n21.protobuf_unittest.TestParsingMerge.RepeatedGroup\x1a\xaa\x04\n\x17RepeatedFieldsGenerator\x12/\n\x06\x66ield1\x18\x01 \x03(\x0b\x32\x1f.protobuf_unittest.TestAllTypes\x12/\n\x06\x66ield2\x18\x02 \x03(\x0b\x32\x1f.protobuf_unittest.TestAllTypes\x12/\n\x06\x66ield3\x18\x03 \x03(\x0b\x32\x1f.protobuf_unittest.TestAllTypes\x12R\n\x06group1\x18\n \x03(\n2B.protobuf_unittest.TestParsingMerge.RepeatedFieldsGenerator.Group1\x12R\n\x06group2\x18\x14 \x03(\n2B.protobuf_unittest.TestParsingMerge.RepeatedFieldsGenerator.Group2\x12.\n\x04\x65xt1\x18\xe8\x07 \x03(\x0b\x32\x1f.protobuf_unittest.TestAllTypes\x12.\n\x04\x65xt2\x18\xe9\x07 \x03(\x0b\x32\x1f.protobuf_unittest.TestAllTypes\x1a\x39\n\x06Group1\x12/\n\x06\x66ield1\x18\x0b \x01(\x0b\x32\x1f.protobuf_unittest.TestAllTypes\x1a\x39\n\x06Group2\x12/\n\x06\x66ield1\x18\x15 \x01(\x0b\x32\x1f.protobuf_unittest.TestAllTypes\x1aR\n\rOptionalGroup\x12\x41\n\x18optional_group_all_types\x18\x0b \x01(\x0b\x32\x1f.protobuf_unittest.TestAllTypes\x1aR\n\rRepeatedGroup\x12\x41\n\x18repeated_group_all_types\x18\x15 \x01(\x0b\x32\x1f.protobuf_unittest.TestAllTypes*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02\x32[\n\x0coptional_ext\x12#.protobuf_unittest.TestParsingMerge\x18\xe8\x07 \x01(\x0b\x32\x1f.protobuf_unittest.TestAllTypes2[\n\x0crepeated_ext\x12#.protobuf_unittest.TestParsingMerge\x18\xe9\x07 \x03(\x0b\x32\x1f.protobuf_unittest.TestAllTypes\"D\n\x1bTestCommentInjectionMessage\x12%\n\x01\x61\x18\x01 \x01(\t:\x1a*/ <- Neither should this.\"\x0c\n\nFooRequest\"\r\n\x0b\x46ooResponse\"\x12\n\x10\x46ooClientMessage\"\x12\n\x10\x46ooServerMessage\"\x0c\n\nBarRequest\"\r\n\x0b\x42\x61rResponse\"\x92\x01\n\x0cTestJsonName\x12\x13\n\x0b\x66ield_name1\x18\x01 \x01(\x05\x12\x12\n\nfieldName2\x18\x02 \x01(\x05\x12\x12\n\nFieldName3\x18\x03 \x01(\x05\x12\x14\n\x0c_field_name4\x18\x04 \x01(\x05\x12\x13\n\x0b\x46IELD_NAME5\x18\x05 \x01(\x05\x12\x1a\n\x0b\x66ield_name6\x18\x06 \x01(\x05R\x05@type\"\xfd\x05\n\x14TestHugeFieldNumbers\x12\x1a\n\x0eoptional_int32\x18\xf0\xf8\xff\xff\x01 \x01(\x05\x12\x14\n\x08\x66ixed_32\x18\xf1\xf8\xff\xff\x01 \x01(\x05\x12\x1e\n\x0erepeated_int32\x18\xf2\xf8\xff\xff\x01 \x03(\x05\x42\x02\x10\x00\x12\x1c\n\x0cpacked_int32\x18\xf3\xf8\xff\xff\x01 \x03(\x05\x42\x02\x10\x01\x12\x39\n\roptional_enum\x18\xf4\xf8\xff\xff\x01 \x01(\x0e\x32\x1e.protobuf_unittest.ForeignEnum\x12\x1b\n\x0foptional_string\x18\xf5\xf8\xff\xff\x01 \x01(\t\x12\x1a\n\x0eoptional_bytes\x18\xf6\xf8\xff\xff\x01 \x01(\x0c\x12?\n\x10optional_message\x18\xf7\xf8\xff\xff\x01 \x01(\x0b\x32!.protobuf_unittest.ForeignMessage\x12P\n\roptionalgroup\x18\xf8\xf8\xff\xff\x01 \x01(\n25.protobuf_unittest.TestHugeFieldNumbers.OptionalGroup\x12[\n\x11string_string_map\x18\xfa\xf8\xff\xff\x01 \x03(\x0b\x32<.protobuf_unittest.TestHugeFieldNumbers.StringStringMapEntry\x12\x1a\n\x0coneof_uint32\x18\xfb\xf8\xff\xff\x01 \x01(\rH\x00\x12\x43\n\x14oneof_test_all_types\x18\xfc\xf8\xff\xff\x01 \x01(\x0b\x32\x1f.protobuf_unittest.TestAllTypesH\x00\x12\x1a\n\x0coneof_string\x18\xfd\xf8\xff\xff\x01 \x01(\tH\x00\x12\x19\n\x0boneof_bytes\x18\xfe\xf8\xff\xff\x01 \x01(\x0cH\x00\x1a$\n\rOptionalGroup\x12\x13\n\x07group_a\x18\xf9\xf8\xff\xff\x01 \x01(\x05\x1a\x36\n\x14StringStringMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01*\x0c\x08\xe0\xaa\xff\xff\x01\x10\xf0\xf8\xff\xff\x01\x42\r\n\x0boneof_field\"\xb1\x01\n\x18TestExtensionInsideTable\x12\x0e\n\x06\x66ield1\x18\x01 \x01(\x05\x12\x0e\n\x06\x66ield2\x18\x02 \x01(\x05\x12\x0e\n\x06\x66ield3\x18\x03 \x01(\x05\x12\x0e\n\x06\x66ield4\x18\x04 \x01(\x05\x12\x0e\n\x06\x66ield6\x18\x06 \x01(\x05\x12\x0e\n\x06\x66ield7\x18\x07 \x01(\x05\x12\x0e\n\x06\x66ield8\x18\x08 \x01(\x05\x12\x0e\n\x06\x66ield9\x18\t \x01(\x05\x12\x0f\n\x07\x66ield10\x18\n \x01(\x05*\x04\x08\x05\x10\x06*@\n\x0b\x46oreignEnum\x12\x0f\n\x0b\x46OREIGN_FOO\x10\x04\x12\x0f\n\x0b\x46OREIGN_BAR\x10\x05\x12\x0f\n\x0b\x46OREIGN_BAZ\x10\x06*K\n\x14TestEnumWithDupValue\x12\x08\n\x04\x46OO1\x10\x01\x12\x08\n\x04\x42\x41R1\x10\x02\x12\x07\n\x03\x42\x41Z\x10\x03\x12\x08\n\x04\x46OO2\x10\x01\x12\x08\n\x04\x42\x41R2\x10\x02\x1a\x02\x10\x01*\x89\x01\n\x0eTestSparseEnum\x12\x0c\n\x08SPARSE_A\x10{\x12\x0e\n\x08SPARSE_B\x10\xa6\xe7\x03\x12\x0f\n\x08SPARSE_C\x10\xb2\xb1\x80\x06\x12\x15\n\x08SPARSE_D\x10\xf1\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x15\n\x08SPARSE_E\x10\xb4\xde\xfc\xff\xff\xff\xff\xff\xff\x01\x12\x0c\n\x08SPARSE_F\x10\x00\x12\x0c\n\x08SPARSE_G\x10\x02*\x8b\x0f\n\rVeryLargeEnum\x12\x16\n\x12\x45NUM_LABEL_DEFAULT\x10\x00\x12\x10\n\x0c\x45NUM_LABEL_1\x10\x01\x12\x10\n\x0c\x45NUM_LABEL_2\x10\x02\x12\x10\n\x0c\x45NUM_LABEL_3\x10\x03\x12\x10\n\x0c\x45NUM_LABEL_4\x10\x04\x12\x10\n\x0c\x45NUM_LABEL_5\x10\x05\x12\x10\n\x0c\x45NUM_LABEL_6\x10\x06\x12\x10\n\x0c\x45NUM_LABEL_7\x10\x07\x12\x10\n\x0c\x45NUM_LABEL_8\x10\x08\x12\x10\n\x0c\x45NUM_LABEL_9\x10\t\x12\x11\n\rENUM_LABEL_10\x10\n\x12\x11\n\rENUM_LABEL_11\x10\x0b\x12\x11\n\rENUM_LABEL_12\x10\x0c\x12\x11\n\rENUM_LABEL_13\x10\r\x12\x11\n\rENUM_LABEL_14\x10\x0e\x12\x11\n\rENUM_LABEL_15\x10\x0f\x12\x11\n\rENUM_LABEL_16\x10\x10\x12\x11\n\rENUM_LABEL_17\x10\x11\x12\x11\n\rENUM_LABEL_18\x10\x12\x12\x11\n\rENUM_LABEL_19\x10\x13\x12\x11\n\rENUM_LABEL_20\x10\x14\x12\x11\n\rENUM_LABEL_21\x10\x15\x12\x11\n\rENUM_LABEL_22\x10\x16\x12\x11\n\rENUM_LABEL_23\x10\x17\x12\x11\n\rENUM_LABEL_24\x10\x18\x12\x11\n\rENUM_LABEL_25\x10\x19\x12\x11\n\rENUM_LABEL_26\x10\x1a\x12\x11\n\rENUM_LABEL_27\x10\x1b\x12\x11\n\rENUM_LABEL_28\x10\x1c\x12\x11\n\rENUM_LABEL_29\x10\x1d\x12\x11\n\rENUM_LABEL_30\x10\x1e\x12\x11\n\rENUM_LABEL_31\x10\x1f\x12\x11\n\rENUM_LABEL_32\x10 \x12\x11\n\rENUM_LABEL_33\x10!\x12\x11\n\rENUM_LABEL_34\x10\"\x12\x11\n\rENUM_LABEL_35\x10#\x12\x11\n\rENUM_LABEL_36\x10$\x12\x11\n\rENUM_LABEL_37\x10%\x12\x11\n\rENUM_LABEL_38\x10&\x12\x11\n\rENUM_LABEL_39\x10\'\x12\x11\n\rENUM_LABEL_40\x10(\x12\x11\n\rENUM_LABEL_41\x10)\x12\x11\n\rENUM_LABEL_42\x10*\x12\x11\n\rENUM_LABEL_43\x10+\x12\x11\n\rENUM_LABEL_44\x10,\x12\x11\n\rENUM_LABEL_45\x10-\x12\x11\n\rENUM_LABEL_46\x10.\x12\x11\n\rENUM_LABEL_47\x10/\x12\x11\n\rENUM_LABEL_48\x10\x30\x12\x11\n\rENUM_LABEL_49\x10\x31\x12\x11\n\rENUM_LABEL_50\x10\x32\x12\x11\n\rENUM_LABEL_51\x10\x33\x12\x11\n\rENUM_LABEL_52\x10\x34\x12\x11\n\rENUM_LABEL_53\x10\x35\x12\x11\n\rENUM_LABEL_54\x10\x36\x12\x11\n\rENUM_LABEL_55\x10\x37\x12\x11\n\rENUM_LABEL_56\x10\x38\x12\x11\n\rENUM_LABEL_57\x10\x39\x12\x11\n\rENUM_LABEL_58\x10:\x12\x11\n\rENUM_LABEL_59\x10;\x12\x11\n\rENUM_LABEL_60\x10<\x12\x11\n\rENUM_LABEL_61\x10=\x12\x11\n\rENUM_LABEL_62\x10>\x12\x11\n\rENUM_LABEL_63\x10?\x12\x11\n\rENUM_LABEL_64\x10@\x12\x11\n\rENUM_LABEL_65\x10\x41\x12\x11\n\rENUM_LABEL_66\x10\x42\x12\x11\n\rENUM_LABEL_67\x10\x43\x12\x11\n\rENUM_LABEL_68\x10\x44\x12\x11\n\rENUM_LABEL_69\x10\x45\x12\x11\n\rENUM_LABEL_70\x10\x46\x12\x11\n\rENUM_LABEL_71\x10G\x12\x11\n\rENUM_LABEL_72\x10H\x12\x11\n\rENUM_LABEL_73\x10I\x12\x11\n\rENUM_LABEL_74\x10J\x12\x11\n\rENUM_LABEL_75\x10K\x12\x11\n\rENUM_LABEL_76\x10L\x12\x11\n\rENUM_LABEL_77\x10M\x12\x11\n\rENUM_LABEL_78\x10N\x12\x11\n\rENUM_LABEL_79\x10O\x12\x11\n\rENUM_LABEL_80\x10P\x12\x11\n\rENUM_LABEL_81\x10Q\x12\x11\n\rENUM_LABEL_82\x10R\x12\x11\n\rENUM_LABEL_83\x10S\x12\x11\n\rENUM_LABEL_84\x10T\x12\x11\n\rENUM_LABEL_85\x10U\x12\x11\n\rENUM_LABEL_86\x10V\x12\x11\n\rENUM_LABEL_87\x10W\x12\x11\n\rENUM_LABEL_88\x10X\x12\x11\n\rENUM_LABEL_89\x10Y\x12\x11\n\rENUM_LABEL_90\x10Z\x12\x11\n\rENUM_LABEL_91\x10[\x12\x11\n\rENUM_LABEL_92\x10\\\x12\x11\n\rENUM_LABEL_93\x10]\x12\x11\n\rENUM_LABEL_94\x10^\x12\x11\n\rENUM_LABEL_95\x10_\x12\x11\n\rENUM_LABEL_96\x10`\x12\x11\n\rENUM_LABEL_97\x10\x61\x12\x11\n\rENUM_LABEL_98\x10\x62\x12\x11\n\rENUM_LABEL_99\x10\x63\x12\x12\n\x0e\x45NUM_LABEL_100\x10\x64\x32\x99\x01\n\x0bTestService\x12\x44\n\x03\x46oo\x12\x1d.protobuf_unittest.FooRequest\x1a\x1e.protobuf_unittest.FooResponse\x12\x44\n\x03\x42\x61r\x12\x1d.protobuf_unittest.BarRequest\x1a\x1e.protobuf_unittest.BarResponse:F\n\x18optional_int32_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x01 \x01(\x05:F\n\x18optional_int64_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x02 \x01(\x03:G\n\x19optional_uint32_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x03 \x01(\r:G\n\x19optional_uint64_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x04 \x01(\x04:G\n\x19optional_sint32_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x05 \x01(\x11:G\n\x19optional_sint64_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x06 \x01(\x12:H\n\x1aoptional_fixed32_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x07 \x01(\x07:H\n\x1aoptional_fixed64_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x08 \x01(\x06:I\n\x1boptional_sfixed32_extension\x12$.protobuf_unittest.TestAllExtensions\x18\t \x01(\x0f:I\n\x1boptional_sfixed64_extension\x12$.protobuf_unittest.TestAllExtensions\x18\n \x01(\x10:F\n\x18optional_float_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x0b \x01(\x02:G\n\x19optional_double_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x0c \x01(\x01:E\n\x17optional_bool_extension\x12$.protobuf_unittest.TestAllExtensions\x18\r \x01(\x08:G\n\x19optional_string_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x0e \x01(\t:F\n\x18optional_bytes_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x0f \x01(\x0c:q\n\x17optionalgroup_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x10 \x01(\n2*.protobuf_unittest.OptionalGroup_extension:~\n!optional_nested_message_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x12 \x01(\x0b\x32-.protobuf_unittest.TestAllTypes.NestedMessage:s\n\"optional_foreign_message_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x13 \x01(\x0b\x32!.protobuf_unittest.ForeignMessage:x\n!optional_import_message_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x14 \x01(\x0b\x32\'.protobuf_unittest_import.ImportMessage:x\n\x1eoptional_nested_enum_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x15 \x01(\x0e\x32*.protobuf_unittest.TestAllTypes.NestedEnum:m\n\x1foptional_foreign_enum_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x16 \x01(\x0e\x32\x1e.protobuf_unittest.ForeignEnum:r\n\x1eoptional_import_enum_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x17 \x01(\x0e\x32$.protobuf_unittest_import.ImportEnum:Q\n\x1foptional_string_piece_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x18 \x01(\tB\x02\x08\x02:I\n\x17optional_cord_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x19 \x01(\tB\x02\x08\x01:\x85\x01\n(optional_public_import_message_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x1a \x01(\x0b\x32-.protobuf_unittest_import.PublicImportMessage:\x80\x01\n\x1foptional_lazy_message_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x1b \x01(\x0b\x32-.protobuf_unittest.TestAllTypes.NestedMessageB\x02(\x01:F\n\x18repeated_int32_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x1f \x03(\x05:F\n\x18repeated_int64_extension\x12$.protobuf_unittest.TestAllExtensions\x18  \x03(\x03:G\n\x19repeated_uint32_extension\x12$.protobuf_unittest.TestAllExtensions\x18! \x03(\r:G\n\x19repeated_uint64_extension\x12$.protobuf_unittest.TestAllExtensions\x18\" \x03(\x04:G\n\x19repeated_sint32_extension\x12$.protobuf_unittest.TestAllExtensions\x18# \x03(\x11:G\n\x19repeated_sint64_extension\x12$.protobuf_unittest.TestAllExtensions\x18$ \x03(\x12:H\n\x1arepeated_fixed32_extension\x12$.protobuf_unittest.TestAllExtensions\x18% \x03(\x07:H\n\x1arepeated_fixed64_extension\x12$.protobuf_unittest.TestAllExtensions\x18& \x03(\x06:I\n\x1brepeated_sfixed32_extension\x12$.protobuf_unittest.TestAllExtensions\x18\' \x03(\x0f:I\n\x1brepeated_sfixed64_extension\x12$.protobuf_unittest.TestAllExtensions\x18( \x03(\x10:F\n\x18repeated_float_extension\x12$.protobuf_unittest.TestAllExtensions\x18) \x03(\x02:G\n\x19repeated_double_extension\x12$.protobuf_unittest.TestAllExtensions\x18* \x03(\x01:E\n\x17repeated_bool_extension\x12$.protobuf_unittest.TestAllExtensions\x18+ \x03(\x08:G\n\x19repeated_string_extension\x12$.protobuf_unittest.TestAllExtensions\x18, \x03(\t:F\n\x18repeated_bytes_extension\x12$.protobuf_unittest.TestAllExtensions\x18- \x03(\x0c:q\n\x17repeatedgroup_extension\x12$.protobuf_unittest.TestAllExtensions\x18. \x03(\n2*.protobuf_unittest.RepeatedGroup_extension:~\n!repeated_nested_message_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x30 \x03(\x0b\x32-.protobuf_unittest.TestAllTypes.NestedMessage:s\n\"repeated_foreign_message_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x31 \x03(\x0b\x32!.protobuf_unittest.ForeignMessage:x\n!repeated_import_message_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x32 \x03(\x0b\x32\'.protobuf_unittest_import.ImportMessage:x\n\x1erepeated_nested_enum_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x33 \x03(\x0e\x32*.protobuf_unittest.TestAllTypes.NestedEnum:m\n\x1frepeated_foreign_enum_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x34 \x03(\x0e\x32\x1e.protobuf_unittest.ForeignEnum:r\n\x1erepeated_import_enum_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x35 \x03(\x0e\x32$.protobuf_unittest_import.ImportEnum:Q\n\x1frepeated_string_piece_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x36 \x03(\tB\x02\x08\x02:I\n\x17repeated_cord_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x37 \x03(\tB\x02\x08\x01:\x80\x01\n\x1frepeated_lazy_message_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x39 \x03(\x0b\x32-.protobuf_unittest.TestAllTypes.NestedMessageB\x02(\x01:I\n\x17\x64\x65\x66\x61ult_int32_extension\x12$.protobuf_unittest.TestAllExtensions\x18= \x01(\x05:\x02\x34\x31:I\n\x17\x64\x65\x66\x61ult_int64_extension\x12$.protobuf_unittest.TestAllExtensions\x18> \x01(\x03:\x02\x34\x32:J\n\x18\x64\x65\x66\x61ult_uint32_extension\x12$.protobuf_unittest.TestAllExtensions\x18? \x01(\r:\x02\x34\x33:J\n\x18\x64\x65\x66\x61ult_uint64_extension\x12$.protobuf_unittest.TestAllExtensions\x18@ \x01(\x04:\x02\x34\x34:K\n\x18\x64\x65\x66\x61ult_sint32_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x41 \x01(\x11:\x03-45:J\n\x18\x64\x65\x66\x61ult_sint64_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x42 \x01(\x12:\x02\x34\x36:K\n\x19\x64\x65\x66\x61ult_fixed32_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x43 \x01(\x07:\x02\x34\x37:K\n\x19\x64\x65\x66\x61ult_fixed64_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x44 \x01(\x06:\x02\x34\x38:L\n\x1a\x64\x65\x66\x61ult_sfixed32_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x45 \x01(\x0f:\x02\x34\x39:M\n\x1a\x64\x65\x66\x61ult_sfixed64_extension\x12$.protobuf_unittest.TestAllExtensions\x18\x46 \x01(\x10:\x03-50:K\n\x17\x64\x65\x66\x61ult_float_extension\x12$.protobuf_unittest.TestAllExtensions\x18G \x01(\x02:\x04\x35\x31.5:M\n\x18\x64\x65\x66\x61ult_double_extension\x12$.protobuf_unittest.TestAllExtensions\x18H \x01(\x01:\x05\x35\x32\x30\x30\x30:J\n\x16\x64\x65\x66\x61ult_bool_extension\x12$.protobuf_unittest.TestAllExtensions\x18I \x01(\x08:\x04true:M\n\x18\x64\x65\x66\x61ult_string_extension\x12$.protobuf_unittest.TestAllExtensions\x18J \x01(\t:\x05hello:L\n\x17\x64\x65\x66\x61ult_bytes_extension\x12$.protobuf_unittest.TestAllExtensions\x18K \x01(\x0c:\x05world:|\n\x1d\x64\x65\x66\x61ult_nested_enum_extension\x12$.protobuf_unittest.TestAllExtensions\x18Q \x01(\x0e\x32*.protobuf_unittest.TestAllTypes.NestedEnum:\x03\x42\x41R:y\n\x1e\x64\x65\x66\x61ult_foreign_enum_extension\x12$.protobuf_unittest.TestAllExtensions\x18R \x01(\x0e\x32\x1e.protobuf_unittest.ForeignEnum:\x0b\x46OREIGN_BAR:}\n\x1d\x64\x65\x66\x61ult_import_enum_extension\x12$.protobuf_unittest.TestAllExtensions\x18S \x01(\x0e\x32$.protobuf_unittest_import.ImportEnum:\nIMPORT_BAR:U\n\x1e\x64\x65\x66\x61ult_string_piece_extension\x12$.protobuf_unittest.TestAllExtensions\x18T \x01(\t:\x03\x61\x62\x63\x42\x02\x08\x02:M\n\x16\x64\x65\x66\x61ult_cord_extension\x12$.protobuf_unittest.TestAllExtensions\x18U \x01(\t:\x03\x31\x32\x33\x42\x02\x08\x01:D\n\x16oneof_uint32_extension\x12$.protobuf_unittest.TestAllExtensions\x18o \x01(\r:{\n\x1eoneof_nested_message_extension\x12$.protobuf_unittest.TestAllExtensions\x18p \x01(\x0b\x32-.protobuf_unittest.TestAllTypes.NestedMessage:D\n\x16oneof_string_extension\x12$.protobuf_unittest.TestAllExtensions\x18q \x01(\t:C\n\x15oneof_bytes_extension\x12$.protobuf_unittest.TestAllExtensions\x18r \x01(\x0c:B\n\x13my_extension_string\x12%.protobuf_unittest.TestFieldOrderings\x18\x32 \x01(\t:?\n\x10my_extension_int\x12%.protobuf_unittest.TestFieldOrderings\x18\x05 \x01(\x05:K\n\x16packed_int32_extension\x12\'.protobuf_unittest.TestPackedExtensions\x18Z \x03(\x05\x42\x02\x10\x01:K\n\x16packed_int64_extension\x12\'.protobuf_unittest.TestPackedExtensions\x18[ \x03(\x03\x42\x02\x10\x01:L\n\x17packed_uint32_extension\x12\'.protobuf_unittest.TestPackedExtensions\x18\\ \x03(\rB\x02\x10\x01:L\n\x17packed_uint64_extension\x12\'.protobuf_unittest.TestPackedExtensions\x18] \x03(\x04\x42\x02\x10\x01:L\n\x17packed_sint32_extension\x12\'.protobuf_unittest.TestPackedExtensions\x18^ \x03(\x11\x42\x02\x10\x01:L\n\x17packed_sint64_extension\x12\'.protobuf_unittest.TestPackedExtensions\x18_ \x03(\x12\x42\x02\x10\x01:M\n\x18packed_fixed32_extension\x12\'.protobuf_unittest.TestPackedExtensions\x18` \x03(\x07\x42\x02\x10\x01:M\n\x18packed_fixed64_extension\x12\'.protobuf_unittest.TestPackedExtensions\x18\x61 \x03(\x06\x42\x02\x10\x01:N\n\x19packed_sfixed32_extension\x12\'.protobuf_unittest.TestPackedExtensions\x18\x62 \x03(\x0f\x42\x02\x10\x01:N\n\x19packed_sfixed64_extension\x12\'.protobuf_unittest.TestPackedExtensions\x18\x63 \x03(\x10\x42\x02\x10\x01:K\n\x16packed_float_extension\x12\'.protobuf_unittest.TestPackedExtensions\x18\x64 \x03(\x02\x42\x02\x10\x01:L\n\x17packed_double_extension\x12\'.protobuf_unittest.TestPackedExtensions\x18\x65 \x03(\x01\x42\x02\x10\x01:J\n\x15packed_bool_extension\x12\'.protobuf_unittest.TestPackedExtensions\x18\x66 \x03(\x08\x42\x02\x10\x01:j\n\x15packed_enum_extension\x12\'.protobuf_unittest.TestPackedExtensions\x18g \x03(\x0e\x32\x1e.protobuf_unittest.ForeignEnumB\x02\x10\x01:O\n\x18unpacked_int32_extension\x12).protobuf_unittest.TestUnpackedExtensions\x18Z \x03(\x05\x42\x02\x10\x00:O\n\x18unpacked_int64_extension\x12).protobuf_unittest.TestUnpackedExtensions\x18[ \x03(\x03\x42\x02\x10\x00:P\n\x19unpacked_uint32_extension\x12).protobuf_unittest.TestUnpackedExtensions\x18\\ \x03(\rB\x02\x10\x00:P\n\x19unpacked_uint64_extension\x12).protobuf_unittest.TestUnpackedExtensions\x18] \x03(\x04\x42\x02\x10\x00:P\n\x19unpacked_sint32_extension\x12).protobuf_unittest.TestUnpackedExtensions\x18^ \x03(\x11\x42\x02\x10\x00:P\n\x19unpacked_sint64_extension\x12).protobuf_unittest.TestUnpackedExtensions\x18_ \x03(\x12\x42\x02\x10\x00:Q\n\x1aunpacked_fixed32_extension\x12).protobuf_unittest.TestUnpackedExtensions\x18` \x03(\x07\x42\x02\x10\x00:Q\n\x1aunpacked_fixed64_extension\x12).protobuf_unittest.TestUnpackedExtensions\x18\x61 \x03(\x06\x42\x02\x10\x00:R\n\x1bunpacked_sfixed32_extension\x12).protobuf_unittest.TestUnpackedExtensions\x18\x62 \x03(\x0f\x42\x02\x10\x00:R\n\x1bunpacked_sfixed64_extension\x12).protobuf_unittest.TestUnpackedExtensions\x18\x63 \x03(\x10\x42\x02\x10\x00:O\n\x18unpacked_float_extension\x12).protobuf_unittest.TestUnpackedExtensions\x18\x64 \x03(\x02\x42\x02\x10\x00:P\n\x19unpacked_double_extension\x12).protobuf_unittest.TestUnpackedExtensions\x18\x65 \x03(\x01\x42\x02\x10\x00:N\n\x17unpacked_bool_extension\x12).protobuf_unittest.TestUnpackedExtensions\x18\x66 \x03(\x08\x42\x02\x10\x00:n\n\x17unpacked_enum_extension\x12).protobuf_unittest.TestUnpackedExtensions\x18g \x03(\x0e\x32\x1e.protobuf_unittest.ForeignEnumB\x02\x10\x00:d\n\x0etest_all_types\x12\'.protobuf_unittest.TestHugeFieldNumbers\x18\xe0\xaa\xff\xff\x01 \x01(\x0b\x32\x1f.protobuf_unittest.TestAllTypes:Z\n%test_extension_inside_table_extension\x12+.protobuf_unittest.TestExtensionInsideTable\x18\x05 \x01(\x05\x42\x1d\x42\rUnittestProtoH\x01\x80\x01\x01\x88\x01\x01\x90\x01\x01\xf8\x01\x01'
  ,
  dependencies=[google_dot_protobuf_dot_unittest__import__pb2.DESCRIPTOR,])

_FOREIGNENUM = _descriptor.EnumDescriptor(
  name='ForeignEnum',
  full_name='protobuf_unittest.ForeignEnum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FOREIGN_FOO', index=0, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOREIGN_BAR', index=1, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOREIGN_BAZ', index=2, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15397,
  serialized_end=15461,
)
_sym_db.RegisterEnumDescriptor(_FOREIGNENUM)

ForeignEnum = enum_type_wrapper.EnumTypeWrapper(_FOREIGNENUM)
_TESTENUMWITHDUPVALUE = _descriptor.EnumDescriptor(
  name='TestEnumWithDupValue',
  full_name='protobuf_unittest.TestEnumWithDupValue',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FOO1', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAR1', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAZ', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOO2', index=3, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAR2', index=4, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=b'\020\001',
  serialized_start=15463,
  serialized_end=15538,
)
_sym_db.RegisterEnumDescriptor(_TESTENUMWITHDUPVALUE)

TestEnumWithDupValue = enum_type_wrapper.EnumTypeWrapper(_TESTENUMWITHDUPVALUE)
_TESTSPARSEENUM = _descriptor.EnumDescriptor(
  name='TestSparseEnum',
  full_name='protobuf_unittest.TestSparseEnum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SPARSE_A', index=0, number=123,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPARSE_B', index=1, number=62374,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPARSE_C', index=2, number=12589234,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPARSE_D', index=3, number=-15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPARSE_E', index=4, number=-53452,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPARSE_F', index=5, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPARSE_G', index=6, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15541,
  serialized_end=15678,
)
_sym_db.RegisterEnumDescriptor(_TESTSPARSEENUM)

TestSparseEnum = enum_type_wrapper.EnumTypeWrapper(_TESTSPARSEENUM)
_VERYLARGEENUM = _descriptor.EnumDescriptor(
  name='VeryLargeEnum',
  full_name='protobuf_unittest.VeryLargeEnum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_4', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_5', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_6', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_7', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_8', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_9', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_10', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_11', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_12', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_13', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_14', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_15', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_16', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_17', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_18', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_19', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_20', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_21', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_22', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_23', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_24', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_25', index=25, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_26', index=26, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_27', index=27, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_28', index=28, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_29', index=29, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_30', index=30, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_31', index=31, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_32', index=32, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_33', index=33, number=33,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_34', index=34, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_35', index=35, number=35,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_36', index=36, number=36,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_37', index=37, number=37,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_38', index=38, number=38,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_39', index=39, number=39,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_40', index=40, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_41', index=41, number=41,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_42', index=42, number=42,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_43', index=43, number=43,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_44', index=44, number=44,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_45', index=45, number=45,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_46', index=46, number=46,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_47', index=47, number=47,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_48', index=48, number=48,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_49', index=49, number=49,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_50', index=50, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_51', index=51, number=51,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_52', index=52, number=52,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_53', index=53, number=53,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_54', index=54, number=54,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_55', index=55, number=55,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_56', index=56, number=56,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_57', index=57, number=57,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_58', index=58, number=58,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_59', index=59, number=59,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_60', index=60, number=60,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_61', index=61, number=61,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_62', index=62, number=62,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_63', index=63, number=63,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_64', index=64, number=64,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_65', index=65, number=65,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_66', index=66, number=66,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_67', index=67, number=67,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_68', index=68, number=68,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_69', index=69, number=69,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_70', index=70, number=70,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_71', index=71, number=71,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_72', index=72, number=72,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_73', index=73, number=73,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_74', index=74, number=74,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_75', index=75, number=75,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_76', index=76, number=76,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_77', index=77, number=77,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_78', index=78, number=78,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_79', index=79, number=79,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_80', index=80, number=80,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_81', index=81, number=81,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_82', index=82, number=82,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_83', index=83, number=83,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_84', index=84, number=84,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_85', index=85, number=85,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_86', index=86, number=86,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_87', index=87, number=87,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_88', index=88, number=88,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_89', index=89, number=89,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_90', index=90, number=90,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_91', index=91, number=91,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_92', index=92, number=92,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_93', index=93, number=93,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_94', index=94, number=94,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_95', index=95, number=95,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_96', index=96, number=96,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_97', index=97, number=97,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_98', index=98, number=98,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_99', index=99, number=99,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENUM_LABEL_100', index=100, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15681,
  serialized_end=17612,
)
_sym_db.RegisterEnumDescriptor(_VERYLARGEENUM)

VeryLargeEnum = enum_type_wrapper.EnumTypeWrapper(_VERYLARGEENUM)
FOREIGN_FOO = 4
FOREIGN_BAR = 5
FOREIGN_BAZ = 6
FOO1 = 1
BAR1 = 2
BAZ = 3
FOO2 = 1
BAR2 = 2
SPARSE_A = 123
SPARSE_B = 62374
SPARSE_C = 12589234
SPARSE_D = -15
SPARSE_E = -53452
SPARSE_F = 0
SPARSE_G = 2
ENUM_LABEL_DEFAULT = 0
ENUM_LABEL_1 = 1
ENUM_LABEL_2 = 2
ENUM_LABEL_3 = 3
ENUM_LABEL_4 = 4
ENUM_LABEL_5 = 5
ENUM_LABEL_6 = 6
ENUM_LABEL_7 = 7
ENUM_LABEL_8 = 8
ENUM_LABEL_9 = 9
ENUM_LABEL_10 = 10
ENUM_LABEL_11 = 11
ENUM_LABEL_12 = 12
ENUM_LABEL_13 = 13
ENUM_LABEL_14 = 14
ENUM_LABEL_15 = 15
ENUM_LABEL_16 = 16
ENUM_LABEL_17 = 17
ENUM_LABEL_18 = 18
ENUM_LABEL_19 = 19
ENUM_LABEL_20 = 20
ENUM_LABEL_21 = 21
ENUM_LABEL_22 = 22
ENUM_LABEL_23 = 23
ENUM_LABEL_24 = 24
ENUM_LABEL_25 = 25
ENUM_LABEL_26 = 26
ENUM_LABEL_27 = 27
ENUM_LABEL_28 = 28
ENUM_LABEL_29 = 29
ENUM_LABEL_30 = 30
ENUM_LABEL_31 = 31
ENUM_LABEL_32 = 32
ENUM_LABEL_33 = 33
ENUM_LABEL_34 = 34
ENUM_LABEL_35 = 35
ENUM_LABEL_36 = 36
ENUM_LABEL_37 = 37
ENUM_LABEL_38 = 38
ENUM_LABEL_39 = 39
ENUM_LABEL_40 = 40
ENUM_LABEL_41 = 41
ENUM_LABEL_42 = 42
ENUM_LABEL_43 = 43
ENUM_LABEL_44 = 44
ENUM_LABEL_45 = 45
ENUM_LABEL_46 = 46
ENUM_LABEL_47 = 47
ENUM_LABEL_48 = 48
ENUM_LABEL_49 = 49
ENUM_LABEL_50 = 50
ENUM_LABEL_51 = 51
ENUM_LABEL_52 = 52
ENUM_LABEL_53 = 53
ENUM_LABEL_54 = 54
ENUM_LABEL_55 = 55
ENUM_LABEL_56 = 56
ENUM_LABEL_57 = 57
ENUM_LABEL_58 = 58
ENUM_LABEL_59 = 59
ENUM_LABEL_60 = 60
ENUM_LABEL_61 = 61
ENUM_LABEL_62 = 62
ENUM_LABEL_63 = 63
ENUM_LABEL_64 = 64
ENUM_LABEL_65 = 65
ENUM_LABEL_66 = 66
ENUM_LABEL_67 = 67
ENUM_LABEL_68 = 68
ENUM_LABEL_69 = 69
ENUM_LABEL_70 = 70
ENUM_LABEL_71 = 71
ENUM_LABEL_72 = 72
ENUM_LABEL_73 = 73
ENUM_LABEL_74 = 74
ENUM_LABEL_75 = 75
ENUM_LABEL_76 = 76
ENUM_LABEL_77 = 77
ENUM_LABEL_78 = 78
ENUM_LABEL_79 = 79
ENUM_LABEL_80 = 80
ENUM_LABEL_81 = 81
ENUM_LABEL_82 = 82
ENUM_LABEL_83 = 83
ENUM_LABEL_84 = 84
ENUM_LABEL_85 = 85
ENUM_LABEL_86 = 86
ENUM_LABEL_87 = 87
ENUM_LABEL_88 = 88
ENUM_LABEL_89 = 89
ENUM_LABEL_90 = 90
ENUM_LABEL_91 = 91
ENUM_LABEL_92 = 92
ENUM_LABEL_93 = 93
ENUM_LABEL_94 = 94
ENUM_LABEL_95 = 95
ENUM_LABEL_96 = 96
ENUM_LABEL_97 = 97
ENUM_LABEL_98 = 98
ENUM_LABEL_99 = 99
ENUM_LABEL_100 = 100

OPTIONAL_INT32_EXTENSION_FIELD_NUMBER = 1
optional_int32_extension = _descriptor.FieldDescriptor(
  name='optional_int32_extension', full_name='protobuf_unittest.optional_int32_extension', index=0,
  number=1, type=5, cpp_type=1, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_INT64_EXTENSION_FIELD_NUMBER = 2
optional_int64_extension = _descriptor.FieldDescriptor(
  name='optional_int64_extension', full_name='protobuf_unittest.optional_int64_extension', index=1,
  number=2, type=3, cpp_type=2, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_UINT32_EXTENSION_FIELD_NUMBER = 3
optional_uint32_extension = _descriptor.FieldDescriptor(
  name='optional_uint32_extension', full_name='protobuf_unittest.optional_uint32_extension', index=2,
  number=3, type=13, cpp_type=3, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_UINT64_EXTENSION_FIELD_NUMBER = 4
optional_uint64_extension = _descriptor.FieldDescriptor(
  name='optional_uint64_extension', full_name='protobuf_unittest.optional_uint64_extension', index=3,
  number=4, type=4, cpp_type=4, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_SINT32_EXTENSION_FIELD_NUMBER = 5
optional_sint32_extension = _descriptor.FieldDescriptor(
  name='optional_sint32_extension', full_name='protobuf_unittest.optional_sint32_extension', index=4,
  number=5, type=17, cpp_type=1, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_SINT64_EXTENSION_FIELD_NUMBER = 6
optional_sint64_extension = _descriptor.FieldDescriptor(
  name='optional_sint64_extension', full_name='protobuf_unittest.optional_sint64_extension', index=5,
  number=6, type=18, cpp_type=2, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_FIXED32_EXTENSION_FIELD_NUMBER = 7
optional_fixed32_extension = _descriptor.FieldDescriptor(
  name='optional_fixed32_extension', full_name='protobuf_unittest.optional_fixed32_extension', index=6,
  number=7, type=7, cpp_type=3, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_FIXED64_EXTENSION_FIELD_NUMBER = 8
optional_fixed64_extension = _descriptor.FieldDescriptor(
  name='optional_fixed64_extension', full_name='protobuf_unittest.optional_fixed64_extension', index=7,
  number=8, type=6, cpp_type=4, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_SFIXED32_EXTENSION_FIELD_NUMBER = 9
optional_sfixed32_extension = _descriptor.FieldDescriptor(
  name='optional_sfixed32_extension', full_name='protobuf_unittest.optional_sfixed32_extension', index=8,
  number=9, type=15, cpp_type=1, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_SFIXED64_EXTENSION_FIELD_NUMBER = 10
optional_sfixed64_extension = _descriptor.FieldDescriptor(
  name='optional_sfixed64_extension', full_name='protobuf_unittest.optional_sfixed64_extension', index=9,
  number=10, type=16, cpp_type=2, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_FLOAT_EXTENSION_FIELD_NUMBER = 11
optional_float_extension = _descriptor.FieldDescriptor(
  name='optional_float_extension', full_name='protobuf_unittest.optional_float_extension', index=10,
  number=11, type=2, cpp_type=6, label=1,
  has_default_value=False, default_value=float(0),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_DOUBLE_EXTENSION_FIELD_NUMBER = 12
optional_double_extension = _descriptor.FieldDescriptor(
  name='optional_double_extension', full_name='protobuf_unittest.optional_double_extension', index=11,
  number=12, type=1, cpp_type=5, label=1,
  has_default_value=False, default_value=float(0),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_BOOL_EXTENSION_FIELD_NUMBER = 13
optional_bool_extension = _descriptor.FieldDescriptor(
  name='optional_bool_extension', full_name='protobuf_unittest.optional_bool_extension', index=12,
  number=13, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_STRING_EXTENSION_FIELD_NUMBER = 14
optional_string_extension = _descriptor.FieldDescriptor(
  name='optional_string_extension', full_name='protobuf_unittest.optional_string_extension', index=13,
  number=14, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_BYTES_EXTENSION_FIELD_NUMBER = 15
optional_bytes_extension = _descriptor.FieldDescriptor(
  name='optional_bytes_extension', full_name='protobuf_unittest.optional_bytes_extension', index=14,
  number=15, type=12, cpp_type=9, label=1,
  has_default_value=False, default_value=b"",
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONALGROUP_EXTENSION_FIELD_NUMBER = 16
optionalgroup_extension = _descriptor.FieldDescriptor(
  name='optionalgroup_extension', full_name='protobuf_unittest.optionalgroup_extension', index=15,
  number=16, type=10, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_NESTED_MESSAGE_EXTENSION_FIELD_NUMBER = 18
optional_nested_message_extension = _descriptor.FieldDescriptor(
  name='optional_nested_message_extension', full_name='protobuf_unittest.optional_nested_message_extension', index=16,
  number=18, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_FOREIGN_MESSAGE_EXTENSION_FIELD_NUMBER = 19
optional_foreign_message_extension = _descriptor.FieldDescriptor(
  name='optional_foreign_message_extension', full_name='protobuf_unittest.optional_foreign_message_extension', index=17,
  number=19, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_IMPORT_MESSAGE_EXTENSION_FIELD_NUMBER = 20
optional_import_message_extension = _descriptor.FieldDescriptor(
  name='optional_import_message_extension', full_name='protobuf_unittest.optional_import_message_extension', index=18,
  number=20, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_NESTED_ENUM_EXTENSION_FIELD_NUMBER = 21
optional_nested_enum_extension = _descriptor.FieldDescriptor(
  name='optional_nested_enum_extension', full_name='protobuf_unittest.optional_nested_enum_extension', index=19,
  number=21, type=14, cpp_type=8, label=1,
  has_default_value=False, default_value=1,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_FOREIGN_ENUM_EXTENSION_FIELD_NUMBER = 22
optional_foreign_enum_extension = _descriptor.FieldDescriptor(
  name='optional_foreign_enum_extension', full_name='protobuf_unittest.optional_foreign_enum_extension', index=20,
  number=22, type=14, cpp_type=8, label=1,
  has_default_value=False, default_value=4,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_IMPORT_ENUM_EXTENSION_FIELD_NUMBER = 23
optional_import_enum_extension = _descriptor.FieldDescriptor(
  name='optional_import_enum_extension', full_name='protobuf_unittest.optional_import_enum_extension', index=21,
  number=23, type=14, cpp_type=8, label=1,
  has_default_value=False, default_value=7,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_STRING_PIECE_EXTENSION_FIELD_NUMBER = 24
optional_string_piece_extension = _descriptor.FieldDescriptor(
  name='optional_string_piece_extension', full_name='protobuf_unittest.optional_string_piece_extension', index=22,
  number=24, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_CORD_EXTENSION_FIELD_NUMBER = 25
optional_cord_extension = _descriptor.FieldDescriptor(
  name='optional_cord_extension', full_name='protobuf_unittest.optional_cord_extension', index=23,
  number=25, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_PUBLIC_IMPORT_MESSAGE_EXTENSION_FIELD_NUMBER = 26
optional_public_import_message_extension = _descriptor.FieldDescriptor(
  name='optional_public_import_message_extension', full_name='protobuf_unittest.optional_public_import_message_extension', index=24,
  number=26, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_LAZY_MESSAGE_EXTENSION_FIELD_NUMBER = 27
optional_lazy_message_extension = _descriptor.FieldDescriptor(
  name='optional_lazy_message_extension', full_name='protobuf_unittest.optional_lazy_message_extension', index=25,
  number=27, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_INT32_EXTENSION_FIELD_NUMBER = 31
repeated_int32_extension = _descriptor.FieldDescriptor(
  name='repeated_int32_extension', full_name='protobuf_unittest.repeated_int32_extension', index=26,
  number=31, type=5, cpp_type=1, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_INT64_EXTENSION_FIELD_NUMBER = 32
repeated_int64_extension = _descriptor.FieldDescriptor(
  name='repeated_int64_extension', full_name='protobuf_unittest.repeated_int64_extension', index=27,
  number=32, type=3, cpp_type=2, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_UINT32_EXTENSION_FIELD_NUMBER = 33
repeated_uint32_extension = _descriptor.FieldDescriptor(
  name='repeated_uint32_extension', full_name='protobuf_unittest.repeated_uint32_extension', index=28,
  number=33, type=13, cpp_type=3, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_UINT64_EXTENSION_FIELD_NUMBER = 34
repeated_uint64_extension = _descriptor.FieldDescriptor(
  name='repeated_uint64_extension', full_name='protobuf_unittest.repeated_uint64_extension', index=29,
  number=34, type=4, cpp_type=4, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_SINT32_EXTENSION_FIELD_NUMBER = 35
repeated_sint32_extension = _descriptor.FieldDescriptor(
  name='repeated_sint32_extension', full_name='protobuf_unittest.repeated_sint32_extension', index=30,
  number=35, type=17, cpp_type=1, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_SINT64_EXTENSION_FIELD_NUMBER = 36
repeated_sint64_extension = _descriptor.FieldDescriptor(
  name='repeated_sint64_extension', full_name='protobuf_unittest.repeated_sint64_extension', index=31,
  number=36, type=18, cpp_type=2, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_FIXED32_EXTENSION_FIELD_NUMBER = 37
repeated_fixed32_extension = _descriptor.FieldDescriptor(
  name='repeated_fixed32_extension', full_name='protobuf_unittest.repeated_fixed32_extension', index=32,
  number=37, type=7, cpp_type=3, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_FIXED64_EXTENSION_FIELD_NUMBER = 38
repeated_fixed64_extension = _descriptor.FieldDescriptor(
  name='repeated_fixed64_extension', full_name='protobuf_unittest.repeated_fixed64_extension', index=33,
  number=38, type=6, cpp_type=4, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_SFIXED32_EXTENSION_FIELD_NUMBER = 39
repeated_sfixed32_extension = _descriptor.FieldDescriptor(
  name='repeated_sfixed32_extension', full_name='protobuf_unittest.repeated_sfixed32_extension', index=34,
  number=39, type=15, cpp_type=1, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_SFIXED64_EXTENSION_FIELD_NUMBER = 40
repeated_sfixed64_extension = _descriptor.FieldDescriptor(
  name='repeated_sfixed64_extension', full_name='protobuf_unittest.repeated_sfixed64_extension', index=35,
  number=40, type=16, cpp_type=2, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_FLOAT_EXTENSION_FIELD_NUMBER = 41
repeated_float_extension = _descriptor.FieldDescriptor(
  name='repeated_float_extension', full_name='protobuf_unittest.repeated_float_extension', index=36,
  number=41, type=2, cpp_type=6, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_DOUBLE_EXTENSION_FIELD_NUMBER = 42
repeated_double_extension = _descriptor.FieldDescriptor(
  name='repeated_double_extension', full_name='protobuf_unittest.repeated_double_extension', index=37,
  number=42, type=1, cpp_type=5, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_BOOL_EXTENSION_FIELD_NUMBER = 43
repeated_bool_extension = _descriptor.FieldDescriptor(
  name='repeated_bool_extension', full_name='protobuf_unittest.repeated_bool_extension', index=38,
  number=43, type=8, cpp_type=7, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_STRING_EXTENSION_FIELD_NUMBER = 44
repeated_string_extension = _descriptor.FieldDescriptor(
  name='repeated_string_extension', full_name='protobuf_unittest.repeated_string_extension', index=39,
  number=44, type=9, cpp_type=9, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_BYTES_EXTENSION_FIELD_NUMBER = 45
repeated_bytes_extension = _descriptor.FieldDescriptor(
  name='repeated_bytes_extension', full_name='protobuf_unittest.repeated_bytes_extension', index=40,
  number=45, type=12, cpp_type=9, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATEDGROUP_EXTENSION_FIELD_NUMBER = 46
repeatedgroup_extension = _descriptor.FieldDescriptor(
  name='repeatedgroup_extension', full_name='protobuf_unittest.repeatedgroup_extension', index=41,
  number=46, type=10, cpp_type=10, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_NESTED_MESSAGE_EXTENSION_FIELD_NUMBER = 48
repeated_nested_message_extension = _descriptor.FieldDescriptor(
  name='repeated_nested_message_extension', full_name='protobuf_unittest.repeated_nested_message_extension', index=42,
  number=48, type=11, cpp_type=10, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_FOREIGN_MESSAGE_EXTENSION_FIELD_NUMBER = 49
repeated_foreign_message_extension = _descriptor.FieldDescriptor(
  name='repeated_foreign_message_extension', full_name='protobuf_unittest.repeated_foreign_message_extension', index=43,
  number=49, type=11, cpp_type=10, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_IMPORT_MESSAGE_EXTENSION_FIELD_NUMBER = 50
repeated_import_message_extension = _descriptor.FieldDescriptor(
  name='repeated_import_message_extension', full_name='protobuf_unittest.repeated_import_message_extension', index=44,
  number=50, type=11, cpp_type=10, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_NESTED_ENUM_EXTENSION_FIELD_NUMBER = 51
repeated_nested_enum_extension = _descriptor.FieldDescriptor(
  name='repeated_nested_enum_extension', full_name='protobuf_unittest.repeated_nested_enum_extension', index=45,
  number=51, type=14, cpp_type=8, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_FOREIGN_ENUM_EXTENSION_FIELD_NUMBER = 52
repeated_foreign_enum_extension = _descriptor.FieldDescriptor(
  name='repeated_foreign_enum_extension', full_name='protobuf_unittest.repeated_foreign_enum_extension', index=46,
  number=52, type=14, cpp_type=8, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_IMPORT_ENUM_EXTENSION_FIELD_NUMBER = 53
repeated_import_enum_extension = _descriptor.FieldDescriptor(
  name='repeated_import_enum_extension', full_name='protobuf_unittest.repeated_import_enum_extension', index=47,
  number=53, type=14, cpp_type=8, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_STRING_PIECE_EXTENSION_FIELD_NUMBER = 54
repeated_string_piece_extension = _descriptor.FieldDescriptor(
  name='repeated_string_piece_extension', full_name='protobuf_unittest.repeated_string_piece_extension', index=48,
  number=54, type=9, cpp_type=9, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_CORD_EXTENSION_FIELD_NUMBER = 55
repeated_cord_extension = _descriptor.FieldDescriptor(
  name='repeated_cord_extension', full_name='protobuf_unittest.repeated_cord_extension', index=49,
  number=55, type=9, cpp_type=9, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REPEATED_LAZY_MESSAGE_EXTENSION_FIELD_NUMBER = 57
repeated_lazy_message_extension = _descriptor.FieldDescriptor(
  name='repeated_lazy_message_extension', full_name='protobuf_unittest.repeated_lazy_message_extension', index=50,
  number=57, type=11, cpp_type=10, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_INT32_EXTENSION_FIELD_NUMBER = 61
default_int32_extension = _descriptor.FieldDescriptor(
  name='default_int32_extension', full_name='protobuf_unittest.default_int32_extension', index=51,
  number=61, type=5, cpp_type=1, label=1,
  has_default_value=True, default_value=41,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_INT64_EXTENSION_FIELD_NUMBER = 62
default_int64_extension = _descriptor.FieldDescriptor(
  name='default_int64_extension', full_name='protobuf_unittest.default_int64_extension', index=52,
  number=62, type=3, cpp_type=2, label=1,
  has_default_value=True, default_value=42,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_UINT32_EXTENSION_FIELD_NUMBER = 63
default_uint32_extension = _descriptor.FieldDescriptor(
  name='default_uint32_extension', full_name='protobuf_unittest.default_uint32_extension', index=53,
  number=63, type=13, cpp_type=3, label=1,
  has_default_value=True, default_value=43,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_UINT64_EXTENSION_FIELD_NUMBER = 64
default_uint64_extension = _descriptor.FieldDescriptor(
  name='default_uint64_extension', full_name='protobuf_unittest.default_uint64_extension', index=54,
  number=64, type=4, cpp_type=4, label=1,
  has_default_value=True, default_value=44,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_SINT32_EXTENSION_FIELD_NUMBER = 65
default_sint32_extension = _descriptor.FieldDescriptor(
  name='default_sint32_extension', full_name='protobuf_unittest.default_sint32_extension', index=55,
  number=65, type=17, cpp_type=1, label=1,
  has_default_value=True, default_value=-45,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_SINT64_EXTENSION_FIELD_NUMBER = 66
default_sint64_extension = _descriptor.FieldDescriptor(
  name='default_sint64_extension', full_name='protobuf_unittest.default_sint64_extension', index=56,
  number=66, type=18, cpp_type=2, label=1,
  has_default_value=True, default_value=46,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_FIXED32_EXTENSION_FIELD_NUMBER = 67
default_fixed32_extension = _descriptor.FieldDescriptor(
  name='default_fixed32_extension', full_name='protobuf_unittest.default_fixed32_extension', index=57,
  number=67, type=7, cpp_type=3, label=1,
  has_default_value=True, default_value=47,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_FIXED64_EXTENSION_FIELD_NUMBER = 68
default_fixed64_extension = _descriptor.FieldDescriptor(
  name='default_fixed64_extension', full_name='protobuf_unittest.default_fixed64_extension', index=58,
  number=68, type=6, cpp_type=4, label=1,
  has_default_value=True, default_value=48,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_SFIXED32_EXTENSION_FIELD_NUMBER = 69
default_sfixed32_extension = _descriptor.FieldDescriptor(
  name='default_sfixed32_extension', full_name='protobuf_unittest.default_sfixed32_extension', index=59,
  number=69, type=15, cpp_type=1, label=1,
  has_default_value=True, default_value=49,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_SFIXED64_EXTENSION_FIELD_NUMBER = 70
default_sfixed64_extension = _descriptor.FieldDescriptor(
  name='default_sfixed64_extension', full_name='protobuf_unittest.default_sfixed64_extension', index=60,
  number=70, type=16, cpp_type=2, label=1,
  has_default_value=True, default_value=-50,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_FLOAT_EXTENSION_FIELD_NUMBER = 71
default_float_extension = _descriptor.FieldDescriptor(
  name='default_float_extension', full_name='protobuf_unittest.default_float_extension', index=61,
  number=71, type=2, cpp_type=6, label=1,
  has_default_value=True, default_value=float(51.5),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_DOUBLE_EXTENSION_FIELD_NUMBER = 72
default_double_extension = _descriptor.FieldDescriptor(
  name='default_double_extension', full_name='protobuf_unittest.default_double_extension', index=62,
  number=72, type=1, cpp_type=5, label=1,
  has_default_value=True, default_value=float(52000),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_BOOL_EXTENSION_FIELD_NUMBER = 73
default_bool_extension = _descriptor.FieldDescriptor(
  name='default_bool_extension', full_name='protobuf_unittest.default_bool_extension', index=63,
  number=73, type=8, cpp_type=7, label=1,
  has_default_value=True, default_value=True,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_STRING_EXTENSION_FIELD_NUMBER = 74
default_string_extension = _descriptor.FieldDescriptor(
  name='default_string_extension', full_name='protobuf_unittest.default_string_extension', index=64,
  number=74, type=9, cpp_type=9, label=1,
  has_default_value=True, default_value=b"hello".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_BYTES_EXTENSION_FIELD_NUMBER = 75
default_bytes_extension = _descriptor.FieldDescriptor(
  name='default_bytes_extension', full_name='protobuf_unittest.default_bytes_extension', index=65,
  number=75, type=12, cpp_type=9, label=1,
  has_default_value=True, default_value=b"world",
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_NESTED_ENUM_EXTENSION_FIELD_NUMBER = 81
default_nested_enum_extension = _descriptor.FieldDescriptor(
  name='default_nested_enum_extension', full_name='protobuf_unittest.default_nested_enum_extension', index=66,
  number=81, type=14, cpp_type=8, label=1,
  has_default_value=True, default_value=2,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_FOREIGN_ENUM_EXTENSION_FIELD_NUMBER = 82
default_foreign_enum_extension = _descriptor.FieldDescriptor(
  name='default_foreign_enum_extension', full_name='protobuf_unittest.default_foreign_enum_extension', index=67,
  number=82, type=14, cpp_type=8, label=1,
  has_default_value=True, default_value=5,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_IMPORT_ENUM_EXTENSION_FIELD_NUMBER = 83
default_import_enum_extension = _descriptor.FieldDescriptor(
  name='default_import_enum_extension', full_name='protobuf_unittest.default_import_enum_extension', index=68,
  number=83, type=14, cpp_type=8, label=1,
  has_default_value=True, default_value=8,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_STRING_PIECE_EXTENSION_FIELD_NUMBER = 84
default_string_piece_extension = _descriptor.FieldDescriptor(
  name='default_string_piece_extension', full_name='protobuf_unittest.default_string_piece_extension', index=69,
  number=84, type=9, cpp_type=9, label=1,
  has_default_value=True, default_value=b"abc".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DEFAULT_CORD_EXTENSION_FIELD_NUMBER = 85
default_cord_extension = _descriptor.FieldDescriptor(
  name='default_cord_extension', full_name='protobuf_unittest.default_cord_extension', index=70,
  number=85, type=9, cpp_type=9, label=1,
  has_default_value=True, default_value=b"123".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ONEOF_UINT32_EXTENSION_FIELD_NUMBER = 111
oneof_uint32_extension = _descriptor.FieldDescriptor(
  name='oneof_uint32_extension', full_name='protobuf_unittest.oneof_uint32_extension', index=71,
  number=111, type=13, cpp_type=3, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ONEOF_NESTED_MESSAGE_EXTENSION_FIELD_NUMBER = 112
oneof_nested_message_extension = _descriptor.FieldDescriptor(
  name='oneof_nested_message_extension', full_name='protobuf_unittest.oneof_nested_message_extension', index=72,
  number=112, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ONEOF_STRING_EXTENSION_FIELD_NUMBER = 113
oneof_string_extension = _descriptor.FieldDescriptor(
  name='oneof_string_extension', full_name='protobuf_unittest.oneof_string_extension', index=73,
  number=113, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ONEOF_BYTES_EXTENSION_FIELD_NUMBER = 114
oneof_bytes_extension = _descriptor.FieldDescriptor(
  name='oneof_bytes_extension', full_name='protobuf_unittest.oneof_bytes_extension', index=74,
  number=114, type=12, cpp_type=9, label=1,
  has_default_value=False, default_value=b"",
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
MY_EXTENSION_STRING_FIELD_NUMBER = 50
my_extension_string = _descriptor.FieldDescriptor(
  name='my_extension_string', full_name='protobuf_unittest.my_extension_string', index=75,
  number=50, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
MY_EXTENSION_INT_FIELD_NUMBER = 5
my_extension_int = _descriptor.FieldDescriptor(
  name='my_extension_int', full_name='protobuf_unittest.my_extension_int', index=76,
  number=5, type=5, cpp_type=1, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
PACKED_INT32_EXTENSION_FIELD_NUMBER = 90
packed_int32_extension = _descriptor.FieldDescriptor(
  name='packed_int32_extension', full_name='protobuf_unittest.packed_int32_extension', index=77,
  number=90, type=5, cpp_type=1, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
PACKED_INT64_EXTENSION_FIELD_NUMBER = 91
packed_int64_extension = _descriptor.FieldDescriptor(
  name='packed_int64_extension', full_name='protobuf_unittest.packed_int64_extension', index=78,
  number=91, type=3, cpp_type=2, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
PACKED_UINT32_EXTENSION_FIELD_NUMBER = 92
packed_uint32_extension = _descriptor.FieldDescriptor(
  name='packed_uint32_extension', full_name='protobuf_unittest.packed_uint32_extension', index=79,
  number=92, type=13, cpp_type=3, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
PACKED_UINT64_EXTENSION_FIELD_NUMBER = 93
packed_uint64_extension = _descriptor.FieldDescriptor(
  name='packed_uint64_extension', full_name='protobuf_unittest.packed_uint64_extension', index=80,
  number=93, type=4, cpp_type=4, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
PACKED_SINT32_EXTENSION_FIELD_NUMBER = 94
packed_sint32_extension = _descriptor.FieldDescriptor(
  name='packed_sint32_extension', full_name='protobuf_unittest.packed_sint32_extension', index=81,
  number=94, type=17, cpp_type=1, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
PACKED_SINT64_EXTENSION_FIELD_NUMBER = 95
packed_sint64_extension = _descriptor.FieldDescriptor(
  name='packed_sint64_extension', full_name='protobuf_unittest.packed_sint64_extension', index=82,
  number=95, type=18, cpp_type=2, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
PACKED_FIXED32_EXTENSION_FIELD_NUMBER = 96
packed_fixed32_extension = _descriptor.FieldDescriptor(
  name='packed_fixed32_extension', full_name='protobuf_unittest.packed_fixed32_extension', index=83,
  number=96, type=7, cpp_type=3, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
PACKED_FIXED64_EXTENSION_FIELD_NUMBER = 97
packed_fixed64_extension = _descriptor.FieldDescriptor(
  name='packed_fixed64_extension', full_name='protobuf_unittest.packed_fixed64_extension', index=84,
  number=97, type=6, cpp_type=4, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
PACKED_SFIXED32_EXTENSION_FIELD_NUMBER = 98
packed_sfixed32_extension = _descriptor.FieldDescriptor(
  name='packed_sfixed32_extension', full_name='protobuf_unittest.packed_sfixed32_extension', index=85,
  number=98, type=15, cpp_type=1, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
PACKED_SFIXED64_EXTENSION_FIELD_NUMBER = 99
packed_sfixed64_extension = _descriptor.FieldDescriptor(
  name='packed_sfixed64_extension', full_name='protobuf_unittest.packed_sfixed64_extension', index=86,
  number=99, type=16, cpp_type=2, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
PACKED_FLOAT_EXTENSION_FIELD_NUMBER = 100
packed_float_extension = _descriptor.FieldDescriptor(
  name='packed_float_extension', full_name='protobuf_unittest.packed_float_extension', index=87,
  number=100, type=2, cpp_type=6, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
PACKED_DOUBLE_EXTENSION_FIELD_NUMBER = 101
packed_double_extension = _descriptor.FieldDescriptor(
  name='packed_double_extension', full_name='protobuf_unittest.packed_double_extension', index=88,
  number=101, type=1, cpp_type=5, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
PACKED_BOOL_EXTENSION_FIELD_NUMBER = 102
packed_bool_extension = _descriptor.FieldDescriptor(
  name='packed_bool_extension', full_name='protobuf_unittest.packed_bool_extension', index=89,
  number=102, type=8, cpp_type=7, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
PACKED_ENUM_EXTENSION_FIELD_NUMBER = 103
packed_enum_extension = _descriptor.FieldDescriptor(
  name='packed_enum_extension', full_name='protobuf_unittest.packed_enum_extension', index=90,
  number=103, type=14, cpp_type=8, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNPACKED_INT32_EXTENSION_FIELD_NUMBER = 90
unpacked_int32_extension = _descriptor.FieldDescriptor(
  name='unpacked_int32_extension', full_name='protobuf_unittest.unpacked_int32_extension', index=91,
  number=90, type=5, cpp_type=1, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNPACKED_INT64_EXTENSION_FIELD_NUMBER = 91
unpacked_int64_extension = _descriptor.FieldDescriptor(
  name='unpacked_int64_extension', full_name='protobuf_unittest.unpacked_int64_extension', index=92,
  number=91, type=3, cpp_type=2, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNPACKED_UINT32_EXTENSION_FIELD_NUMBER = 92
unpacked_uint32_extension = _descriptor.FieldDescriptor(
  name='unpacked_uint32_extension', full_name='protobuf_unittest.unpacked_uint32_extension', index=93,
  number=92, type=13, cpp_type=3, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNPACKED_UINT64_EXTENSION_FIELD_NUMBER = 93
unpacked_uint64_extension = _descriptor.FieldDescriptor(
  name='unpacked_uint64_extension', full_name='protobuf_unittest.unpacked_uint64_extension', index=94,
  number=93, type=4, cpp_type=4, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNPACKED_SINT32_EXTENSION_FIELD_NUMBER = 94
unpacked_sint32_extension = _descriptor.FieldDescriptor(
  name='unpacked_sint32_extension', full_name='protobuf_unittest.unpacked_sint32_extension', index=95,
  number=94, type=17, cpp_type=1, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNPACKED_SINT64_EXTENSION_FIELD_NUMBER = 95
unpacked_sint64_extension = _descriptor.FieldDescriptor(
  name='unpacked_sint64_extension', full_name='protobuf_unittest.unpacked_sint64_extension', index=96,
  number=95, type=18, cpp_type=2, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNPACKED_FIXED32_EXTENSION_FIELD_NUMBER = 96
unpacked_fixed32_extension = _descriptor.FieldDescriptor(
  name='unpacked_fixed32_extension', full_name='protobuf_unittest.unpacked_fixed32_extension', index=97,
  number=96, type=7, cpp_type=3, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNPACKED_FIXED64_EXTENSION_FIELD_NUMBER = 97
unpacked_fixed64_extension = _descriptor.FieldDescriptor(
  name='unpacked_fixed64_extension', full_name='protobuf_unittest.unpacked_fixed64_extension', index=98,
  number=97, type=6, cpp_type=4, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNPACKED_SFIXED32_EXTENSION_FIELD_NUMBER = 98
unpacked_sfixed32_extension = _descriptor.FieldDescriptor(
  name='unpacked_sfixed32_extension', full_name='protobuf_unittest.unpacked_sfixed32_extension', index=99,
  number=98, type=15, cpp_type=1, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNPACKED_SFIXED64_EXTENSION_FIELD_NUMBER = 99
unpacked_sfixed64_extension = _descriptor.FieldDescriptor(
  name='unpacked_sfixed64_extension', full_name='protobuf_unittest.unpacked_sfixed64_extension', index=100,
  number=99, type=16, cpp_type=2, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNPACKED_FLOAT_EXTENSION_FIELD_NUMBER = 100
unpacked_float_extension = _descriptor.FieldDescriptor(
  name='unpacked_float_extension', full_name='protobuf_unittest.unpacked_float_extension', index=101,
  number=100, type=2, cpp_type=6, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNPACKED_DOUBLE_EXTENSION_FIELD_NUMBER = 101
unpacked_double_extension = _descriptor.FieldDescriptor(
  name='unpacked_double_extension', full_name='protobuf_unittest.unpacked_double_extension', index=102,
  number=101, type=1, cpp_type=5, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNPACKED_BOOL_EXTENSION_FIELD_NUMBER = 102
unpacked_bool_extension = _descriptor.FieldDescriptor(
  name='unpacked_bool_extension', full_name='protobuf_unittest.unpacked_bool_extension', index=103,
  number=102, type=8, cpp_type=7, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNPACKED_ENUM_EXTENSION_FIELD_NUMBER = 103
unpacked_enum_extension = _descriptor.FieldDescriptor(
  name='unpacked_enum_extension', full_name='protobuf_unittest.unpacked_enum_extension', index=104,
  number=103, type=14, cpp_type=8, label=3,
  has_default_value=False, default_value=[],
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
TEST_ALL_TYPES_FIELD_NUMBER = 536860000
test_all_types = _descriptor.FieldDescriptor(
  name='test_all_types', full_name='protobuf_unittest.test_all_types', index=105,
  number=536860000, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
TEST_EXTENSION_INSIDE_TABLE_EXTENSION_FIELD_NUMBER = 5
test_extension_inside_table_extension = _descriptor.FieldDescriptor(
  name='test_extension_inside_table_extension', full_name='protobuf_unittest.test_extension_inside_table_extension', index=106,
  number=5, type=5, cpp_type=1, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)

_TESTALLTYPES_NESTEDENUM = _descriptor.EnumDescriptor(
  name='NestedEnum',
  full_name='protobuf_unittest.TestAllTypes.NestedEnum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FOO', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAR', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAZ', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEG', index=3, number=-1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3202,
  serialized_end=3259,
)
_sym_db.RegisterEnumDescriptor(_TESTALLTYPES_NESTEDENUM)

_TESTONEOF2_NESTEDENUM = _descriptor.EnumDescriptor(
  name='NestedEnum',
  full_name='protobuf_unittest.TestOneof2.NestedEnum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FOO', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAR', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAZ', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3202,
  serialized_end=3241,
)
_sym_db.RegisterEnumDescriptor(_TESTONEOF2_NESTEDENUM)

_TESTDYNAMICEXTENSIONS_DYNAMICENUMTYPE = _descriptor.EnumDescriptor(
  name='DynamicEnumType',
  full_name='protobuf_unittest.TestDynamicExtensions.DynamicEnumType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_FOO', index=0, number=2200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_BAR', index=1, number=2201,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_BAZ', index=2, number=2202,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12590,
  serialized_end=12661,
)
_sym_db.RegisterEnumDescriptor(_TESTDYNAMICEXTENSIONS_DYNAMICENUMTYPE)


_TESTALLTYPES_NESTEDMESSAGE = _descriptor.Descriptor(
  name='NestedMessage',
  full_name='protobuf_unittest.TestAllTypes.NestedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bb', full_name='protobuf_unittest.TestAllTypes.NestedMessage.bb', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3117,
  serialized_end=3144,
)

_TESTALLTYPES_OPTIONALGROUP = _descriptor.Descriptor(
  name='OptionalGroup',
  full_name='protobuf_unittest.TestAllTypes.OptionalGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='protobuf_unittest.TestAllTypes.OptionalGroup.a', index=0,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3146,
  serialized_end=3172,
)

_TESTALLTYPES_REPEATEDGROUP = _descriptor.Descriptor(
  name='RepeatedGroup',
  full_name='protobuf_unittest.TestAllTypes.RepeatedGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='protobuf_unittest.TestAllTypes.RepeatedGroup.a', index=0,
      number=47, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3174,
  serialized_end=3200,
)

_TESTALLTYPES = _descriptor.Descriptor(
  name='TestAllTypes',
  full_name='protobuf_unittest.TestAllTypes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='optional_int32', full_name='protobuf_unittest.TestAllTypes.optional_int32', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_int64', full_name='protobuf_unittest.TestAllTypes.optional_int64', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_uint32', full_name='protobuf_unittest.TestAllTypes.optional_uint32', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_uint64', full_name='protobuf_unittest.TestAllTypes.optional_uint64', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_sint32', full_name='protobuf_unittest.TestAllTypes.optional_sint32', index=4,
      number=5, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_sint64', full_name='protobuf_unittest.TestAllTypes.optional_sint64', index=5,
      number=6, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_fixed32', full_name='protobuf_unittest.TestAllTypes.optional_fixed32', index=6,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_fixed64', full_name='protobuf_unittest.TestAllTypes.optional_fixed64', index=7,
      number=8, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_sfixed32', full_name='protobuf_unittest.TestAllTypes.optional_sfixed32', index=8,
      number=9, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_sfixed64', full_name='protobuf_unittest.TestAllTypes.optional_sfixed64', index=9,
      number=10, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_float', full_name='protobuf_unittest.TestAllTypes.optional_float', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_double', full_name='protobuf_unittest.TestAllTypes.optional_double', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_bool', full_name='protobuf_unittest.TestAllTypes.optional_bool', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_string', full_name='protobuf_unittest.TestAllTypes.optional_string', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_bytes', full_name='protobuf_unittest.TestAllTypes.optional_bytes', index=14,
      number=15, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optionalgroup', full_name='protobuf_unittest.TestAllTypes.optionalgroup', index=15,
      number=16, type=10, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_nested_message', full_name='protobuf_unittest.TestAllTypes.optional_nested_message', index=16,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_foreign_message', full_name='protobuf_unittest.TestAllTypes.optional_foreign_message', index=17,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_import_message', full_name='protobuf_unittest.TestAllTypes.optional_import_message', index=18,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_nested_enum', full_name='protobuf_unittest.TestAllTypes.optional_nested_enum', index=19,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_foreign_enum', full_name='protobuf_unittest.TestAllTypes.optional_foreign_enum', index=20,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=4,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_import_enum', full_name='protobuf_unittest.TestAllTypes.optional_import_enum', index=21,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=7,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_string_piece', full_name='protobuf_unittest.TestAllTypes.optional_string_piece', index=22,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_cord', full_name='protobuf_unittest.TestAllTypes.optional_cord', index=23,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_public_import_message', full_name='protobuf_unittest.TestAllTypes.optional_public_import_message', index=24,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_lazy_message', full_name='protobuf_unittest.TestAllTypes.optional_lazy_message', index=25,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_int32', full_name='protobuf_unittest.TestAllTypes.repeated_int32', index=26,
      number=31, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_int64', full_name='protobuf_unittest.TestAllTypes.repeated_int64', index=27,
      number=32, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_uint32', full_name='protobuf_unittest.TestAllTypes.repeated_uint32', index=28,
      number=33, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_uint64', full_name='protobuf_unittest.TestAllTypes.repeated_uint64', index=29,
      number=34, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_sint32', full_name='protobuf_unittest.TestAllTypes.repeated_sint32', index=30,
      number=35, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_sint64', full_name='protobuf_unittest.TestAllTypes.repeated_sint64', index=31,
      number=36, type=18, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_fixed32', full_name='protobuf_unittest.TestAllTypes.repeated_fixed32', index=32,
      number=37, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_fixed64', full_name='protobuf_unittest.TestAllTypes.repeated_fixed64', index=33,
      number=38, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_sfixed32', full_name='protobuf_unittest.TestAllTypes.repeated_sfixed32', index=34,
      number=39, type=15, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_sfixed64', full_name='protobuf_unittest.TestAllTypes.repeated_sfixed64', index=35,
      number=40, type=16, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_float', full_name='protobuf_unittest.TestAllTypes.repeated_float', index=36,
      number=41, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_double', full_name='protobuf_unittest.TestAllTypes.repeated_double', index=37,
      number=42, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_bool', full_name='protobuf_unittest.TestAllTypes.repeated_bool', index=38,
      number=43, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_string', full_name='protobuf_unittest.TestAllTypes.repeated_string', index=39,
      number=44, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_bytes', full_name='protobuf_unittest.TestAllTypes.repeated_bytes', index=40,
      number=45, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeatedgroup', full_name='protobuf_unittest.TestAllTypes.repeatedgroup', index=41,
      number=46, type=10, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_nested_message', full_name='protobuf_unittest.TestAllTypes.repeated_nested_message', index=42,
      number=48, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_foreign_message', full_name='protobuf_unittest.TestAllTypes.repeated_foreign_message', index=43,
      number=49, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_import_message', full_name='protobuf_unittest.TestAllTypes.repeated_import_message', index=44,
      number=50, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_nested_enum', full_name='protobuf_unittest.TestAllTypes.repeated_nested_enum', index=45,
      number=51, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_foreign_enum', full_name='protobuf_unittest.TestAllTypes.repeated_foreign_enum', index=46,
      number=52, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_import_enum', full_name='protobuf_unittest.TestAllTypes.repeated_import_enum', index=47,
      number=53, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_string_piece', full_name='protobuf_unittest.TestAllTypes.repeated_string_piece', index=48,
      number=54, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_cord', full_name='protobuf_unittest.TestAllTypes.repeated_cord', index=49,
      number=55, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_lazy_message', full_name='protobuf_unittest.TestAllTypes.repeated_lazy_message', index=50,
      number=57, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_int32', full_name='protobuf_unittest.TestAllTypes.default_int32', index=51,
      number=61, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=41,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_int64', full_name='protobuf_unittest.TestAllTypes.default_int64', index=52,
      number=62, type=3, cpp_type=2, label=1,
      has_default_value=True, default_value=42,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_uint32', full_name='protobuf_unittest.TestAllTypes.default_uint32', index=53,
      number=63, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=43,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_uint64', full_name='protobuf_unittest.TestAllTypes.default_uint64', index=54,
      number=64, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=44,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_sint32', full_name='protobuf_unittest.TestAllTypes.default_sint32', index=55,
      number=65, type=17, cpp_type=1, label=1,
      has_default_value=True, default_value=-45,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_sint64', full_name='protobuf_unittest.TestAllTypes.default_sint64', index=56,
      number=66, type=18, cpp_type=2, label=1,
      has_default_value=True, default_value=46,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_fixed32', full_name='protobuf_unittest.TestAllTypes.default_fixed32', index=57,
      number=67, type=7, cpp_type=3, label=1,
      has_default_value=True, default_value=47,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_fixed64', full_name='protobuf_unittest.TestAllTypes.default_fixed64', index=58,
      number=68, type=6, cpp_type=4, label=1,
      has_default_value=True, default_value=48,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_sfixed32', full_name='protobuf_unittest.TestAllTypes.default_sfixed32', index=59,
      number=69, type=15, cpp_type=1, label=1,
      has_default_value=True, default_value=49,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_sfixed64', full_name='protobuf_unittest.TestAllTypes.default_sfixed64', index=60,
      number=70, type=16, cpp_type=2, label=1,
      has_default_value=True, default_value=-50,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_float', full_name='protobuf_unittest.TestAllTypes.default_float', index=61,
      number=71, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(51.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_double', full_name='protobuf_unittest.TestAllTypes.default_double', index=62,
      number=72, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(52000),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_bool', full_name='protobuf_unittest.TestAllTypes.default_bool', index=63,
      number=73, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_string', full_name='protobuf_unittest.TestAllTypes.default_string', index=64,
      number=74, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"hello".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_bytes', full_name='protobuf_unittest.TestAllTypes.default_bytes', index=65,
      number=75, type=12, cpp_type=9, label=1,
      has_default_value=True, default_value=b"world",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_nested_enum', full_name='protobuf_unittest.TestAllTypes.default_nested_enum', index=66,
      number=81, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_foreign_enum', full_name='protobuf_unittest.TestAllTypes.default_foreign_enum', index=67,
      number=82, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=5,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_import_enum', full_name='protobuf_unittest.TestAllTypes.default_import_enum', index=68,
      number=83, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=8,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_string_piece', full_name='protobuf_unittest.TestAllTypes.default_string_piece', index=69,
      number=84, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"abc".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_cord', full_name='protobuf_unittest.TestAllTypes.default_cord', index=70,
      number=85, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"123".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oneof_uint32', full_name='protobuf_unittest.TestAllTypes.oneof_uint32', index=71,
      number=111, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oneof_nested_message', full_name='protobuf_unittest.TestAllTypes.oneof_nested_message', index=72,
      number=112, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oneof_string', full_name='protobuf_unittest.TestAllTypes.oneof_string', index=73,
      number=113, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oneof_bytes', full_name='protobuf_unittest.TestAllTypes.oneof_bytes', index=74,
      number=114, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TESTALLTYPES_NESTEDMESSAGE, _TESTALLTYPES_OPTIONALGROUP, _TESTALLTYPES_REPEATEDGROUP, ],
  enum_types=[
    _TESTALLTYPES_NESTEDENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_field', full_name='protobuf_unittest.TestAllTypes.oneof_field',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=93,
  serialized_end=3274,
)


_NESTEDTESTALLTYPES = _descriptor.Descriptor(
  name='NestedTestAllTypes',
  full_name='protobuf_unittest.NestedTestAllTypes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='child', full_name='protobuf_unittest.NestedTestAllTypes.child', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='protobuf_unittest.NestedTestAllTypes.payload', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_child', full_name='protobuf_unittest.NestedTestAllTypes.repeated_child', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3277,
  serialized_end=3464,
)


_TESTDEPRECATEDFIELDS = _descriptor.Descriptor(
  name='TestDeprecatedFields',
  full_name='protobuf_unittest.TestDeprecatedFields',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deprecated_int32', full_name='protobuf_unittest.TestDeprecatedFields.deprecated_int32', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_int32_in_oneof', full_name='protobuf_unittest.TestDeprecatedFields.deprecated_int32_in_oneof', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_fields', full_name='protobuf_unittest.TestDeprecatedFields.oneof_fields',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3466,
  serialized_end=3575,
)


_TESTDEPRECATEDMESSAGE = _descriptor.Descriptor(
  name='TestDeprecatedMessage',
  full_name='protobuf_unittest.TestDeprecatedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\030\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3577,
  serialized_end=3604,
)


_FOREIGNMESSAGE = _descriptor.Descriptor(
  name='ForeignMessage',
  full_name='protobuf_unittest.ForeignMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='c', full_name='protobuf_unittest.ForeignMessage.c', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d', full_name='protobuf_unittest.ForeignMessage.d', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3606,
  serialized_end=3644,
)


_TESTRESERVEDFIELDS = _descriptor.Descriptor(
  name='TestReservedFields',
  full_name='protobuf_unittest.TestReservedFields',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3646,
  serialized_end=3694,
)


_TESTALLEXTENSIONS = _descriptor.Descriptor(
  name='TestAllExtensions',
  full_name='protobuf_unittest.TestAllExtensions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1, 536870912), ],
  oneofs=[
  ],
  serialized_start=3696,
  serialized_end=3725,
)


_OPTIONALGROUP_EXTENSION = _descriptor.Descriptor(
  name='OptionalGroup_extension',
  full_name='protobuf_unittest.OptionalGroup_extension',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='protobuf_unittest.OptionalGroup_extension.a', index=0,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3727,
  serialized_end=3763,
)


_REPEATEDGROUP_EXTENSION = _descriptor.Descriptor(
  name='RepeatedGroup_extension',
  full_name='protobuf_unittest.RepeatedGroup_extension',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='protobuf_unittest.RepeatedGroup_extension.a', index=0,
      number=47, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3765,
  serialized_end=3801,
)


_TESTGROUP_OPTIONALGROUP = _descriptor.Descriptor(
  name='OptionalGroup',
  full_name='protobuf_unittest.TestGroup.OptionalGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='protobuf_unittest.TestGroup.OptionalGroup.a', index=0,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3146,
  serialized_end=3172,
)

_TESTGROUP = _descriptor.Descriptor(
  name='TestGroup',
  full_name='protobuf_unittest.TestGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='optionalgroup', full_name='protobuf_unittest.TestGroup.optionalgroup', index=0,
      number=16, type=10, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_foreign_enum', full_name='protobuf_unittest.TestGroup.optional_foreign_enum', index=1,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=4,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TESTGROUP_OPTIONALGROUP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3804,
  serialized_end=3973,
)


_TESTGROUPEXTENSION = _descriptor.Descriptor(
  name='TestGroupExtension',
  full_name='protobuf_unittest.TestGroupExtension',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1, 536870912), ],
  oneofs=[
  ],
  serialized_start=3975,
  serialized_end=4005,
)


_TESTNESTEDEXTENSION_OPTIONALGROUP_EXTENSION = _descriptor.Descriptor(
  name='OptionalGroup_extension',
  full_name='protobuf_unittest.TestNestedExtension.OptionalGroup_extension',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='protobuf_unittest.TestNestedExtension.OptionalGroup_extension.a', index=0,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3727,
  serialized_end=3763,
)

_TESTNESTEDEXTENSION = _descriptor.Descriptor(
  name='TestNestedExtension',
  full_name='protobuf_unittest.TestNestedExtension',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='test', full_name='protobuf_unittest.TestNestedExtension.test', index=0,
      number=1002, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"test".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nested_string_extension', full_name='protobuf_unittest.TestNestedExtension.nested_string_extension', index=1,
      number=1003, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optionalgroup_extension', full_name='protobuf_unittest.TestNestedExtension.optionalgroup_extension', index=2,
      number=16, type=10, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_foreign_enum_extension', full_name='protobuf_unittest.TestNestedExtension.optional_foreign_enum_extension', index=3,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=4,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  nested_types=[_TESTNESTEDEXTENSION_OPTIONALGROUP_EXTENSION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4008,
  serialized_end=4447,
)


_TESTREQUIRED = _descriptor.Descriptor(
  name='TestRequired',
  full_name='protobuf_unittest.TestRequired',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='protobuf_unittest.TestRequired.a', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy2', full_name='protobuf_unittest.TestRequired.dummy2', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b', full_name='protobuf_unittest.TestRequired.b', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy4', full_name='protobuf_unittest.TestRequired.dummy4', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy5', full_name='protobuf_unittest.TestRequired.dummy5', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy6', full_name='protobuf_unittest.TestRequired.dummy6', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy7', full_name='protobuf_unittest.TestRequired.dummy7', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy8', full_name='protobuf_unittest.TestRequired.dummy8', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy9', full_name='protobuf_unittest.TestRequired.dummy9', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy10', full_name='protobuf_unittest.TestRequired.dummy10', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy11', full_name='protobuf_unittest.TestRequired.dummy11', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy12', full_name='protobuf_unittest.TestRequired.dummy12', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy13', full_name='protobuf_unittest.TestRequired.dummy13', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy14', full_name='protobuf_unittest.TestRequired.dummy14', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy15', full_name='protobuf_unittest.TestRequired.dummy15', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy16', full_name='protobuf_unittest.TestRequired.dummy16', index=15,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy17', full_name='protobuf_unittest.TestRequired.dummy17', index=16,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy18', full_name='protobuf_unittest.TestRequired.dummy18', index=17,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy19', full_name='protobuf_unittest.TestRequired.dummy19', index=18,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy20', full_name='protobuf_unittest.TestRequired.dummy20', index=19,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy21', full_name='protobuf_unittest.TestRequired.dummy21', index=20,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy22', full_name='protobuf_unittest.TestRequired.dummy22', index=21,
      number=22, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy23', full_name='protobuf_unittest.TestRequired.dummy23', index=22,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy24', full_name='protobuf_unittest.TestRequired.dummy24', index=23,
      number=24, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy25', full_name='protobuf_unittest.TestRequired.dummy25', index=24,
      number=25, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy26', full_name='protobuf_unittest.TestRequired.dummy26', index=25,
      number=26, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy27', full_name='protobuf_unittest.TestRequired.dummy27', index=26,
      number=27, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy28', full_name='protobuf_unittest.TestRequired.dummy28', index=27,
      number=28, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy29', full_name='protobuf_unittest.TestRequired.dummy29', index=28,
      number=29, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy30', full_name='protobuf_unittest.TestRequired.dummy30', index=29,
      number=30, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy31', full_name='protobuf_unittest.TestRequired.dummy31', index=30,
      number=31, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy32', full_name='protobuf_unittest.TestRequired.dummy32', index=31,
      number=32, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c', full_name='protobuf_unittest.TestRequired.c', index=32,
      number=33, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='single', full_name='protobuf_unittest.TestRequired.single', index=0,
      number=1000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multi', full_name='protobuf_unittest.TestRequired.multi', index=1,
      number=1001, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4450,
  serialized_end=5175,
)


_TESTREQUIREDFOREIGN = _descriptor.Descriptor(
  name='TestRequiredForeign',
  full_name='protobuf_unittest.TestRequiredForeign',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='optional_message', full_name='protobuf_unittest.TestRequiredForeign.optional_message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_message', full_name='protobuf_unittest.TestRequiredForeign.repeated_message', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dummy', full_name='protobuf_unittest.TestRequiredForeign.dummy', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5178,
  serialized_end=5332,
)


_TESTREQUIREDMESSAGE = _descriptor.Descriptor(
  name='TestRequiredMessage',
  full_name='protobuf_unittest.TestRequiredMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='optional_message', full_name='protobuf_unittest.TestRequiredMessage.optional_message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_message', full_name='protobuf_unittest.TestRequiredMessage.repeated_message', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required_message', full_name='protobuf_unittest.TestRequiredMessage.required_message', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5335,
  serialized_end=5533,
)


_TESTFOREIGNNESTED = _descriptor.Descriptor(
  name='TestForeignNested',
  full_name='protobuf_unittest.TestForeignNested',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='foreign_nested', full_name='protobuf_unittest.TestForeignNested.foreign_nested', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5535,
  serialized_end=5625,
)


_TESTEMPTYMESSAGE = _descriptor.Descriptor(
  name='TestEmptyMessage',
  full_name='protobuf_unittest.TestEmptyMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5627,
  serialized_end=5645,
)


_TESTEMPTYMESSAGEWITHEXTENSIONS = _descriptor.Descriptor(
  name='TestEmptyMessageWithExtensions',
  full_name='protobuf_unittest.TestEmptyMessageWithExtensions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1, 536870912), ],
  oneofs=[
  ],
  serialized_start=5647,
  serialized_end=5689,
)


_TESTPICKLENESTEDMESSAGE_NESTEDMESSAGE_NESTEDNESTEDMESSAGE = _descriptor.Descriptor(
  name='NestedNestedMessage',
  full_name='protobuf_unittest.TestPickleNestedMessage.NestedMessage.NestedNestedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cc', full_name='protobuf_unittest.TestPickleNestedMessage.NestedMessage.NestedNestedMessage.cc', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5747,
  serialized_end=5780,
)

_TESTPICKLENESTEDMESSAGE_NESTEDMESSAGE = _descriptor.Descriptor(
  name='NestedMessage',
  full_name='protobuf_unittest.TestPickleNestedMessage.NestedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bb', full_name='protobuf_unittest.TestPickleNestedMessage.NestedMessage.bb', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TESTPICKLENESTEDMESSAGE_NESTEDMESSAGE_NESTEDNESTEDMESSAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5718,
  serialized_end=5780,
)

_TESTPICKLENESTEDMESSAGE = _descriptor.Descriptor(
  name='TestPickleNestedMessage',
  full_name='protobuf_unittest.TestPickleNestedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_TESTPICKLENESTEDMESSAGE_NESTEDMESSAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5691,
  serialized_end=5780,
)


_TESTMULTIPLEEXTENSIONRANGES = _descriptor.Descriptor(
  name='TestMultipleExtensionRanges',
  full_name='protobuf_unittest.TestMultipleExtensionRanges',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(42, 43), (4143, 4244), (65536, 536870912), ],
  oneofs=[
  ],
  serialized_start=5782,
  serialized_end=5837,
)


_TESTREALLYLARGETAGNUMBER = _descriptor.Descriptor(
  name='TestReallyLargeTagNumber',
  full_name='protobuf_unittest.TestReallyLargeTagNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='protobuf_unittest.TestReallyLargeTagNumber.a', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bb', full_name='protobuf_unittest.TestReallyLargeTagNumber.bb', index=1,
      number=268435455, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5839,
  serialized_end=5891,
)


_TESTRECURSIVEMESSAGE = _descriptor.Descriptor(
  name='TestRecursiveMessage',
  full_name='protobuf_unittest.TestRecursiveMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='protobuf_unittest.TestRecursiveMessage.a', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i', full_name='protobuf_unittest.TestRecursiveMessage.i', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5893,
  serialized_end=5978,
)


_TESTMUTUALRECURSIONA_SUBMESSAGE = _descriptor.Descriptor(
  name='SubMessage',
  full_name='protobuf_unittest.TestMutualRecursionA.SubMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='b', full_name='protobuf_unittest.TestMutualRecursionA.SubMessage.b', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6126,
  serialized_end=6190,
)

_TESTMUTUALRECURSIONA_SUBGROUP = _descriptor.Descriptor(
  name='SubGroup',
  full_name='protobuf_unittest.TestMutualRecursionA.SubGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sub_message', full_name='protobuf_unittest.TestMutualRecursionA.SubGroup.sub_message', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='not_in_this_scc', full_name='protobuf_unittest.TestMutualRecursionA.SubGroup.not_in_this_scc', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6193,
  serialized_end=6334,
)

_TESTMUTUALRECURSIONA = _descriptor.Descriptor(
  name='TestMutualRecursionA',
  full_name='protobuf_unittest.TestMutualRecursionA',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bb', full_name='protobuf_unittest.TestMutualRecursionA.bb', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subgroup', full_name='protobuf_unittest.TestMutualRecursionA.subgroup', index=1,
      number=2, type=10, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TESTMUTUALRECURSIONA_SUBMESSAGE, _TESTMUTUALRECURSIONA_SUBGROUP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5981,
  serialized_end=6334,
)


_TESTMUTUALRECURSIONB = _descriptor.Descriptor(
  name='TestMutualRecursionB',
  full_name='protobuf_unittest.TestMutualRecursionB',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='protobuf_unittest.TestMutualRecursionB.a', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_int32', full_name='protobuf_unittest.TestMutualRecursionB.optional_int32', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6336,
  serialized_end=6434,
)


_TESTISINITIALIZED_SUBMESSAGE_SUBGROUP = _descriptor.Descriptor(
  name='SubGroup',
  full_name='protobuf_unittest.TestIsInitialized.SubMessage.SubGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='i', full_name='protobuf_unittest.TestIsInitialized.SubMessage.SubGroup.i', index=0,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6618,
  serialized_end=6639,
)

_TESTISINITIALIZED_SUBMESSAGE = _descriptor.Descriptor(
  name='SubMessage',
  full_name='protobuf_unittest.TestIsInitialized.SubMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subgroup', full_name='protobuf_unittest.TestIsInitialized.SubMessage.subgroup', index=0,
      number=1, type=10, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TESTISINITIALIZED_SUBMESSAGE_SUBGROUP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6528,
  serialized_end=6639,
)

_TESTISINITIALIZED = _descriptor.Descriptor(
  name='TestIsInitialized',
  full_name='protobuf_unittest.TestIsInitialized',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sub_message', full_name='protobuf_unittest.TestIsInitialized.sub_message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TESTISINITIALIZED_SUBMESSAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6437,
  serialized_end=6639,
)


_TESTDUPFIELDNUMBER_FOO = _descriptor.Descriptor(
  name='Foo',
  full_name='protobuf_unittest.TestDupFieldNumber.Foo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='protobuf_unittest.TestDupFieldNumber.Foo.a', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6787,
  serialized_end=6803,
)

_TESTDUPFIELDNUMBER_BAR = _descriptor.Descriptor(
  name='Bar',
  full_name='protobuf_unittest.TestDupFieldNumber.Bar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='protobuf_unittest.TestDupFieldNumber.Bar.a', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6805,
  serialized_end=6821,
)

_TESTDUPFIELDNUMBER = _descriptor.Descriptor(
  name='TestDupFieldNumber',
  full_name='protobuf_unittest.TestDupFieldNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='protobuf_unittest.TestDupFieldNumber.a', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foo', full_name='protobuf_unittest.TestDupFieldNumber.foo', index=1,
      number=2, type=10, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bar', full_name='protobuf_unittest.TestDupFieldNumber.bar', index=2,
      number=3, type=10, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TESTDUPFIELDNUMBER_FOO, _TESTDUPFIELDNUMBER_BAR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6642,
  serialized_end=6821,
)


_TESTEAGERMESSAGE = _descriptor.Descriptor(
  name='TestEagerMessage',
  full_name='protobuf_unittest.TestEagerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sub_message', full_name='protobuf_unittest.TestEagerMessage.sub_message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'(\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6823,
  serialized_end=6899,
)


_TESTLAZYMESSAGE = _descriptor.Descriptor(
  name='TestLazyMessage',
  full_name='protobuf_unittest.TestLazyMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sub_message', full_name='protobuf_unittest.TestLazyMessage.sub_message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6901,
  serialized_end=6976,
)


_TESTNESTEDMESSAGEHASBITS_NESTEDMESSAGE = _descriptor.Descriptor(
  name='NestedMessage',
  full_name='protobuf_unittest.TestNestedMessageHasBits.NestedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nestedmessage_repeated_int32', full_name='protobuf_unittest.TestNestedMessageHasBits.NestedMessage.nestedmessage_repeated_int32', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nestedmessage_repeated_foreignmessage', full_name='protobuf_unittest.TestNestedMessageHasBits.NestedMessage.nestedmessage_repeated_foreignmessage', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7100,
  serialized_end=7235,
)

_TESTNESTEDMESSAGEHASBITS = _descriptor.Descriptor(
  name='TestNestedMessageHasBits',
  full_name='protobuf_unittest.TestNestedMessageHasBits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='optional_nested_message', full_name='protobuf_unittest.TestNestedMessageHasBits.optional_nested_message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TESTNESTEDMESSAGEHASBITS_NESTEDMESSAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6979,
  serialized_end=7235,
)


_TESTCAMELCASEFIELDNAMES = _descriptor.Descriptor(
  name='TestCamelCaseFieldNames',
  full_name='protobuf_unittest.TestCamelCaseFieldNames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='PrimitiveField', full_name='protobuf_unittest.TestCamelCaseFieldNames.PrimitiveField', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='StringField', full_name='protobuf_unittest.TestCamelCaseFieldNames.StringField', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='EnumField', full_name='protobuf_unittest.TestCamelCaseFieldNames.EnumField', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=4,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='MessageField', full_name='protobuf_unittest.TestCamelCaseFieldNames.MessageField', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='StringPieceField', full_name='protobuf_unittest.TestCamelCaseFieldNames.StringPieceField', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='CordField', full_name='protobuf_unittest.TestCamelCaseFieldNames.CordField', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RepeatedPrimitiveField', full_name='protobuf_unittest.TestCamelCaseFieldNames.RepeatedPrimitiveField', index=6,
      number=7, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RepeatedStringField', full_name='protobuf_unittest.TestCamelCaseFieldNames.RepeatedStringField', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RepeatedEnumField', full_name='protobuf_unittest.TestCamelCaseFieldNames.RepeatedEnumField', index=8,
      number=9, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RepeatedMessageField', full_name='protobuf_unittest.TestCamelCaseFieldNames.RepeatedMessageField', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RepeatedStringPieceField', full_name='protobuf_unittest.TestCamelCaseFieldNames.RepeatedStringPieceField', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RepeatedCordField', full_name='protobuf_unittest.TestCamelCaseFieldNames.RepeatedCordField', index=11,
      number=12, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7238,
  serialized_end=7723,
)


_TESTFIELDORDERINGS_NESTEDMESSAGE = _descriptor.Descriptor(
  name='NestedMessage',
  full_name='protobuf_unittest.TestFieldOrderings.NestedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oo', full_name='protobuf_unittest.TestFieldOrderings.NestedMessage.oo', index=0,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bb', full_name='protobuf_unittest.TestFieldOrderings.NestedMessage.bb', index=1,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7888,
  serialized_end=7927,
)

_TESTFIELDORDERINGS = _descriptor.Descriptor(
  name='TestFieldOrderings',
  full_name='protobuf_unittest.TestFieldOrderings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='my_string', full_name='protobuf_unittest.TestFieldOrderings.my_string', index=0,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='my_int', full_name='protobuf_unittest.TestFieldOrderings.my_int', index=1,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='my_float', full_name='protobuf_unittest.TestFieldOrderings.my_float', index=2,
      number=101, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_nested_message', full_name='protobuf_unittest.TestFieldOrderings.optional_nested_message', index=3,
      number=200, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TESTFIELDORDERINGS_NESTEDMESSAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(2, 11), (12, 101), ],
  oneofs=[
  ],
  serialized_start=7726,
  serialized_end=7939,
)


_TESTEXTENSIONORDERINGS1 = _descriptor.Descriptor(
  name='TestExtensionOrderings1',
  full_name='protobuf_unittest.TestExtensionOrderings1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='my_string', full_name='protobuf_unittest.TestExtensionOrderings1.my_string', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='test_ext_orderings1', full_name='protobuf_unittest.TestExtensionOrderings1.test_ext_orderings1', index=0,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7942,
  serialized_end=8098,
)


_TESTEXTENSIONORDERINGS2_TESTEXTENSIONORDERINGS3 = _descriptor.Descriptor(
  name='TestExtensionOrderings3',
  full_name='protobuf_unittest.TestExtensionOrderings2.TestExtensionOrderings3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='my_string', full_name='protobuf_unittest.TestExtensionOrderings2.TestExtensionOrderings3.my_string', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='test_ext_orderings3', full_name='protobuf_unittest.TestExtensionOrderings2.TestExtensionOrderings3.test_ext_orderings3', index=0,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8148,
  serialized_end=8329,
)

_TESTEXTENSIONORDERINGS2 = _descriptor.Descriptor(
  name='TestExtensionOrderings2',
  full_name='protobuf_unittest.TestExtensionOrderings2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='my_string', full_name='protobuf_unittest.TestExtensionOrderings2.my_string', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='test_ext_orderings2', full_name='protobuf_unittest.TestExtensionOrderings2.test_ext_orderings2', index=0,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  nested_types=[_TESTEXTENSIONORDERINGS2_TESTEXTENSIONORDERINGS3, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8101,
  serialized_end=8441,
)


_TESTEXTREMEDEFAULTVALUES = _descriptor.Descriptor(
  name='TestExtremeDefaultValues',
  full_name='protobuf_unittest.TestExtremeDefaultValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='escaped_bytes', full_name='protobuf_unittest.TestExtremeDefaultValues.escaped_bytes', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=True, default_value=b"\000\001\007\010\014\n\r\t\013\\\'\"\376",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='large_uint32', full_name='protobuf_unittest.TestExtremeDefaultValues.large_uint32', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=4294967295,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='large_uint64', full_name='protobuf_unittest.TestExtremeDefaultValues.large_uint64', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=18446744073709551615,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='small_int32', full_name='protobuf_unittest.TestExtremeDefaultValues.small_int32', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-2147483647,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='small_int64', full_name='protobuf_unittest.TestExtremeDefaultValues.small_int64', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=True, default_value=-9223372036854775807,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='really_small_int32', full_name='protobuf_unittest.TestExtremeDefaultValues.really_small_int32', index=5,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-2147483648,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='really_small_int64', full_name='protobuf_unittest.TestExtremeDefaultValues.really_small_int64', index=6,
      number=22, type=3, cpp_type=2, label=1,
      has_default_value=True, default_value=-9223372036854775808,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='utf8_string', full_name='protobuf_unittest.TestExtremeDefaultValues.utf8_string', index=7,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"\341\210\264".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zero_float', full_name='protobuf_unittest.TestExtremeDefaultValues.zero_float', index=8,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='one_float', full_name='protobuf_unittest.TestExtremeDefaultValues.one_float', index=9,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='small_float', full_name='protobuf_unittest.TestExtremeDefaultValues.small_float', index=10,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='negative_one_float', full_name='protobuf_unittest.TestExtremeDefaultValues.negative_one_float', index=11,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(-1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='negative_float', full_name='protobuf_unittest.TestExtremeDefaultValues.negative_float', index=12,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(-1.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='large_float', full_name='protobuf_unittest.TestExtremeDefaultValues.large_float', index=13,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(2e+08),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='small_negative_float', full_name='protobuf_unittest.TestExtremeDefaultValues.small_negative_float', index=14,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(-8e-28),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inf_double', full_name='protobuf_unittest.TestExtremeDefaultValues.inf_double', index=15,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=1e10000,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='neg_inf_double', full_name='protobuf_unittest.TestExtremeDefaultValues.neg_inf_double', index=16,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=-1e10000,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nan_double', full_name='protobuf_unittest.TestExtremeDefaultValues.nan_double', index=17,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inf_float', full_name='protobuf_unittest.TestExtremeDefaultValues.inf_float', index=18,
      number=17, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=1e10000,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='neg_inf_float', full_name='protobuf_unittest.TestExtremeDefaultValues.neg_inf_float', index=19,
      number=18, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=-1e10000,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nan_float', full_name='protobuf_unittest.TestExtremeDefaultValues.nan_float', index=20,
      number=19, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpp_trigraph', full_name='protobuf_unittest.TestExtremeDefaultValues.cpp_trigraph', index=21,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"? ? ?? ?? ??? ??/ ??-".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_with_zero', full_name='protobuf_unittest.TestExtremeDefaultValues.string_with_zero', index=22,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"hel\000lo".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_with_zero', full_name='protobuf_unittest.TestExtremeDefaultValues.bytes_with_zero', index=23,
      number=24, type=12, cpp_type=9, label=1,
      has_default_value=True, default_value=b"wor\000ld",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_piece_with_zero', full_name='protobuf_unittest.TestExtremeDefaultValues.string_piece_with_zero', index=24,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"ab\000c".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cord_with_zero', full_name='protobuf_unittest.TestExtremeDefaultValues.cord_with_zero', index=25,
      number=26, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"12\0003".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replacement_string', full_name='protobuf_unittest.TestExtremeDefaultValues.replacement_string', index=26,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"${unknown}".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8444,
  serialized_end=9394,
)


_SPARSEENUMMESSAGE = _descriptor.Descriptor(
  name='SparseEnumMessage',
  full_name='protobuf_unittest.SparseEnumMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sparse_enum', full_name='protobuf_unittest.SparseEnumMessage.sparse_enum', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=123,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9396,
  serialized_end=9471,
)


_ONESTRING = _descriptor.Descriptor(
  name='OneString',
  full_name='protobuf_unittest.OneString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='protobuf_unittest.OneString.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9473,
  serialized_end=9498,
)


_MORESTRING = _descriptor.Descriptor(
  name='MoreString',
  full_name='protobuf_unittest.MoreString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='protobuf_unittest.MoreString.data', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9500,
  serialized_end=9526,
)


_ONEBYTES = _descriptor.Descriptor(
  name='OneBytes',
  full_name='protobuf_unittest.OneBytes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='protobuf_unittest.OneBytes.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9528,
  serialized_end=9552,
)


_MOREBYTES = _descriptor.Descriptor(
  name='MoreBytes',
  full_name='protobuf_unittest.MoreBytes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='protobuf_unittest.MoreBytes.data', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9554,
  serialized_end=9579,
)


_INT32MESSAGE = _descriptor.Descriptor(
  name='Int32Message',
  full_name='protobuf_unittest.Int32Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='protobuf_unittest.Int32Message.data', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9581,
  serialized_end=9609,
)


_UINT32MESSAGE = _descriptor.Descriptor(
  name='Uint32Message',
  full_name='protobuf_unittest.Uint32Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='protobuf_unittest.Uint32Message.data', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9611,
  serialized_end=9640,
)


_INT64MESSAGE = _descriptor.Descriptor(
  name='Int64Message',
  full_name='protobuf_unittest.Int64Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='protobuf_unittest.Int64Message.data', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9642,
  serialized_end=9670,
)


_UINT64MESSAGE = _descriptor.Descriptor(
  name='Uint64Message',
  full_name='protobuf_unittest.Uint64Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='protobuf_unittest.Uint64Message.data', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9672,
  serialized_end=9701,
)


_BOOLMESSAGE = _descriptor.Descriptor(
  name='BoolMessage',
  full_name='protobuf_unittest.BoolMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='protobuf_unittest.BoolMessage.data', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9703,
  serialized_end=9730,
)


_TESTONEOF_FOOGROUP = _descriptor.Descriptor(
  name='FooGroup',
  full_name='protobuf_unittest.TestOneof.FooGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='protobuf_unittest.TestOneof.FooGroup.a', index=0,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b', full_name='protobuf_unittest.TestOneof.FooGroup.b', index=1,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9902,
  serialized_end=9934,
)

_TESTONEOF = _descriptor.Descriptor(
  name='TestOneof',
  full_name='protobuf_unittest.TestOneof',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='foo_int', full_name='protobuf_unittest.TestOneof.foo_int', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foo_string', full_name='protobuf_unittest.TestOneof.foo_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foo_message', full_name='protobuf_unittest.TestOneof.foo_message', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foogroup', full_name='protobuf_unittest.TestOneof.foogroup', index=3,
      number=4, type=10, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TESTONEOF_FOOGROUP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='foo', full_name='protobuf_unittest.TestOneof.foo',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=9733,
  serialized_end=9941,
)


_TESTONEOFBACKWARDSCOMPATIBLE_FOOGROUP = _descriptor.Descriptor(
  name='FooGroup',
  full_name='protobuf_unittest.TestOneofBackwardsCompatible.FooGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='protobuf_unittest.TestOneofBackwardsCompatible.FooGroup.a', index=0,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b', full_name='protobuf_unittest.TestOneofBackwardsCompatible.FooGroup.b', index=1,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9902,
  serialized_end=9934,
)

_TESTONEOFBACKWARDSCOMPATIBLE = _descriptor.Descriptor(
  name='TestOneofBackwardsCompatible',
  full_name='protobuf_unittest.TestOneofBackwardsCompatible',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='foo_int', full_name='protobuf_unittest.TestOneofBackwardsCompatible.foo_int', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foo_string', full_name='protobuf_unittest.TestOneofBackwardsCompatible.foo_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foo_message', full_name='protobuf_unittest.TestOneofBackwardsCompatible.foo_message', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foogroup', full_name='protobuf_unittest.TestOneofBackwardsCompatible.foogroup', index=3,
      number=4, type=10, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TESTONEOFBACKWARDSCOMPATIBLE_FOOGROUP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9944,
  serialized_end=10175,
)


_TESTONEOF2_FOOGROUP = _descriptor.Descriptor(
  name='FooGroup',
  full_name='protobuf_unittest.TestOneof2.FooGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='protobuf_unittest.TestOneof2.FooGroup.a', index=0,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b', full_name='protobuf_unittest.TestOneof2.FooGroup.b', index=1,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10836,
  serialized_end=10868,
)

_TESTONEOF2_NESTEDMESSAGE = _descriptor.Descriptor(
  name='NestedMessage',
  full_name='protobuf_unittest.TestOneof2.NestedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='qux_int', full_name='protobuf_unittest.TestOneof2.NestedMessage.qux_int', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='corge_int', full_name='protobuf_unittest.TestOneof2.NestedMessage.corge_int', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10870,
  serialized_end=10921,
)

_TESTONEOF2 = _descriptor.Descriptor(
  name='TestOneof2',
  full_name='protobuf_unittest.TestOneof2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='foo_int', full_name='protobuf_unittest.TestOneof2.foo_int', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foo_string', full_name='protobuf_unittest.TestOneof2.foo_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foo_cord', full_name='protobuf_unittest.TestOneof2.foo_cord', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foo_string_piece', full_name='protobuf_unittest.TestOneof2.foo_string_piece', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foo_bytes', full_name='protobuf_unittest.TestOneof2.foo_bytes', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foo_enum', full_name='protobuf_unittest.TestOneof2.foo_enum', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foo_message', full_name='protobuf_unittest.TestOneof2.foo_message', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foogroup', full_name='protobuf_unittest.TestOneof2.foogroup', index=7,
      number=8, type=10, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foo_lazy_message', full_name='protobuf_unittest.TestOneof2.foo_lazy_message', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bar_int', full_name='protobuf_unittest.TestOneof2.bar_int', index=9,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=5,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bar_string', full_name='protobuf_unittest.TestOneof2.bar_string', index=10,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"STRING".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bar_cord', full_name='protobuf_unittest.TestOneof2.bar_cord', index=11,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"CORD".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bar_string_piece', full_name='protobuf_unittest.TestOneof2.bar_string_piece', index=12,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"SPIECE".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bar_bytes', full_name='protobuf_unittest.TestOneof2.bar_bytes', index=13,
      number=16, type=12, cpp_type=9, label=1,
      has_default_value=True, default_value=b"BYTES",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bar_enum', full_name='protobuf_unittest.TestOneof2.bar_enum', index=14,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baz_int', full_name='protobuf_unittest.TestOneof2.baz_int', index=15,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baz_string', full_name='protobuf_unittest.TestOneof2.baz_string', index=16,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"BAZ".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TESTONEOF2_FOOGROUP, _TESTONEOF2_NESTEDMESSAGE, ],
  enum_types=[
    _TESTONEOF2_NESTEDENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='foo', full_name='protobuf_unittest.TestOneof2.foo',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='bar', full_name='protobuf_unittest.TestOneof2.bar',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=10178,
  serialized_end=10976,
)


_TESTREQUIREDONEOF_NESTEDMESSAGE = _descriptor.Descriptor(
  name='NestedMessage',
  full_name='protobuf_unittest.TestRequiredOneof.NestedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='required_double', full_name='protobuf_unittest.TestRequiredOneof.NestedMessage.required_double', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11116,
  serialized_end=11156,
)

_TESTREQUIREDONEOF = _descriptor.Descriptor(
  name='TestRequiredOneof',
  full_name='protobuf_unittest.TestRequiredOneof',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='foo_int', full_name='protobuf_unittest.TestRequiredOneof.foo_int', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foo_string', full_name='protobuf_unittest.TestRequiredOneof.foo_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foo_message', full_name='protobuf_unittest.TestRequiredOneof.foo_message', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TESTREQUIREDONEOF_NESTEDMESSAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='foo', full_name='protobuf_unittest.TestRequiredOneof.foo',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=10979,
  serialized_end=11163,
)


_TESTPACKEDTYPES = _descriptor.Descriptor(
  name='TestPackedTypes',
  full_name='protobuf_unittest.TestPackedTypes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='packed_int32', full_name='protobuf_unittest.TestPackedTypes.packed_int32', index=0,
      number=90, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packed_int64', full_name='protobuf_unittest.TestPackedTypes.packed_int64', index=1,
      number=91, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packed_uint32', full_name='protobuf_unittest.TestPackedTypes.packed_uint32', index=2,
      number=92, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packed_uint64', full_name='protobuf_unittest.TestPackedTypes.packed_uint64', index=3,
      number=93, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packed_sint32', full_name='protobuf_unittest.TestPackedTypes.packed_sint32', index=4,
      number=94, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packed_sint64', full_name='protobuf_unittest.TestPackedTypes.packed_sint64', index=5,
      number=95, type=18, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packed_fixed32', full_name='protobuf_unittest.TestPackedTypes.packed_fixed32', index=6,
      number=96, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packed_fixed64', full_name='protobuf_unittest.TestPackedTypes.packed_fixed64', index=7,
      number=97, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packed_sfixed32', full_name='protobuf_unittest.TestPackedTypes.packed_sfixed32', index=8,
      number=98, type=15, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packed_sfixed64', full_name='protobuf_unittest.TestPackedTypes.packed_sfixed64', index=9,
      number=99, type=16, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packed_float', full_name='protobuf_unittest.TestPackedTypes.packed_float', index=10,
      number=100, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packed_double', full_name='protobuf_unittest.TestPackedTypes.packed_double', index=11,
      number=101, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packed_bool', full_name='protobuf_unittest.TestPackedTypes.packed_bool', index=12,
      number=102, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packed_enum', full_name='protobuf_unittest.TestPackedTypes.packed_enum', index=13,
      number=103, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11166,
  serialized_end=11592,
)


_TESTUNPACKEDTYPES = _descriptor.Descriptor(
  name='TestUnpackedTypes',
  full_name='protobuf_unittest.TestUnpackedTypes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unpacked_int32', full_name='protobuf_unittest.TestUnpackedTypes.unpacked_int32', index=0,
      number=90, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unpacked_int64', full_name='protobuf_unittest.TestUnpackedTypes.unpacked_int64', index=1,
      number=91, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unpacked_uint32', full_name='protobuf_unittest.TestUnpackedTypes.unpacked_uint32', index=2,
      number=92, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unpacked_uint64', full_name='protobuf_unittest.TestUnpackedTypes.unpacked_uint64', index=3,
      number=93, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unpacked_sint32', full_name='protobuf_unittest.TestUnpackedTypes.unpacked_sint32', index=4,
      number=94, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unpacked_sint64', full_name='protobuf_unittest.TestUnpackedTypes.unpacked_sint64', index=5,
      number=95, type=18, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unpacked_fixed32', full_name='protobuf_unittest.TestUnpackedTypes.unpacked_fixed32', index=6,
      number=96, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unpacked_fixed64', full_name='protobuf_unittest.TestUnpackedTypes.unpacked_fixed64', index=7,
      number=97, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unpacked_sfixed32', full_name='protobuf_unittest.TestUnpackedTypes.unpacked_sfixed32', index=8,
      number=98, type=15, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unpacked_sfixed64', full_name='protobuf_unittest.TestUnpackedTypes.unpacked_sfixed64', index=9,
      number=99, type=16, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unpacked_float', full_name='protobuf_unittest.TestUnpackedTypes.unpacked_float', index=10,
      number=100, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unpacked_double', full_name='protobuf_unittest.TestUnpackedTypes.unpacked_double', index=11,
      number=101, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unpacked_bool', full_name='protobuf_unittest.TestUnpackedTypes.unpacked_bool', index=12,
      number=102, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unpacked_enum', full_name='protobuf_unittest.TestUnpackedTypes.unpacked_enum', index=13,
      number=103, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11595,
  serialized_end=12051,
)


_TESTPACKEDEXTENSIONS = _descriptor.Descriptor(
  name='TestPackedExtensions',
  full_name='protobuf_unittest.TestPackedExtensions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1, 536870912), ],
  oneofs=[
  ],
  serialized_start=12053,
  serialized_end=12085,
)


_TESTUNPACKEDEXTENSIONS = _descriptor.Descriptor(
  name='TestUnpackedExtensions',
  full_name='protobuf_unittest.TestUnpackedExtensions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1, 536870912), ],
  oneofs=[
  ],
  serialized_start=12087,
  serialized_end=12121,
)


_TESTDYNAMICEXTENSIONS_DYNAMICMESSAGETYPE = _descriptor.Descriptor(
  name='DynamicMessageType',
  full_name='protobuf_unittest.TestDynamicExtensions.DynamicMessageType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dynamic_field', full_name='protobuf_unittest.TestDynamicExtensions.DynamicMessageType.dynamic_field', index=0,
      number=2100, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12544,
  serialized_end=12588,
)

_TESTDYNAMICEXTENSIONS = _descriptor.Descriptor(
  name='TestDynamicExtensions',
  full_name='protobuf_unittest.TestDynamicExtensions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scalar_extension', full_name='protobuf_unittest.TestDynamicExtensions.scalar_extension', index=0,
      number=2000, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enum_extension', full_name='protobuf_unittest.TestDynamicExtensions.enum_extension', index=1,
      number=2001, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=4,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_enum_extension', full_name='protobuf_unittest.TestDynamicExtensions.dynamic_enum_extension', index=2,
      number=2002, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=2200,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_extension', full_name='protobuf_unittest.TestDynamicExtensions.message_extension', index=3,
      number=2003, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_message_extension', full_name='protobuf_unittest.TestDynamicExtensions.dynamic_message_extension', index=4,
      number=2004, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_extension', full_name='protobuf_unittest.TestDynamicExtensions.repeated_extension', index=5,
      number=2005, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packed_extension', full_name='protobuf_unittest.TestDynamicExtensions.packed_extension', index=6,
      number=2006, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TESTDYNAMICEXTENSIONS_DYNAMICMESSAGETYPE, ],
  enum_types=[
    _TESTDYNAMICEXTENSIONS_DYNAMICENUMTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12124,
  serialized_end=12661,
)


_TESTREPEATEDSCALARDIFFERENTTAGSIZES = _descriptor.Descriptor(
  name='TestRepeatedScalarDifferentTagSizes',
  full_name='protobuf_unittest.TestRepeatedScalarDifferentTagSizes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repeated_fixed32', full_name='protobuf_unittest.TestRepeatedScalarDifferentTagSizes.repeated_fixed32', index=0,
      number=12, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_int32', full_name='protobuf_unittest.TestRepeatedScalarDifferentTagSizes.repeated_int32', index=1,
      number=13, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_fixed64', full_name='protobuf_unittest.TestRepeatedScalarDifferentTagSizes.repeated_fixed64', index=2,
      number=2046, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_int64', full_name='protobuf_unittest.TestRepeatedScalarDifferentTagSizes.repeated_int64', index=3,
      number=2047, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_float', full_name='protobuf_unittest.TestRepeatedScalarDifferentTagSizes.repeated_float', index=4,
      number=262142, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_uint64', full_name='protobuf_unittest.TestRepeatedScalarDifferentTagSizes.repeated_uint64', index=5,
      number=262143, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12664,
  serialized_end=12856,
)


_TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR_GROUP1 = _descriptor.Descriptor(
  name='Group1',
  full_name='protobuf_unittest.TestParsingMerge.RepeatedFieldsGenerator.Group1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='field1', full_name='protobuf_unittest.TestParsingMerge.RepeatedFieldsGenerator.Group1.field1', index=0,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13649,
  serialized_end=13706,
)

_TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR_GROUP2 = _descriptor.Descriptor(
  name='Group2',
  full_name='protobuf_unittest.TestParsingMerge.RepeatedFieldsGenerator.Group2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='field1', full_name='protobuf_unittest.TestParsingMerge.RepeatedFieldsGenerator.Group2.field1', index=0,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13708,
  serialized_end=13765,
)

_TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR = _descriptor.Descriptor(
  name='RepeatedFieldsGenerator',
  full_name='protobuf_unittest.TestParsingMerge.RepeatedFieldsGenerator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='field1', full_name='protobuf_unittest.TestParsingMerge.RepeatedFieldsGenerator.field1', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field2', full_name='protobuf_unittest.TestParsingMerge.RepeatedFieldsGenerator.field2', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field3', full_name='protobuf_unittest.TestParsingMerge.RepeatedFieldsGenerator.field3', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group1', full_name='protobuf_unittest.TestParsingMerge.RepeatedFieldsGenerator.group1', index=3,
      number=10, type=10, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group2', full_name='protobuf_unittest.TestParsingMerge.RepeatedFieldsGenerator.group2', index=4,
      number=20, type=10, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ext1', full_name='protobuf_unittest.TestParsingMerge.RepeatedFieldsGenerator.ext1', index=5,
      number=1000, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ext2', full_name='protobuf_unittest.TestParsingMerge.RepeatedFieldsGenerator.ext2', index=6,
      number=1001, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR_GROUP1, _TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR_GROUP2, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13211,
  serialized_end=13765,
)

_TESTPARSINGMERGE_OPTIONALGROUP = _descriptor.Descriptor(
  name='OptionalGroup',
  full_name='protobuf_unittest.TestParsingMerge.OptionalGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='optional_group_all_types', full_name='protobuf_unittest.TestParsingMerge.OptionalGroup.optional_group_all_types', index=0,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13767,
  serialized_end=13849,
)

_TESTPARSINGMERGE_REPEATEDGROUP = _descriptor.Descriptor(
  name='RepeatedGroup',
  full_name='protobuf_unittest.TestParsingMerge.RepeatedGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repeated_group_all_types', full_name='protobuf_unittest.TestParsingMerge.RepeatedGroup.repeated_group_all_types', index=0,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13851,
  serialized_end=13933,
)

_TESTPARSINGMERGE = _descriptor.Descriptor(
  name='TestParsingMerge',
  full_name='protobuf_unittest.TestParsingMerge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='required_all_types', full_name='protobuf_unittest.TestParsingMerge.required_all_types', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_all_types', full_name='protobuf_unittest.TestParsingMerge.optional_all_types', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_all_types', full_name='protobuf_unittest.TestParsingMerge.repeated_all_types', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optionalgroup', full_name='protobuf_unittest.TestParsingMerge.optionalgroup', index=3,
      number=10, type=10, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeatedgroup', full_name='protobuf_unittest.TestParsingMerge.repeatedgroup', index=4,
      number=20, type=10, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='optional_ext', full_name='protobuf_unittest.TestParsingMerge.optional_ext', index=0,
      number=1000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_ext', full_name='protobuf_unittest.TestParsingMerge.repeated_ext', index=1,
      number=1001, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  nested_types=[_TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR, _TESTPARSINGMERGE_OPTIONALGROUP, _TESTPARSINGMERGE_REPEATEDGROUP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1000, 536870912), ],
  oneofs=[
  ],
  serialized_start=12859,
  serialized_end=14130,
)


_TESTCOMMENTINJECTIONMESSAGE = _descriptor.Descriptor(
  name='TestCommentInjectionMessage',
  full_name='protobuf_unittest.TestCommentInjectionMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='protobuf_unittest.TestCommentInjectionMessage.a', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"*/ <- Neither should this.".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14132,
  serialized_end=14200,
)


_FOOREQUEST = _descriptor.Descriptor(
  name='FooRequest',
  full_name='protobuf_unittest.FooRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14202,
  serialized_end=14214,
)


_FOORESPONSE = _descriptor.Descriptor(
  name='FooResponse',
  full_name='protobuf_unittest.FooResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14216,
  serialized_end=14229,
)


_FOOCLIENTMESSAGE = _descriptor.Descriptor(
  name='FooClientMessage',
  full_name='protobuf_unittest.FooClientMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14231,
  serialized_end=14249,
)


_FOOSERVERMESSAGE = _descriptor.Descriptor(
  name='FooServerMessage',
  full_name='protobuf_unittest.FooServerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14251,
  serialized_end=14269,
)


_BARREQUEST = _descriptor.Descriptor(
  name='BarRequest',
  full_name='protobuf_unittest.BarRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14271,
  serialized_end=14283,
)


_BARRESPONSE = _descriptor.Descriptor(
  name='BarResponse',
  full_name='protobuf_unittest.BarResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14285,
  serialized_end=14298,
)


_TESTJSONNAME = _descriptor.Descriptor(
  name='TestJsonName',
  full_name='protobuf_unittest.TestJsonName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='field_name1', full_name='protobuf_unittest.TestJsonName.field_name1', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fieldName2', full_name='protobuf_unittest.TestJsonName.fieldName2', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='FieldName3', full_name='protobuf_unittest.TestJsonName.FieldName3', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='_field_name4', full_name='protobuf_unittest.TestJsonName._field_name4', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='FIELD_NAME5', full_name='protobuf_unittest.TestJsonName.FIELD_NAME5', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field_name6', full_name='protobuf_unittest.TestJsonName.field_name6', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='@type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14301,
  serialized_end=14447,
)


_TESTHUGEFIELDNUMBERS_OPTIONALGROUP = _descriptor.Descriptor(
  name='OptionalGroup',
  full_name='protobuf_unittest.TestHugeFieldNumbers.OptionalGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_a', full_name='protobuf_unittest.TestHugeFieldNumbers.OptionalGroup.group_a', index=0,
      number=536870009, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15094,
  serialized_end=15130,
)

_TESTHUGEFIELDNUMBERS_STRINGSTRINGMAPENTRY = _descriptor.Descriptor(
  name='StringStringMapEntry',
  full_name='protobuf_unittest.TestHugeFieldNumbers.StringStringMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protobuf_unittest.TestHugeFieldNumbers.StringStringMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='protobuf_unittest.TestHugeFieldNumbers.StringStringMapEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15132,
  serialized_end=15186,
)

_TESTHUGEFIELDNUMBERS = _descriptor.Descriptor(
  name='TestHugeFieldNumbers',
  full_name='protobuf_unittest.TestHugeFieldNumbers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='optional_int32', full_name='protobuf_unittest.TestHugeFieldNumbers.optional_int32', index=0,
      number=536870000, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fixed_32', full_name='protobuf_unittest.TestHugeFieldNumbers.fixed_32', index=1,
      number=536870001, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_int32', full_name='protobuf_unittest.TestHugeFieldNumbers.repeated_int32', index=2,
      number=536870002, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packed_int32', full_name='protobuf_unittest.TestHugeFieldNumbers.packed_int32', index=3,
      number=536870003, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_enum', full_name='protobuf_unittest.TestHugeFieldNumbers.optional_enum', index=4,
      number=536870004, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=4,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_string', full_name='protobuf_unittest.TestHugeFieldNumbers.optional_string', index=5,
      number=536870005, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_bytes', full_name='protobuf_unittest.TestHugeFieldNumbers.optional_bytes', index=6,
      number=536870006, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_message', full_name='protobuf_unittest.TestHugeFieldNumbers.optional_message', index=7,
      number=536870007, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optionalgroup', full_name='protobuf_unittest.TestHugeFieldNumbers.optionalgroup', index=8,
      number=536870008, type=10, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_string_map', full_name='protobuf_unittest.TestHugeFieldNumbers.string_string_map', index=9,
      number=536870010, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oneof_uint32', full_name='protobuf_unittest.TestHugeFieldNumbers.oneof_uint32', index=10,
      number=536870011, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oneof_test_all_types', full_name='protobuf_unittest.TestHugeFieldNumbers.oneof_test_all_types', index=11,
      number=536870012, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oneof_string', full_name='protobuf_unittest.TestHugeFieldNumbers.oneof_string', index=12,
      number=536870013, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oneof_bytes', full_name='protobuf_unittest.TestHugeFieldNumbers.oneof_bytes', index=13,
      number=536870014, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TESTHUGEFIELDNUMBERS_OPTIONALGROUP, _TESTHUGEFIELDNUMBERS_STRINGSTRINGMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(536860000, 536870000), ],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_field', full_name='protobuf_unittest.TestHugeFieldNumbers.oneof_field',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=14450,
  serialized_end=15215,
)


_TESTEXTENSIONINSIDETABLE = _descriptor.Descriptor(
  name='TestExtensionInsideTable',
  full_name='protobuf_unittest.TestExtensionInsideTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='field1', full_name='protobuf_unittest.TestExtensionInsideTable.field1', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field2', full_name='protobuf_unittest.TestExtensionInsideTable.field2', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field3', full_name='protobuf_unittest.TestExtensionInsideTable.field3', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field4', full_name='protobuf_unittest.TestExtensionInsideTable.field4', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field6', full_name='protobuf_unittest.TestExtensionInsideTable.field6', index=4,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field7', full_name='protobuf_unittest.TestExtensionInsideTable.field7', index=5,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field8', full_name='protobuf_unittest.TestExtensionInsideTable.field8', index=6,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field9', full_name='protobuf_unittest.TestExtensionInsideTable.field9', index=7,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field10', full_name='protobuf_unittest.TestExtensionInsideTable.field10', index=8,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(5, 6), ],
  oneofs=[
  ],
  serialized_start=15218,
  serialized_end=15395,
)

_TESTALLTYPES_NESTEDMESSAGE.containing_type = _TESTALLTYPES
_TESTALLTYPES_OPTIONALGROUP.containing_type = _TESTALLTYPES
_TESTALLTYPES_REPEATEDGROUP.containing_type = _TESTALLTYPES
_TESTALLTYPES.fields_by_name['optionalgroup'].message_type = _TESTALLTYPES_OPTIONALGROUP
_TESTALLTYPES.fields_by_name['optional_nested_message'].message_type = _TESTALLTYPES_NESTEDMESSAGE
_TESTALLTYPES.fields_by_name['optional_foreign_message'].message_type = _FOREIGNMESSAGE
_TESTALLTYPES.fields_by_name['optional_import_message'].message_type = google_dot_protobuf_dot_unittest__import__pb2._IMPORTMESSAGE
_TESTALLTYPES.fields_by_name['optional_nested_enum'].enum_type = _TESTALLTYPES_NESTEDENUM
_TESTALLTYPES.fields_by_name['optional_foreign_enum'].enum_type = _FOREIGNENUM
_TESTALLTYPES.fields_by_name['optional_import_enum'].enum_type = google_dot_protobuf_dot_unittest__import__pb2._IMPORTENUM
_TESTALLTYPES.fields_by_name['optional_public_import_message'].message_type = google_dot_protobuf_dot_unittest__import__public__pb2._PUBLICIMPORTMESSAGE
_TESTALLTYPES.fields_by_name['optional_lazy_message'].message_type = _TESTALLTYPES_NESTEDMESSAGE
_TESTALLTYPES.fields_by_name['repeatedgroup'].message_type = _TESTALLTYPES_REPEATEDGROUP
_TESTALLTYPES.fields_by_name['repeated_nested_message'].message_type = _TESTALLTYPES_NESTEDMESSAGE
_TESTALLTYPES.fields_by_name['repeated_foreign_message'].message_type = _FOREIGNMESSAGE
_TESTALLTYPES.fields_by_name['repeated_import_message'].message_type = google_dot_protobuf_dot_unittest__import__pb2._IMPORTMESSAGE
_TESTALLTYPES.fields_by_name['repeated_nested_enum'].enum_type = _TESTALLTYPES_NESTEDENUM
_TESTALLTYPES.fields_by_name['repeated_foreign_enum'].enum_type = _FOREIGNENUM
_TESTALLTYPES.fields_by_name['repeated_import_enum'].enum_type = google_dot_protobuf_dot_unittest__import__pb2._IMPORTENUM
_TESTALLTYPES.fields_by_name['repeated_lazy_message'].message_type = _TESTALLTYPES_NESTEDMESSAGE
_TESTALLTYPES.fields_by_name['default_nested_enum'].enum_type = _TESTALLTYPES_NESTEDENUM
_TESTALLTYPES.fields_by_name['default_foreign_enum'].enum_type = _FOREIGNENUM
_TESTALLTYPES.fields_by_name['default_import_enum'].enum_type = google_dot_protobuf_dot_unittest__import__pb2._IMPORTENUM
_TESTALLTYPES.fields_by_name['oneof_nested_message'].message_type = _TESTALLTYPES_NESTEDMESSAGE
_TESTALLTYPES_NESTEDENUM.containing_type = _TESTALLTYPES
_TESTALLTYPES.oneofs_by_name['oneof_field'].fields.append(
  _TESTALLTYPES.fields_by_name['oneof_uint32'])
_TESTALLTYPES.fields_by_name['oneof_uint32'].containing_oneof = _TESTALLTYPES.oneofs_by_name['oneof_field']
_TESTALLTYPES.oneofs_by_name['oneof_field'].fields.append(
  _TESTALLTYPES.fields_by_name['oneof_nested_message'])
_TESTALLTYPES.fields_by_name['oneof_nested_message'].containing_oneof = _TESTALLTYPES.oneofs_by_name['oneof_field']
_TESTALLTYPES.oneofs_by_name['oneof_field'].fields.append(
  _TESTALLTYPES.fields_by_name['oneof_string'])
_TESTALLTYPES.fields_by_name['oneof_string'].containing_oneof = _TESTALLTYPES.oneofs_by_name['oneof_field']
_TESTALLTYPES.oneofs_by_name['oneof_field'].fields.append(
  _TESTALLTYPES.fields_by_name['oneof_bytes'])
_TESTALLTYPES.fields_by_name['oneof_bytes'].containing_oneof = _TESTALLTYPES.oneofs_by_name['oneof_field']
_NESTEDTESTALLTYPES.fields_by_name['child'].message_type = _NESTEDTESTALLTYPES
_NESTEDTESTALLTYPES.fields_by_name['payload'].message_type = _TESTALLTYPES
_NESTEDTESTALLTYPES.fields_by_name['repeated_child'].message_type = _NESTEDTESTALLTYPES
_TESTDEPRECATEDFIELDS.oneofs_by_name['oneof_fields'].fields.append(
  _TESTDEPRECATEDFIELDS.fields_by_name['deprecated_int32_in_oneof'])
_TESTDEPRECATEDFIELDS.fields_by_name['deprecated_int32_in_oneof'].containing_oneof = _TESTDEPRECATEDFIELDS.oneofs_by_name['oneof_fields']
_TESTGROUP_OPTIONALGROUP.containing_type = _TESTGROUP
_TESTGROUP.fields_by_name['optionalgroup'].message_type = _TESTGROUP_OPTIONALGROUP
_TESTGROUP.fields_by_name['optional_foreign_enum'].enum_type = _FOREIGNENUM
_TESTNESTEDEXTENSION_OPTIONALGROUP_EXTENSION.containing_type = _TESTNESTEDEXTENSION
_TESTREQUIREDFOREIGN.fields_by_name['optional_message'].message_type = _TESTREQUIRED
_TESTREQUIREDFOREIGN.fields_by_name['repeated_message'].message_type = _TESTREQUIRED
_TESTREQUIREDMESSAGE.fields_by_name['optional_message'].message_type = _TESTREQUIRED
_TESTREQUIREDMESSAGE.fields_by_name['repeated_message'].message_type = _TESTREQUIRED
_TESTREQUIREDMESSAGE.fields_by_name['required_message'].message_type = _TESTREQUIRED
_TESTFOREIGNNESTED.fields_by_name['foreign_nested'].message_type = _TESTALLTYPES_NESTEDMESSAGE
_TESTPICKLENESTEDMESSAGE_NESTEDMESSAGE_NESTEDNESTEDMESSAGE.containing_type = _TESTPICKLENESTEDMESSAGE_NESTEDMESSAGE
_TESTPICKLENESTEDMESSAGE_NESTEDMESSAGE.containing_type = _TESTPICKLENESTEDMESSAGE
_TESTRECURSIVEMESSAGE.fields_by_name['a'].message_type = _TESTRECURSIVEMESSAGE
_TESTMUTUALRECURSIONA_SUBMESSAGE.fields_by_name['b'].message_type = _TESTMUTUALRECURSIONB
_TESTMUTUALRECURSIONA_SUBMESSAGE.containing_type = _TESTMUTUALRECURSIONA
_TESTMUTUALRECURSIONA_SUBGROUP.fields_by_name['sub_message'].message_type = _TESTMUTUALRECURSIONA_SUBMESSAGE
_TESTMUTUALRECURSIONA_SUBGROUP.fields_by_name['not_in_this_scc'].message_type = _TESTALLTYPES
_TESTMUTUALRECURSIONA_SUBGROUP.containing_type = _TESTMUTUALRECURSIONA
_TESTMUTUALRECURSIONA.fields_by_name['bb'].message_type = _TESTMUTUALRECURSIONB
_TESTMUTUALRECURSIONA.fields_by_name['subgroup'].message_type = _TESTMUTUALRECURSIONA_SUBGROUP
_TESTMUTUALRECURSIONB.fields_by_name['a'].message_type = _TESTMUTUALRECURSIONA
_TESTISINITIALIZED_SUBMESSAGE_SUBGROUP.containing_type = _TESTISINITIALIZED_SUBMESSAGE
_TESTISINITIALIZED_SUBMESSAGE.fields_by_name['subgroup'].message_type = _TESTISINITIALIZED_SUBMESSAGE_SUBGROUP
_TESTISINITIALIZED_SUBMESSAGE.containing_type = _TESTISINITIALIZED
_TESTISINITIALIZED.fields_by_name['sub_message'].message_type = _TESTISINITIALIZED_SUBMESSAGE
_TESTDUPFIELDNUMBER_FOO.containing_type = _TESTDUPFIELDNUMBER
_TESTDUPFIELDNUMBER_BAR.containing_type = _TESTDUPFIELDNUMBER
_TESTDUPFIELDNUMBER.fields_by_name['foo'].message_type = _TESTDUPFIELDNUMBER_FOO
_TESTDUPFIELDNUMBER.fields_by_name['bar'].message_type = _TESTDUPFIELDNUMBER_BAR
_TESTEAGERMESSAGE.fields_by_name['sub_message'].message_type = _TESTALLTYPES
_TESTLAZYMESSAGE.fields_by_name['sub_message'].message_type = _TESTALLTYPES
_TESTNESTEDMESSAGEHASBITS_NESTEDMESSAGE.fields_by_name['nestedmessage_repeated_foreignmessage'].message_type = _FOREIGNMESSAGE
_TESTNESTEDMESSAGEHASBITS_NESTEDMESSAGE.containing_type = _TESTNESTEDMESSAGEHASBITS
_TESTNESTEDMESSAGEHASBITS.fields_by_name['optional_nested_message'].message_type = _TESTNESTEDMESSAGEHASBITS_NESTEDMESSAGE
_TESTCAMELCASEFIELDNAMES.fields_by_name['EnumField'].enum_type = _FOREIGNENUM
_TESTCAMELCASEFIELDNAMES.fields_by_name['MessageField'].message_type = _FOREIGNMESSAGE
_TESTCAMELCASEFIELDNAMES.fields_by_name['RepeatedEnumField'].enum_type = _FOREIGNENUM
_TESTCAMELCASEFIELDNAMES.fields_by_name['RepeatedMessageField'].message_type = _FOREIGNMESSAGE
_TESTFIELDORDERINGS_NESTEDMESSAGE.containing_type = _TESTFIELDORDERINGS
_TESTFIELDORDERINGS.fields_by_name['optional_nested_message'].message_type = _TESTFIELDORDERINGS_NESTEDMESSAGE
_TESTEXTENSIONORDERINGS2_TESTEXTENSIONORDERINGS3.containing_type = _TESTEXTENSIONORDERINGS2
_SPARSEENUMMESSAGE.fields_by_name['sparse_enum'].enum_type = _TESTSPARSEENUM
_TESTONEOF_FOOGROUP.containing_type = _TESTONEOF
_TESTONEOF.fields_by_name['foo_message'].message_type = _TESTALLTYPES
_TESTONEOF.fields_by_name['foogroup'].message_type = _TESTONEOF_FOOGROUP
_TESTONEOF.oneofs_by_name['foo'].fields.append(
  _TESTONEOF.fields_by_name['foo_int'])
_TESTONEOF.fields_by_name['foo_int'].containing_oneof = _TESTONEOF.oneofs_by_name['foo']
_TESTONEOF.oneofs_by_name['foo'].fields.append(
  _TESTONEOF.fields_by_name['foo_string'])
_TESTONEOF.fields_by_name['foo_string'].containing_oneof = _TESTONEOF.oneofs_by_name['foo']
_TESTONEOF.oneofs_by_name['foo'].fields.append(
  _TESTONEOF.fields_by_name['foo_message'])
_TESTONEOF.fields_by_name['foo_message'].containing_oneof = _TESTONEOF.oneofs_by_name['foo']
_TESTONEOF.oneofs_by_name['foo'].fields.append(
  _TESTONEOF.fields_by_name['foogroup'])
_TESTONEOF.fields_by_name['foogroup'].containing_oneof = _TESTONEOF.oneofs_by_name['foo']
_TESTONEOFBACKWARDSCOMPATIBLE_FOOGROUP.containing_type = _TESTONEOFBACKWARDSCOMPATIBLE
_TESTONEOFBACKWARDSCOMPATIBLE.fields_by_name['foo_message'].message_type = _TESTALLTYPES
_TESTONEOFBACKWARDSCOMPATIBLE.fields_by_name['foogroup'].message_type = _TESTONEOFBACKWARDSCOMPATIBLE_FOOGROUP
_TESTONEOF2_FOOGROUP.containing_type = _TESTONEOF2
_TESTONEOF2_NESTEDMESSAGE.containing_type = _TESTONEOF2
_TESTONEOF2.fields_by_name['foo_enum'].enum_type = _TESTONEOF2_NESTEDENUM
_TESTONEOF2.fields_by_name['foo_message'].message_type = _TESTONEOF2_NESTEDMESSAGE
_TESTONEOF2.fields_by_name['foogroup'].message_type = _TESTONEOF2_FOOGROUP
_TESTONEOF2.fields_by_name['foo_lazy_message'].message_type = _TESTONEOF2_NESTEDMESSAGE
_TESTONEOF2.fields_by_name['bar_enum'].enum_type = _TESTONEOF2_NESTEDENUM
_TESTONEOF2_NESTEDENUM.containing_type = _TESTONEOF2
_TESTONEOF2.oneofs_by_name['foo'].fields.append(
  _TESTONEOF2.fields_by_name['foo_int'])
_TESTONEOF2.fields_by_name['foo_int'].containing_oneof = _TESTONEOF2.oneofs_by_name['foo']
_TESTONEOF2.oneofs_by_name['foo'].fields.append(
  _TESTONEOF2.fields_by_name['foo_string'])
_TESTONEOF2.fields_by_name['foo_string'].containing_oneof = _TESTONEOF2.oneofs_by_name['foo']
_TESTONEOF2.oneofs_by_name['foo'].fields.append(
  _TESTONEOF2.fields_by_name['foo_cord'])
_TESTONEOF2.fields_by_name['foo_cord'].containing_oneof = _TESTONEOF2.oneofs_by_name['foo']
_TESTONEOF2.oneofs_by_name['foo'].fields.append(
  _TESTONEOF2.fields_by_name['foo_string_piece'])
_TESTONEOF2.fields_by_name['foo_string_piece'].containing_oneof = _TESTONEOF2.oneofs_by_name['foo']
_TESTONEOF2.oneofs_by_name['foo'].fields.append(
  _TESTONEOF2.fields_by_name['foo_bytes'])
_TESTONEOF2.fields_by_name['foo_bytes'].containing_oneof = _TESTONEOF2.oneofs_by_name['foo']
_TESTONEOF2.oneofs_by_name['foo'].fields.append(
  _TESTONEOF2.fields_by_name['foo_enum'])
_TESTONEOF2.fields_by_name['foo_enum'].containing_oneof = _TESTONEOF2.oneofs_by_name['foo']
_TESTONEOF2.oneofs_by_name['foo'].fields.append(
  _TESTONEOF2.fields_by_name['foo_message'])
_TESTONEOF2.fields_by_name['foo_message'].containing_oneof = _TESTONEOF2.oneofs_by_name['foo']
_TESTONEOF2.oneofs_by_name['foo'].fields.append(
  _TESTONEOF2.fields_by_name['foogroup'])
_TESTONEOF2.fields_by_name['foogroup'].containing_oneof = _TESTONEOF2.oneofs_by_name['foo']
_TESTONEOF2.oneofs_by_name['foo'].fields.append(
  _TESTONEOF2.fields_by_name['foo_lazy_message'])
_TESTONEOF2.fields_by_name['foo_lazy_message'].containing_oneof = _TESTONEOF2.oneofs_by_name['foo']
_TESTONEOF2.oneofs_by_name['bar'].fields.append(
  _TESTONEOF2.fields_by_name['bar_int'])
_TESTONEOF2.fields_by_name['bar_int'].containing_oneof = _TESTONEOF2.oneofs_by_name['bar']
_TESTONEOF2.oneofs_by_name['bar'].fields.append(
  _TESTONEOF2.fields_by_name['bar_string'])
_TESTONEOF2.fields_by_name['bar_string'].containing_oneof = _TESTONEOF2.oneofs_by_name['bar']
_TESTONEOF2.oneofs_by_name['bar'].fields.append(
  _TESTONEOF2.fields_by_name['bar_cord'])
_TESTONEOF2.fields_by_name['bar_cord'].containing_oneof = _TESTONEOF2.oneofs_by_name['bar']
_TESTONEOF2.oneofs_by_name['bar'].fields.append(
  _TESTONEOF2.fields_by_name['bar_string_piece'])
_TESTONEOF2.fields_by_name['bar_string_piece'].containing_oneof = _TESTONEOF2.oneofs_by_name['bar']
_TESTONEOF2.oneofs_by_name['bar'].fields.append(
  _TESTONEOF2.fields_by_name['bar_bytes'])
_TESTONEOF2.fields_by_name['bar_bytes'].containing_oneof = _TESTONEOF2.oneofs_by_name['bar']
_TESTONEOF2.oneofs_by_name['bar'].fields.append(
  _TESTONEOF2.fields_by_name['bar_enum'])
_TESTONEOF2.fields_by_name['bar_enum'].containing_oneof = _TESTONEOF2.oneofs_by_name['bar']
_TESTREQUIREDONEOF_NESTEDMESSAGE.containing_type = _TESTREQUIREDONEOF
_TESTREQUIREDONEOF.fields_by_name['foo_message'].message_type = _TESTREQUIREDONEOF_NESTEDMESSAGE
_TESTREQUIREDONEOF.oneofs_by_name['foo'].fields.append(
  _TESTREQUIREDONEOF.fields_by_name['foo_int'])
_TESTREQUIREDONEOF.fields_by_name['foo_int'].containing_oneof = _TESTREQUIREDONEOF.oneofs_by_name['foo']
_TESTREQUIREDONEOF.oneofs_by_name['foo'].fields.append(
  _TESTREQUIREDONEOF.fields_by_name['foo_string'])
_TESTREQUIREDONEOF.fields_by_name['foo_string'].containing_oneof = _TESTREQUIREDONEOF.oneofs_by_name['foo']
_TESTREQUIREDONEOF.oneofs_by_name['foo'].fields.append(
  _TESTREQUIREDONEOF.fields_by_name['foo_message'])
_TESTREQUIREDONEOF.fields_by_name['foo_message'].containing_oneof = _TESTREQUIREDONEOF.oneofs_by_name['foo']
_TESTPACKEDTYPES.fields_by_name['packed_enum'].enum_type = _FOREIGNENUM
_TESTUNPACKEDTYPES.fields_by_name['unpacked_enum'].enum_type = _FOREIGNENUM
_TESTDYNAMICEXTENSIONS_DYNAMICMESSAGETYPE.containing_type = _TESTDYNAMICEXTENSIONS
_TESTDYNAMICEXTENSIONS.fields_by_name['enum_extension'].enum_type = _FOREIGNENUM
_TESTDYNAMICEXTENSIONS.fields_by_name['dynamic_enum_extension'].enum_type = _TESTDYNAMICEXTENSIONS_DYNAMICENUMTYPE
_TESTDYNAMICEXTENSIONS.fields_by_name['message_extension'].message_type = _FOREIGNMESSAGE
_TESTDYNAMICEXTENSIONS.fields_by_name['dynamic_message_extension'].message_type = _TESTDYNAMICEXTENSIONS_DYNAMICMESSAGETYPE
_TESTDYNAMICEXTENSIONS_DYNAMICENUMTYPE.containing_type = _TESTDYNAMICEXTENSIONS
_TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR_GROUP1.fields_by_name['field1'].message_type = _TESTALLTYPES
_TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR_GROUP1.containing_type = _TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR
_TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR_GROUP2.fields_by_name['field1'].message_type = _TESTALLTYPES
_TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR_GROUP2.containing_type = _TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR
_TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR.fields_by_name['field1'].message_type = _TESTALLTYPES
_TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR.fields_by_name['field2'].message_type = _TESTALLTYPES
_TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR.fields_by_name['field3'].message_type = _TESTALLTYPES
_TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR.fields_by_name['group1'].message_type = _TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR_GROUP1
_TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR.fields_by_name['group2'].message_type = _TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR_GROUP2
_TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR.fields_by_name['ext1'].message_type = _TESTALLTYPES
_TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR.fields_by_name['ext2'].message_type = _TESTALLTYPES
_TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR.containing_type = _TESTPARSINGMERGE
_TESTPARSINGMERGE_OPTIONALGROUP.fields_by_name['optional_group_all_types'].message_type = _TESTALLTYPES
_TESTPARSINGMERGE_OPTIONALGROUP.containing_type = _TESTPARSINGMERGE
_TESTPARSINGMERGE_REPEATEDGROUP.fields_by_name['repeated_group_all_types'].message_type = _TESTALLTYPES
_TESTPARSINGMERGE_REPEATEDGROUP.containing_type = _TESTPARSINGMERGE
_TESTPARSINGMERGE.fields_by_name['required_all_types'].message_type = _TESTALLTYPES
_TESTPARSINGMERGE.fields_by_name['optional_all_types'].message_type = _TESTALLTYPES
_TESTPARSINGMERGE.fields_by_name['repeated_all_types'].message_type = _TESTALLTYPES
_TESTPARSINGMERGE.fields_by_name['optionalgroup'].message_type = _TESTPARSINGMERGE_OPTIONALGROUP
_TESTPARSINGMERGE.fields_by_name['repeatedgroup'].message_type = _TESTPARSINGMERGE_REPEATEDGROUP
_TESTHUGEFIELDNUMBERS_OPTIONALGROUP.containing_type = _TESTHUGEFIELDNUMBERS
_TESTHUGEFIELDNUMBERS_STRINGSTRINGMAPENTRY.containing_type = _TESTHUGEFIELDNUMBERS
_TESTHUGEFIELDNUMBERS.fields_by_name['optional_enum'].enum_type = _FOREIGNENUM
_TESTHUGEFIELDNUMBERS.fields_by_name['optional_message'].message_type = _FOREIGNMESSAGE
_TESTHUGEFIELDNUMBERS.fields_by_name['optionalgroup'].message_type = _TESTHUGEFIELDNUMBERS_OPTIONALGROUP
_TESTHUGEFIELDNUMBERS.fields_by_name['string_string_map'].message_type = _TESTHUGEFIELDNUMBERS_STRINGSTRINGMAPENTRY
_TESTHUGEFIELDNUMBERS.fields_by_name['oneof_test_all_types'].message_type = _TESTALLTYPES
_TESTHUGEFIELDNUMBERS.oneofs_by_name['oneof_field'].fields.append(
  _TESTHUGEFIELDNUMBERS.fields_by_name['oneof_uint32'])
_TESTHUGEFIELDNUMBERS.fields_by_name['oneof_uint32'].containing_oneof = _TESTHUGEFIELDNUMBERS.oneofs_by_name['oneof_field']
_TESTHUGEFIELDNUMBERS.oneofs_by_name['oneof_field'].fields.append(
  _TESTHUGEFIELDNUMBERS.fields_by_name['oneof_test_all_types'])
_TESTHUGEFIELDNUMBERS.fields_by_name['oneof_test_all_types'].containing_oneof = _TESTHUGEFIELDNUMBERS.oneofs_by_name['oneof_field']
_TESTHUGEFIELDNUMBERS.oneofs_by_name['oneof_field'].fields.append(
  _TESTHUGEFIELDNUMBERS.fields_by_name['oneof_string'])
_TESTHUGEFIELDNUMBERS.fields_by_name['oneof_string'].containing_oneof = _TESTHUGEFIELDNUMBERS.oneofs_by_name['oneof_field']
_TESTHUGEFIELDNUMBERS.oneofs_by_name['oneof_field'].fields.append(
  _TESTHUGEFIELDNUMBERS.fields_by_name['oneof_bytes'])
_TESTHUGEFIELDNUMBERS.fields_by_name['oneof_bytes'].containing_oneof = _TESTHUGEFIELDNUMBERS.oneofs_by_name['oneof_field']
DESCRIPTOR.message_types_by_name['TestAllTypes'] = _TESTALLTYPES
DESCRIPTOR.message_types_by_name['NestedTestAllTypes'] = _NESTEDTESTALLTYPES
DESCRIPTOR.message_types_by_name['TestDeprecatedFields'] = _TESTDEPRECATEDFIELDS
DESCRIPTOR.message_types_by_name['TestDeprecatedMessage'] = _TESTDEPRECATEDMESSAGE
DESCRIPTOR.message_types_by_name['ForeignMessage'] = _FOREIGNMESSAGE
DESCRIPTOR.message_types_by_name['TestReservedFields'] = _TESTRESERVEDFIELDS
DESCRIPTOR.message_types_by_name['TestAllExtensions'] = _TESTALLEXTENSIONS
DESCRIPTOR.message_types_by_name['OptionalGroup_extension'] = _OPTIONALGROUP_EXTENSION
DESCRIPTOR.message_types_by_name['RepeatedGroup_extension'] = _REPEATEDGROUP_EXTENSION
DESCRIPTOR.message_types_by_name['TestGroup'] = _TESTGROUP
DESCRIPTOR.message_types_by_name['TestGroupExtension'] = _TESTGROUPEXTENSION
DESCRIPTOR.message_types_by_name['TestNestedExtension'] = _TESTNESTEDEXTENSION
DESCRIPTOR.message_types_by_name['TestRequired'] = _TESTREQUIRED
DESCRIPTOR.message_types_by_name['TestRequiredForeign'] = _TESTREQUIREDFOREIGN
DESCRIPTOR.message_types_by_name['TestRequiredMessage'] = _TESTREQUIREDMESSAGE
DESCRIPTOR.message_types_by_name['TestForeignNested'] = _TESTFOREIGNNESTED
DESCRIPTOR.message_types_by_name['TestEmptyMessage'] = _TESTEMPTYMESSAGE
DESCRIPTOR.message_types_by_name['TestEmptyMessageWithExtensions'] = _TESTEMPTYMESSAGEWITHEXTENSIONS
DESCRIPTOR.message_types_by_name['TestPickleNestedMessage'] = _TESTPICKLENESTEDMESSAGE
DESCRIPTOR.message_types_by_name['TestMultipleExtensionRanges'] = _TESTMULTIPLEEXTENSIONRANGES
DESCRIPTOR.message_types_by_name['TestReallyLargeTagNumber'] = _TESTREALLYLARGETAGNUMBER
DESCRIPTOR.message_types_by_name['TestRecursiveMessage'] = _TESTRECURSIVEMESSAGE
DESCRIPTOR.message_types_by_name['TestMutualRecursionA'] = _TESTMUTUALRECURSIONA
DESCRIPTOR.message_types_by_name['TestMutualRecursionB'] = _TESTMUTUALRECURSIONB
DESCRIPTOR.message_types_by_name['TestIsInitialized'] = _TESTISINITIALIZED
DESCRIPTOR.message_types_by_name['TestDupFieldNumber'] = _TESTDUPFIELDNUMBER
DESCRIPTOR.message_types_by_name['TestEagerMessage'] = _TESTEAGERMESSAGE
DESCRIPTOR.message_types_by_name['TestLazyMessage'] = _TESTLAZYMESSAGE
DESCRIPTOR.message_types_by_name['TestNestedMessageHasBits'] = _TESTNESTEDMESSAGEHASBITS
DESCRIPTOR.message_types_by_name['TestCamelCaseFieldNames'] = _TESTCAMELCASEFIELDNAMES
DESCRIPTOR.message_types_by_name['TestFieldOrderings'] = _TESTFIELDORDERINGS
DESCRIPTOR.message_types_by_name['TestExtensionOrderings1'] = _TESTEXTENSIONORDERINGS1
DESCRIPTOR.message_types_by_name['TestExtensionOrderings2'] = _TESTEXTENSIONORDERINGS2
DESCRIPTOR.message_types_by_name['TestExtremeDefaultValues'] = _TESTEXTREMEDEFAULTVALUES
DESCRIPTOR.message_types_by_name['SparseEnumMessage'] = _SPARSEENUMMESSAGE
DESCRIPTOR.message_types_by_name['OneString'] = _ONESTRING
DESCRIPTOR.message_types_by_name['MoreString'] = _MORESTRING
DESCRIPTOR.message_types_by_name['OneBytes'] = _ONEBYTES
DESCRIPTOR.message_types_by_name['MoreBytes'] = _MOREBYTES
DESCRIPTOR.message_types_by_name['Int32Message'] = _INT32MESSAGE
DESCRIPTOR.message_types_by_name['Uint32Message'] = _UINT32MESSAGE
DESCRIPTOR.message_types_by_name['Int64Message'] = _INT64MESSAGE
DESCRIPTOR.message_types_by_name['Uint64Message'] = _UINT64MESSAGE
DESCRIPTOR.message_types_by_name['BoolMessage'] = _BOOLMESSAGE
DESCRIPTOR.message_types_by_name['TestOneof'] = _TESTONEOF
DESCRIPTOR.message_types_by_name['TestOneofBackwardsCompatible'] = _TESTONEOFBACKWARDSCOMPATIBLE
DESCRIPTOR.message_types_by_name['TestOneof2'] = _TESTONEOF2
DESCRIPTOR.message_types_by_name['TestRequiredOneof'] = _TESTREQUIREDONEOF
DESCRIPTOR.message_types_by_name['TestPackedTypes'] = _TESTPACKEDTYPES
DESCRIPTOR.message_types_by_name['TestUnpackedTypes'] = _TESTUNPACKEDTYPES
DESCRIPTOR.message_types_by_name['TestPackedExtensions'] = _TESTPACKEDEXTENSIONS
DESCRIPTOR.message_types_by_name['TestUnpackedExtensions'] = _TESTUNPACKEDEXTENSIONS
DESCRIPTOR.message_types_by_name['TestDynamicExtensions'] = _TESTDYNAMICEXTENSIONS
DESCRIPTOR.message_types_by_name['TestRepeatedScalarDifferentTagSizes'] = _TESTREPEATEDSCALARDIFFERENTTAGSIZES
DESCRIPTOR.message_types_by_name['TestParsingMerge'] = _TESTPARSINGMERGE
DESCRIPTOR.message_types_by_name['TestCommentInjectionMessage'] = _TESTCOMMENTINJECTIONMESSAGE
DESCRIPTOR.message_types_by_name['FooRequest'] = _FOOREQUEST
DESCRIPTOR.message_types_by_name['FooResponse'] = _FOORESPONSE
DESCRIPTOR.message_types_by_name['FooClientMessage'] = _FOOCLIENTMESSAGE
DESCRIPTOR.message_types_by_name['FooServerMessage'] = _FOOSERVERMESSAGE
DESCRIPTOR.message_types_by_name['BarRequest'] = _BARREQUEST
DESCRIPTOR.message_types_by_name['BarResponse'] = _BARRESPONSE
DESCRIPTOR.message_types_by_name['TestJsonName'] = _TESTJSONNAME
DESCRIPTOR.message_types_by_name['TestHugeFieldNumbers'] = _TESTHUGEFIELDNUMBERS
DESCRIPTOR.message_types_by_name['TestExtensionInsideTable'] = _TESTEXTENSIONINSIDETABLE
DESCRIPTOR.enum_types_by_name['ForeignEnum'] = _FOREIGNENUM
DESCRIPTOR.enum_types_by_name['TestEnumWithDupValue'] = _TESTENUMWITHDUPVALUE
DESCRIPTOR.enum_types_by_name['TestSparseEnum'] = _TESTSPARSEENUM
DESCRIPTOR.enum_types_by_name['VeryLargeEnum'] = _VERYLARGEENUM
DESCRIPTOR.extensions_by_name['optional_int32_extension'] = optional_int32_extension
DESCRIPTOR.extensions_by_name['optional_int64_extension'] = optional_int64_extension
DESCRIPTOR.extensions_by_name['optional_uint32_extension'] = optional_uint32_extension
DESCRIPTOR.extensions_by_name['optional_uint64_extension'] = optional_uint64_extension
DESCRIPTOR.extensions_by_name['optional_sint32_extension'] = optional_sint32_extension
DESCRIPTOR.extensions_by_name['optional_sint64_extension'] = optional_sint64_extension
DESCRIPTOR.extensions_by_name['optional_fixed32_extension'] = optional_fixed32_extension
DESCRIPTOR.extensions_by_name['optional_fixed64_extension'] = optional_fixed64_extension
DESCRIPTOR.extensions_by_name['optional_sfixed32_extension'] = optional_sfixed32_extension
DESCRIPTOR.extensions_by_name['optional_sfixed64_extension'] = optional_sfixed64_extension
DESCRIPTOR.extensions_by_name['optional_float_extension'] = optional_float_extension
DESCRIPTOR.extensions_by_name['optional_double_extension'] = optional_double_extension
DESCRIPTOR.extensions_by_name['optional_bool_extension'] = optional_bool_extension
DESCRIPTOR.extensions_by_name['optional_string_extension'] = optional_string_extension
DESCRIPTOR.extensions_by_name['optional_bytes_extension'] = optional_bytes_extension
DESCRIPTOR.extensions_by_name['optionalgroup_extension'] = optionalgroup_extension
DESCRIPTOR.extensions_by_name['optional_nested_message_extension'] = optional_nested_message_extension
DESCRIPTOR.extensions_by_name['optional_foreign_message_extension'] = optional_foreign_message_extension
DESCRIPTOR.extensions_by_name['optional_import_message_extension'] = optional_import_message_extension
DESCRIPTOR.extensions_by_name['optional_nested_enum_extension'] = optional_nested_enum_extension
DESCRIPTOR.extensions_by_name['optional_foreign_enum_extension'] = optional_foreign_enum_extension
DESCRIPTOR.extensions_by_name['optional_import_enum_extension'] = optional_import_enum_extension
DESCRIPTOR.extensions_by_name['optional_string_piece_extension'] = optional_string_piece_extension
DESCRIPTOR.extensions_by_name['optional_cord_extension'] = optional_cord_extension
DESCRIPTOR.extensions_by_name['optional_public_import_message_extension'] = optional_public_import_message_extension
DESCRIPTOR.extensions_by_name['optional_lazy_message_extension'] = optional_lazy_message_extension
DESCRIPTOR.extensions_by_name['repeated_int32_extension'] = repeated_int32_extension
DESCRIPTOR.extensions_by_name['repeated_int64_extension'] = repeated_int64_extension
DESCRIPTOR.extensions_by_name['repeated_uint32_extension'] = repeated_uint32_extension
DESCRIPTOR.extensions_by_name['repeated_uint64_extension'] = repeated_uint64_extension
DESCRIPTOR.extensions_by_name['repeated_sint32_extension'] = repeated_sint32_extension
DESCRIPTOR.extensions_by_name['repeated_sint64_extension'] = repeated_sint64_extension
DESCRIPTOR.extensions_by_name['repeated_fixed32_extension'] = repeated_fixed32_extension
DESCRIPTOR.extensions_by_name['repeated_fixed64_extension'] = repeated_fixed64_extension
DESCRIPTOR.extensions_by_name['repeated_sfixed32_extension'] = repeated_sfixed32_extension
DESCRIPTOR.extensions_by_name['repeated_sfixed64_extension'] = repeated_sfixed64_extension
DESCRIPTOR.extensions_by_name['repeated_float_extension'] = repeated_float_extension
DESCRIPTOR.extensions_by_name['repeated_double_extension'] = repeated_double_extension
DESCRIPTOR.extensions_by_name['repeated_bool_extension'] = repeated_bool_extension
DESCRIPTOR.extensions_by_name['repeated_string_extension'] = repeated_string_extension
DESCRIPTOR.extensions_by_name['repeated_bytes_extension'] = repeated_bytes_extension
DESCRIPTOR.extensions_by_name['repeatedgroup_extension'] = repeatedgroup_extension
DESCRIPTOR.extensions_by_name['repeated_nested_message_extension'] = repeated_nested_message_extension
DESCRIPTOR.extensions_by_name['repeated_foreign_message_extension'] = repeated_foreign_message_extension
DESCRIPTOR.extensions_by_name['repeated_import_message_extension'] = repeated_import_message_extension
DESCRIPTOR.extensions_by_name['repeated_nested_enum_extension'] = repeated_nested_enum_extension
DESCRIPTOR.extensions_by_name['repeated_foreign_enum_extension'] = repeated_foreign_enum_extension
DESCRIPTOR.extensions_by_name['repeated_import_enum_extension'] = repeated_import_enum_extension
DESCRIPTOR.extensions_by_name['repeated_string_piece_extension'] = repeated_string_piece_extension
DESCRIPTOR.extensions_by_name['repeated_cord_extension'] = repeated_cord_extension
DESCRIPTOR.extensions_by_name['repeated_lazy_message_extension'] = repeated_lazy_message_extension
DESCRIPTOR.extensions_by_name['default_int32_extension'] = default_int32_extension
DESCRIPTOR.extensions_by_name['default_int64_extension'] = default_int64_extension
DESCRIPTOR.extensions_by_name['default_uint32_extension'] = default_uint32_extension
DESCRIPTOR.extensions_by_name['default_uint64_extension'] = default_uint64_extension
DESCRIPTOR.extensions_by_name['default_sint32_extension'] = default_sint32_extension
DESCRIPTOR.extensions_by_name['default_sint64_extension'] = default_sint64_extension
DESCRIPTOR.extensions_by_name['default_fixed32_extension'] = default_fixed32_extension
DESCRIPTOR.extensions_by_name['default_fixed64_extension'] = default_fixed64_extension
DESCRIPTOR.extensions_by_name['default_sfixed32_extension'] = default_sfixed32_extension
DESCRIPTOR.extensions_by_name['default_sfixed64_extension'] = default_sfixed64_extension
DESCRIPTOR.extensions_by_name['default_float_extension'] = default_float_extension
DESCRIPTOR.extensions_by_name['default_double_extension'] = default_double_extension
DESCRIPTOR.extensions_by_name['default_bool_extension'] = default_bool_extension
DESCRIPTOR.extensions_by_name['default_string_extension'] = default_string_extension
DESCRIPTOR.extensions_by_name['default_bytes_extension'] = default_bytes_extension
DESCRIPTOR.extensions_by_name['default_nested_enum_extension'] = default_nested_enum_extension
DESCRIPTOR.extensions_by_name['default_foreign_enum_extension'] = default_foreign_enum_extension
DESCRIPTOR.extensions_by_name['default_import_enum_extension'] = default_import_enum_extension
DESCRIPTOR.extensions_by_name['default_string_piece_extension'] = default_string_piece_extension
DESCRIPTOR.extensions_by_name['default_cord_extension'] = default_cord_extension
DESCRIPTOR.extensions_by_name['oneof_uint32_extension'] = oneof_uint32_extension
DESCRIPTOR.extensions_by_name['oneof_nested_message_extension'] = oneof_nested_message_extension
DESCRIPTOR.extensions_by_name['oneof_string_extension'] = oneof_string_extension
DESCRIPTOR.extensions_by_name['oneof_bytes_extension'] = oneof_bytes_extension
DESCRIPTOR.extensions_by_name['my_extension_string'] = my_extension_string
DESCRIPTOR.extensions_by_name['my_extension_int'] = my_extension_int
DESCRIPTOR.extensions_by_name['packed_int32_extension'] = packed_int32_extension
DESCRIPTOR.extensions_by_name['packed_int64_extension'] = packed_int64_extension
DESCRIPTOR.extensions_by_name['packed_uint32_extension'] = packed_uint32_extension
DESCRIPTOR.extensions_by_name['packed_uint64_extension'] = packed_uint64_extension
DESCRIPTOR.extensions_by_name['packed_sint32_extension'] = packed_sint32_extension
DESCRIPTOR.extensions_by_name['packed_sint64_extension'] = packed_sint64_extension
DESCRIPTOR.extensions_by_name['packed_fixed32_extension'] = packed_fixed32_extension
DESCRIPTOR.extensions_by_name['packed_fixed64_extension'] = packed_fixed64_extension
DESCRIPTOR.extensions_by_name['packed_sfixed32_extension'] = packed_sfixed32_extension
DESCRIPTOR.extensions_by_name['packed_sfixed64_extension'] = packed_sfixed64_extension
DESCRIPTOR.extensions_by_name['packed_float_extension'] = packed_float_extension
DESCRIPTOR.extensions_by_name['packed_double_extension'] = packed_double_extension
DESCRIPTOR.extensions_by_name['packed_bool_extension'] = packed_bool_extension
DESCRIPTOR.extensions_by_name['packed_enum_extension'] = packed_enum_extension
DESCRIPTOR.extensions_by_name['unpacked_int32_extension'] = unpacked_int32_extension
DESCRIPTOR.extensions_by_name['unpacked_int64_extension'] = unpacked_int64_extension
DESCRIPTOR.extensions_by_name['unpacked_uint32_extension'] = unpacked_uint32_extension
DESCRIPTOR.extensions_by_name['unpacked_uint64_extension'] = unpacked_uint64_extension
DESCRIPTOR.extensions_by_name['unpacked_sint32_extension'] = unpacked_sint32_extension
DESCRIPTOR.extensions_by_name['unpacked_sint64_extension'] = unpacked_sint64_extension
DESCRIPTOR.extensions_by_name['unpacked_fixed32_extension'] = unpacked_fixed32_extension
DESCRIPTOR.extensions_by_name['unpacked_fixed64_extension'] = unpacked_fixed64_extension
DESCRIPTOR.extensions_by_name['unpacked_sfixed32_extension'] = unpacked_sfixed32_extension
DESCRIPTOR.extensions_by_name['unpacked_sfixed64_extension'] = unpacked_sfixed64_extension
DESCRIPTOR.extensions_by_name['unpacked_float_extension'] = unpacked_float_extension
DESCRIPTOR.extensions_by_name['unpacked_double_extension'] = unpacked_double_extension
DESCRIPTOR.extensions_by_name['unpacked_bool_extension'] = unpacked_bool_extension
DESCRIPTOR.extensions_by_name['unpacked_enum_extension'] = unpacked_enum_extension
DESCRIPTOR.extensions_by_name['test_all_types'] = test_all_types
DESCRIPTOR.extensions_by_name['test_extension_inside_table_extension'] = test_extension_inside_table_extension
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TestAllTypes = _reflection.GeneratedProtocolMessageType('TestAllTypes', (_message.Message,), {

  'NestedMessage' : _reflection.GeneratedProtocolMessageType('NestedMessage', (_message.Message,), {
    'DESCRIPTOR' : _TESTALLTYPES_NESTEDMESSAGE,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestAllTypes.NestedMessage)
    })
  ,

  'OptionalGroup' : _reflection.GeneratedProtocolMessageType('OptionalGroup', (_message.Message,), {
    'DESCRIPTOR' : _TESTALLTYPES_OPTIONALGROUP,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestAllTypes.OptionalGroup)
    })
  ,

  'RepeatedGroup' : _reflection.GeneratedProtocolMessageType('RepeatedGroup', (_message.Message,), {
    'DESCRIPTOR' : _TESTALLTYPES_REPEATEDGROUP,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestAllTypes.RepeatedGroup)
    })
  ,
  'DESCRIPTOR' : _TESTALLTYPES,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestAllTypes)
  })
_sym_db.RegisterMessage(TestAllTypes)
_sym_db.RegisterMessage(TestAllTypes.NestedMessage)
_sym_db.RegisterMessage(TestAllTypes.OptionalGroup)
_sym_db.RegisterMessage(TestAllTypes.RepeatedGroup)

NestedTestAllTypes = _reflection.GeneratedProtocolMessageType('NestedTestAllTypes', (_message.Message,), {
  'DESCRIPTOR' : _NESTEDTESTALLTYPES,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.NestedTestAllTypes)
  })
_sym_db.RegisterMessage(NestedTestAllTypes)

TestDeprecatedFields = _reflection.GeneratedProtocolMessageType('TestDeprecatedFields', (_message.Message,), {
  'DESCRIPTOR' : _TESTDEPRECATEDFIELDS,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestDeprecatedFields)
  })
_sym_db.RegisterMessage(TestDeprecatedFields)

TestDeprecatedMessage = _reflection.GeneratedProtocolMessageType('TestDeprecatedMessage', (_message.Message,), {
  'DESCRIPTOR' : _TESTDEPRECATEDMESSAGE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestDeprecatedMessage)
  })
_sym_db.RegisterMessage(TestDeprecatedMessage)

ForeignMessage = _reflection.GeneratedProtocolMessageType('ForeignMessage', (_message.Message,), {
  'DESCRIPTOR' : _FOREIGNMESSAGE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.ForeignMessage)
  })
_sym_db.RegisterMessage(ForeignMessage)

TestReservedFields = _reflection.GeneratedProtocolMessageType('TestReservedFields', (_message.Message,), {
  'DESCRIPTOR' : _TESTRESERVEDFIELDS,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestReservedFields)
  })
_sym_db.RegisterMessage(TestReservedFields)

TestAllExtensions = _reflection.GeneratedProtocolMessageType('TestAllExtensions', (_message.Message,), {
  'DESCRIPTOR' : _TESTALLEXTENSIONS,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestAllExtensions)
  })
_sym_db.RegisterMessage(TestAllExtensions)

OptionalGroup_extension = _reflection.GeneratedProtocolMessageType('OptionalGroup_extension', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONALGROUP_EXTENSION,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.OptionalGroup_extension)
  })
_sym_db.RegisterMessage(OptionalGroup_extension)

RepeatedGroup_extension = _reflection.GeneratedProtocolMessageType('RepeatedGroup_extension', (_message.Message,), {
  'DESCRIPTOR' : _REPEATEDGROUP_EXTENSION,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.RepeatedGroup_extension)
  })
_sym_db.RegisterMessage(RepeatedGroup_extension)

TestGroup = _reflection.GeneratedProtocolMessageType('TestGroup', (_message.Message,), {

  'OptionalGroup' : _reflection.GeneratedProtocolMessageType('OptionalGroup', (_message.Message,), {
    'DESCRIPTOR' : _TESTGROUP_OPTIONALGROUP,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestGroup.OptionalGroup)
    })
  ,
  'DESCRIPTOR' : _TESTGROUP,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestGroup)
  })
_sym_db.RegisterMessage(TestGroup)
_sym_db.RegisterMessage(TestGroup.OptionalGroup)

TestGroupExtension = _reflection.GeneratedProtocolMessageType('TestGroupExtension', (_message.Message,), {
  'DESCRIPTOR' : _TESTGROUPEXTENSION,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestGroupExtension)
  })
_sym_db.RegisterMessage(TestGroupExtension)

TestNestedExtension = _reflection.GeneratedProtocolMessageType('TestNestedExtension', (_message.Message,), {

  'OptionalGroup_extension' : _reflection.GeneratedProtocolMessageType('OptionalGroup_extension', (_message.Message,), {
    'DESCRIPTOR' : _TESTNESTEDEXTENSION_OPTIONALGROUP_EXTENSION,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestNestedExtension.OptionalGroup_extension)
    })
  ,
  'DESCRIPTOR' : _TESTNESTEDEXTENSION,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestNestedExtension)
  })
_sym_db.RegisterMessage(TestNestedExtension)
_sym_db.RegisterMessage(TestNestedExtension.OptionalGroup_extension)

TestRequired = _reflection.GeneratedProtocolMessageType('TestRequired', (_message.Message,), {
  'DESCRIPTOR' : _TESTREQUIRED,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestRequired)
  })
_sym_db.RegisterMessage(TestRequired)

TestRequiredForeign = _reflection.GeneratedProtocolMessageType('TestRequiredForeign', (_message.Message,), {
  'DESCRIPTOR' : _TESTREQUIREDFOREIGN,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestRequiredForeign)
  })
_sym_db.RegisterMessage(TestRequiredForeign)

TestRequiredMessage = _reflection.GeneratedProtocolMessageType('TestRequiredMessage', (_message.Message,), {
  'DESCRIPTOR' : _TESTREQUIREDMESSAGE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestRequiredMessage)
  })
_sym_db.RegisterMessage(TestRequiredMessage)

TestForeignNested = _reflection.GeneratedProtocolMessageType('TestForeignNested', (_message.Message,), {
  'DESCRIPTOR' : _TESTFOREIGNNESTED,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestForeignNested)
  })
_sym_db.RegisterMessage(TestForeignNested)

TestEmptyMessage = _reflection.GeneratedProtocolMessageType('TestEmptyMessage', (_message.Message,), {
  'DESCRIPTOR' : _TESTEMPTYMESSAGE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestEmptyMessage)
  })
_sym_db.RegisterMessage(TestEmptyMessage)

TestEmptyMessageWithExtensions = _reflection.GeneratedProtocolMessageType('TestEmptyMessageWithExtensions', (_message.Message,), {
  'DESCRIPTOR' : _TESTEMPTYMESSAGEWITHEXTENSIONS,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestEmptyMessageWithExtensions)
  })
_sym_db.RegisterMessage(TestEmptyMessageWithExtensions)

TestPickleNestedMessage = _reflection.GeneratedProtocolMessageType('TestPickleNestedMessage', (_message.Message,), {

  'NestedMessage' : _reflection.GeneratedProtocolMessageType('NestedMessage', (_message.Message,), {

    'NestedNestedMessage' : _reflection.GeneratedProtocolMessageType('NestedNestedMessage', (_message.Message,), {
      'DESCRIPTOR' : _TESTPICKLENESTEDMESSAGE_NESTEDMESSAGE_NESTEDNESTEDMESSAGE,
      '__module__' : 'google.protobuf.unittest_pb2'
      # @@protoc_insertion_point(class_scope:protobuf_unittest.TestPickleNestedMessage.NestedMessage.NestedNestedMessage)
      })
    ,
    'DESCRIPTOR' : _TESTPICKLENESTEDMESSAGE_NESTEDMESSAGE,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestPickleNestedMessage.NestedMessage)
    })
  ,
  'DESCRIPTOR' : _TESTPICKLENESTEDMESSAGE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestPickleNestedMessage)
  })
_sym_db.RegisterMessage(TestPickleNestedMessage)
_sym_db.RegisterMessage(TestPickleNestedMessage.NestedMessage)
_sym_db.RegisterMessage(TestPickleNestedMessage.NestedMessage.NestedNestedMessage)

TestMultipleExtensionRanges = _reflection.GeneratedProtocolMessageType('TestMultipleExtensionRanges', (_message.Message,), {
  'DESCRIPTOR' : _TESTMULTIPLEEXTENSIONRANGES,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestMultipleExtensionRanges)
  })
_sym_db.RegisterMessage(TestMultipleExtensionRanges)

TestReallyLargeTagNumber = _reflection.GeneratedProtocolMessageType('TestReallyLargeTagNumber', (_message.Message,), {
  'DESCRIPTOR' : _TESTREALLYLARGETAGNUMBER,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestReallyLargeTagNumber)
  })
_sym_db.RegisterMessage(TestReallyLargeTagNumber)

TestRecursiveMessage = _reflection.GeneratedProtocolMessageType('TestRecursiveMessage', (_message.Message,), {
  'DESCRIPTOR' : _TESTRECURSIVEMESSAGE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestRecursiveMessage)
  })
_sym_db.RegisterMessage(TestRecursiveMessage)

TestMutualRecursionA = _reflection.GeneratedProtocolMessageType('TestMutualRecursionA', (_message.Message,), {

  'SubMessage' : _reflection.GeneratedProtocolMessageType('SubMessage', (_message.Message,), {
    'DESCRIPTOR' : _TESTMUTUALRECURSIONA_SUBMESSAGE,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestMutualRecursionA.SubMessage)
    })
  ,

  'SubGroup' : _reflection.GeneratedProtocolMessageType('SubGroup', (_message.Message,), {
    'DESCRIPTOR' : _TESTMUTUALRECURSIONA_SUBGROUP,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestMutualRecursionA.SubGroup)
    })
  ,
  'DESCRIPTOR' : _TESTMUTUALRECURSIONA,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestMutualRecursionA)
  })
_sym_db.RegisterMessage(TestMutualRecursionA)
_sym_db.RegisterMessage(TestMutualRecursionA.SubMessage)
_sym_db.RegisterMessage(TestMutualRecursionA.SubGroup)

TestMutualRecursionB = _reflection.GeneratedProtocolMessageType('TestMutualRecursionB', (_message.Message,), {
  'DESCRIPTOR' : _TESTMUTUALRECURSIONB,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestMutualRecursionB)
  })
_sym_db.RegisterMessage(TestMutualRecursionB)

TestIsInitialized = _reflection.GeneratedProtocolMessageType('TestIsInitialized', (_message.Message,), {

  'SubMessage' : _reflection.GeneratedProtocolMessageType('SubMessage', (_message.Message,), {

    'SubGroup' : _reflection.GeneratedProtocolMessageType('SubGroup', (_message.Message,), {
      'DESCRIPTOR' : _TESTISINITIALIZED_SUBMESSAGE_SUBGROUP,
      '__module__' : 'google.protobuf.unittest_pb2'
      # @@protoc_insertion_point(class_scope:protobuf_unittest.TestIsInitialized.SubMessage.SubGroup)
      })
    ,
    'DESCRIPTOR' : _TESTISINITIALIZED_SUBMESSAGE,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestIsInitialized.SubMessage)
    })
  ,
  'DESCRIPTOR' : _TESTISINITIALIZED,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestIsInitialized)
  })
_sym_db.RegisterMessage(TestIsInitialized)
_sym_db.RegisterMessage(TestIsInitialized.SubMessage)
_sym_db.RegisterMessage(TestIsInitialized.SubMessage.SubGroup)

TestDupFieldNumber = _reflection.GeneratedProtocolMessageType('TestDupFieldNumber', (_message.Message,), {

  'Foo' : _reflection.GeneratedProtocolMessageType('Foo', (_message.Message,), {
    'DESCRIPTOR' : _TESTDUPFIELDNUMBER_FOO,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestDupFieldNumber.Foo)
    })
  ,

  'Bar' : _reflection.GeneratedProtocolMessageType('Bar', (_message.Message,), {
    'DESCRIPTOR' : _TESTDUPFIELDNUMBER_BAR,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestDupFieldNumber.Bar)
    })
  ,
  'DESCRIPTOR' : _TESTDUPFIELDNUMBER,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestDupFieldNumber)
  })
_sym_db.RegisterMessage(TestDupFieldNumber)
_sym_db.RegisterMessage(TestDupFieldNumber.Foo)
_sym_db.RegisterMessage(TestDupFieldNumber.Bar)

TestEagerMessage = _reflection.GeneratedProtocolMessageType('TestEagerMessage', (_message.Message,), {
  'DESCRIPTOR' : _TESTEAGERMESSAGE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestEagerMessage)
  })
_sym_db.RegisterMessage(TestEagerMessage)

TestLazyMessage = _reflection.GeneratedProtocolMessageType('TestLazyMessage', (_message.Message,), {
  'DESCRIPTOR' : _TESTLAZYMESSAGE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestLazyMessage)
  })
_sym_db.RegisterMessage(TestLazyMessage)

TestNestedMessageHasBits = _reflection.GeneratedProtocolMessageType('TestNestedMessageHasBits', (_message.Message,), {

  'NestedMessage' : _reflection.GeneratedProtocolMessageType('NestedMessage', (_message.Message,), {
    'DESCRIPTOR' : _TESTNESTEDMESSAGEHASBITS_NESTEDMESSAGE,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestNestedMessageHasBits.NestedMessage)
    })
  ,
  'DESCRIPTOR' : _TESTNESTEDMESSAGEHASBITS,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestNestedMessageHasBits)
  })
_sym_db.RegisterMessage(TestNestedMessageHasBits)
_sym_db.RegisterMessage(TestNestedMessageHasBits.NestedMessage)

TestCamelCaseFieldNames = _reflection.GeneratedProtocolMessageType('TestCamelCaseFieldNames', (_message.Message,), {
  'DESCRIPTOR' : _TESTCAMELCASEFIELDNAMES,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestCamelCaseFieldNames)
  })
_sym_db.RegisterMessage(TestCamelCaseFieldNames)

TestFieldOrderings = _reflection.GeneratedProtocolMessageType('TestFieldOrderings', (_message.Message,), {

  'NestedMessage' : _reflection.GeneratedProtocolMessageType('NestedMessage', (_message.Message,), {
    'DESCRIPTOR' : _TESTFIELDORDERINGS_NESTEDMESSAGE,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestFieldOrderings.NestedMessage)
    })
  ,
  'DESCRIPTOR' : _TESTFIELDORDERINGS,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestFieldOrderings)
  })
_sym_db.RegisterMessage(TestFieldOrderings)
_sym_db.RegisterMessage(TestFieldOrderings.NestedMessage)

TestExtensionOrderings1 = _reflection.GeneratedProtocolMessageType('TestExtensionOrderings1', (_message.Message,), {
  'DESCRIPTOR' : _TESTEXTENSIONORDERINGS1,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestExtensionOrderings1)
  })
_sym_db.RegisterMessage(TestExtensionOrderings1)

TestExtensionOrderings2 = _reflection.GeneratedProtocolMessageType('TestExtensionOrderings2', (_message.Message,), {

  'TestExtensionOrderings3' : _reflection.GeneratedProtocolMessageType('TestExtensionOrderings3', (_message.Message,), {
    'DESCRIPTOR' : _TESTEXTENSIONORDERINGS2_TESTEXTENSIONORDERINGS3,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestExtensionOrderings2.TestExtensionOrderings3)
    })
  ,
  'DESCRIPTOR' : _TESTEXTENSIONORDERINGS2,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestExtensionOrderings2)
  })
_sym_db.RegisterMessage(TestExtensionOrderings2)
_sym_db.RegisterMessage(TestExtensionOrderings2.TestExtensionOrderings3)

TestExtremeDefaultValues = _reflection.GeneratedProtocolMessageType('TestExtremeDefaultValues', (_message.Message,), {
  'DESCRIPTOR' : _TESTEXTREMEDEFAULTVALUES,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestExtremeDefaultValues)
  })
_sym_db.RegisterMessage(TestExtremeDefaultValues)

SparseEnumMessage = _reflection.GeneratedProtocolMessageType('SparseEnumMessage', (_message.Message,), {
  'DESCRIPTOR' : _SPARSEENUMMESSAGE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.SparseEnumMessage)
  })
_sym_db.RegisterMessage(SparseEnumMessage)

OneString = _reflection.GeneratedProtocolMessageType('OneString', (_message.Message,), {
  'DESCRIPTOR' : _ONESTRING,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.OneString)
  })
_sym_db.RegisterMessage(OneString)

MoreString = _reflection.GeneratedProtocolMessageType('MoreString', (_message.Message,), {
  'DESCRIPTOR' : _MORESTRING,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.MoreString)
  })
_sym_db.RegisterMessage(MoreString)

OneBytes = _reflection.GeneratedProtocolMessageType('OneBytes', (_message.Message,), {
  'DESCRIPTOR' : _ONEBYTES,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.OneBytes)
  })
_sym_db.RegisterMessage(OneBytes)

MoreBytes = _reflection.GeneratedProtocolMessageType('MoreBytes', (_message.Message,), {
  'DESCRIPTOR' : _MOREBYTES,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.MoreBytes)
  })
_sym_db.RegisterMessage(MoreBytes)

Int32Message = _reflection.GeneratedProtocolMessageType('Int32Message', (_message.Message,), {
  'DESCRIPTOR' : _INT32MESSAGE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.Int32Message)
  })
_sym_db.RegisterMessage(Int32Message)

Uint32Message = _reflection.GeneratedProtocolMessageType('Uint32Message', (_message.Message,), {
  'DESCRIPTOR' : _UINT32MESSAGE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.Uint32Message)
  })
_sym_db.RegisterMessage(Uint32Message)

Int64Message = _reflection.GeneratedProtocolMessageType('Int64Message', (_message.Message,), {
  'DESCRIPTOR' : _INT64MESSAGE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.Int64Message)
  })
_sym_db.RegisterMessage(Int64Message)

Uint64Message = _reflection.GeneratedProtocolMessageType('Uint64Message', (_message.Message,), {
  'DESCRIPTOR' : _UINT64MESSAGE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.Uint64Message)
  })
_sym_db.RegisterMessage(Uint64Message)

BoolMessage = _reflection.GeneratedProtocolMessageType('BoolMessage', (_message.Message,), {
  'DESCRIPTOR' : _BOOLMESSAGE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.BoolMessage)
  })
_sym_db.RegisterMessage(BoolMessage)

TestOneof = _reflection.GeneratedProtocolMessageType('TestOneof', (_message.Message,), {

  'FooGroup' : _reflection.GeneratedProtocolMessageType('FooGroup', (_message.Message,), {
    'DESCRIPTOR' : _TESTONEOF_FOOGROUP,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestOneof.FooGroup)
    })
  ,
  'DESCRIPTOR' : _TESTONEOF,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestOneof)
  })
_sym_db.RegisterMessage(TestOneof)
_sym_db.RegisterMessage(TestOneof.FooGroup)

TestOneofBackwardsCompatible = _reflection.GeneratedProtocolMessageType('TestOneofBackwardsCompatible', (_message.Message,), {

  'FooGroup' : _reflection.GeneratedProtocolMessageType('FooGroup', (_message.Message,), {
    'DESCRIPTOR' : _TESTONEOFBACKWARDSCOMPATIBLE_FOOGROUP,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestOneofBackwardsCompatible.FooGroup)
    })
  ,
  'DESCRIPTOR' : _TESTONEOFBACKWARDSCOMPATIBLE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestOneofBackwardsCompatible)
  })
_sym_db.RegisterMessage(TestOneofBackwardsCompatible)
_sym_db.RegisterMessage(TestOneofBackwardsCompatible.FooGroup)

TestOneof2 = _reflection.GeneratedProtocolMessageType('TestOneof2', (_message.Message,), {

  'FooGroup' : _reflection.GeneratedProtocolMessageType('FooGroup', (_message.Message,), {
    'DESCRIPTOR' : _TESTONEOF2_FOOGROUP,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestOneof2.FooGroup)
    })
  ,

  'NestedMessage' : _reflection.GeneratedProtocolMessageType('NestedMessage', (_message.Message,), {
    'DESCRIPTOR' : _TESTONEOF2_NESTEDMESSAGE,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestOneof2.NestedMessage)
    })
  ,
  'DESCRIPTOR' : _TESTONEOF2,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestOneof2)
  })
_sym_db.RegisterMessage(TestOneof2)
_sym_db.RegisterMessage(TestOneof2.FooGroup)
_sym_db.RegisterMessage(TestOneof2.NestedMessage)

TestRequiredOneof = _reflection.GeneratedProtocolMessageType('TestRequiredOneof', (_message.Message,), {

  'NestedMessage' : _reflection.GeneratedProtocolMessageType('NestedMessage', (_message.Message,), {
    'DESCRIPTOR' : _TESTREQUIREDONEOF_NESTEDMESSAGE,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestRequiredOneof.NestedMessage)
    })
  ,
  'DESCRIPTOR' : _TESTREQUIREDONEOF,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestRequiredOneof)
  })
_sym_db.RegisterMessage(TestRequiredOneof)
_sym_db.RegisterMessage(TestRequiredOneof.NestedMessage)

TestPackedTypes = _reflection.GeneratedProtocolMessageType('TestPackedTypes', (_message.Message,), {
  'DESCRIPTOR' : _TESTPACKEDTYPES,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestPackedTypes)
  })
_sym_db.RegisterMessage(TestPackedTypes)

TestUnpackedTypes = _reflection.GeneratedProtocolMessageType('TestUnpackedTypes', (_message.Message,), {
  'DESCRIPTOR' : _TESTUNPACKEDTYPES,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestUnpackedTypes)
  })
_sym_db.RegisterMessage(TestUnpackedTypes)

TestPackedExtensions = _reflection.GeneratedProtocolMessageType('TestPackedExtensions', (_message.Message,), {
  'DESCRIPTOR' : _TESTPACKEDEXTENSIONS,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestPackedExtensions)
  })
_sym_db.RegisterMessage(TestPackedExtensions)

TestUnpackedExtensions = _reflection.GeneratedProtocolMessageType('TestUnpackedExtensions', (_message.Message,), {
  'DESCRIPTOR' : _TESTUNPACKEDEXTENSIONS,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestUnpackedExtensions)
  })
_sym_db.RegisterMessage(TestUnpackedExtensions)

TestDynamicExtensions = _reflection.GeneratedProtocolMessageType('TestDynamicExtensions', (_message.Message,), {

  'DynamicMessageType' : _reflection.GeneratedProtocolMessageType('DynamicMessageType', (_message.Message,), {
    'DESCRIPTOR' : _TESTDYNAMICEXTENSIONS_DYNAMICMESSAGETYPE,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestDynamicExtensions.DynamicMessageType)
    })
  ,
  'DESCRIPTOR' : _TESTDYNAMICEXTENSIONS,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestDynamicExtensions)
  })
_sym_db.RegisterMessage(TestDynamicExtensions)
_sym_db.RegisterMessage(TestDynamicExtensions.DynamicMessageType)

TestRepeatedScalarDifferentTagSizes = _reflection.GeneratedProtocolMessageType('TestRepeatedScalarDifferentTagSizes', (_message.Message,), {
  'DESCRIPTOR' : _TESTREPEATEDSCALARDIFFERENTTAGSIZES,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestRepeatedScalarDifferentTagSizes)
  })
_sym_db.RegisterMessage(TestRepeatedScalarDifferentTagSizes)

TestParsingMerge = _reflection.GeneratedProtocolMessageType('TestParsingMerge', (_message.Message,), {

  'RepeatedFieldsGenerator' : _reflection.GeneratedProtocolMessageType('RepeatedFieldsGenerator', (_message.Message,), {

    'Group1' : _reflection.GeneratedProtocolMessageType('Group1', (_message.Message,), {
      'DESCRIPTOR' : _TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR_GROUP1,
      '__module__' : 'google.protobuf.unittest_pb2'
      # @@protoc_insertion_point(class_scope:protobuf_unittest.TestParsingMerge.RepeatedFieldsGenerator.Group1)
      })
    ,

    'Group2' : _reflection.GeneratedProtocolMessageType('Group2', (_message.Message,), {
      'DESCRIPTOR' : _TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR_GROUP2,
      '__module__' : 'google.protobuf.unittest_pb2'
      # @@protoc_insertion_point(class_scope:protobuf_unittest.TestParsingMerge.RepeatedFieldsGenerator.Group2)
      })
    ,
    'DESCRIPTOR' : _TESTPARSINGMERGE_REPEATEDFIELDSGENERATOR,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestParsingMerge.RepeatedFieldsGenerator)
    })
  ,

  'OptionalGroup' : _reflection.GeneratedProtocolMessageType('OptionalGroup', (_message.Message,), {
    'DESCRIPTOR' : _TESTPARSINGMERGE_OPTIONALGROUP,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestParsingMerge.OptionalGroup)
    })
  ,

  'RepeatedGroup' : _reflection.GeneratedProtocolMessageType('RepeatedGroup', (_message.Message,), {
    'DESCRIPTOR' : _TESTPARSINGMERGE_REPEATEDGROUP,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestParsingMerge.RepeatedGroup)
    })
  ,
  'DESCRIPTOR' : _TESTPARSINGMERGE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestParsingMerge)
  })
_sym_db.RegisterMessage(TestParsingMerge)
_sym_db.RegisterMessage(TestParsingMerge.RepeatedFieldsGenerator)
_sym_db.RegisterMessage(TestParsingMerge.RepeatedFieldsGenerator.Group1)
_sym_db.RegisterMessage(TestParsingMerge.RepeatedFieldsGenerator.Group2)
_sym_db.RegisterMessage(TestParsingMerge.OptionalGroup)
_sym_db.RegisterMessage(TestParsingMerge.RepeatedGroup)

TestCommentInjectionMessage = _reflection.GeneratedProtocolMessageType('TestCommentInjectionMessage', (_message.Message,), {
  'DESCRIPTOR' : _TESTCOMMENTINJECTIONMESSAGE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestCommentInjectionMessage)
  })
_sym_db.RegisterMessage(TestCommentInjectionMessage)

FooRequest = _reflection.GeneratedProtocolMessageType('FooRequest', (_message.Message,), {
  'DESCRIPTOR' : _FOOREQUEST,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.FooRequest)
  })
_sym_db.RegisterMessage(FooRequest)

FooResponse = _reflection.GeneratedProtocolMessageType('FooResponse', (_message.Message,), {
  'DESCRIPTOR' : _FOORESPONSE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.FooResponse)
  })
_sym_db.RegisterMessage(FooResponse)

FooClientMessage = _reflection.GeneratedProtocolMessageType('FooClientMessage', (_message.Message,), {
  'DESCRIPTOR' : _FOOCLIENTMESSAGE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.FooClientMessage)
  })
_sym_db.RegisterMessage(FooClientMessage)

FooServerMessage = _reflection.GeneratedProtocolMessageType('FooServerMessage', (_message.Message,), {
  'DESCRIPTOR' : _FOOSERVERMESSAGE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.FooServerMessage)
  })
_sym_db.RegisterMessage(FooServerMessage)

BarRequest = _reflection.GeneratedProtocolMessageType('BarRequest', (_message.Message,), {
  'DESCRIPTOR' : _BARREQUEST,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.BarRequest)
  })
_sym_db.RegisterMessage(BarRequest)

BarResponse = _reflection.GeneratedProtocolMessageType('BarResponse', (_message.Message,), {
  'DESCRIPTOR' : _BARRESPONSE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.BarResponse)
  })
_sym_db.RegisterMessage(BarResponse)

TestJsonName = _reflection.GeneratedProtocolMessageType('TestJsonName', (_message.Message,), {
  'DESCRIPTOR' : _TESTJSONNAME,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestJsonName)
  })
_sym_db.RegisterMessage(TestJsonName)

TestHugeFieldNumbers = _reflection.GeneratedProtocolMessageType('TestHugeFieldNumbers', (_message.Message,), {

  'OptionalGroup' : _reflection.GeneratedProtocolMessageType('OptionalGroup', (_message.Message,), {
    'DESCRIPTOR' : _TESTHUGEFIELDNUMBERS_OPTIONALGROUP,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestHugeFieldNumbers.OptionalGroup)
    })
  ,

  'StringStringMapEntry' : _reflection.GeneratedProtocolMessageType('StringStringMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _TESTHUGEFIELDNUMBERS_STRINGSTRINGMAPENTRY,
    '__module__' : 'google.protobuf.unittest_pb2'
    # @@protoc_insertion_point(class_scope:protobuf_unittest.TestHugeFieldNumbers.StringStringMapEntry)
    })
  ,
  'DESCRIPTOR' : _TESTHUGEFIELDNUMBERS,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestHugeFieldNumbers)
  })
_sym_db.RegisterMessage(TestHugeFieldNumbers)
_sym_db.RegisterMessage(TestHugeFieldNumbers.OptionalGroup)
_sym_db.RegisterMessage(TestHugeFieldNumbers.StringStringMapEntry)

TestExtensionInsideTable = _reflection.GeneratedProtocolMessageType('TestExtensionInsideTable', (_message.Message,), {
  'DESCRIPTOR' : _TESTEXTENSIONINSIDETABLE,
  '__module__' : 'google.protobuf.unittest_pb2'
  # @@protoc_insertion_point(class_scope:protobuf_unittest.TestExtensionInsideTable)
  })
_sym_db.RegisterMessage(TestExtensionInsideTable)

TestAllExtensions.RegisterExtension(optional_int32_extension)
TestAllExtensions.RegisterExtension(optional_int64_extension)
TestAllExtensions.RegisterExtension(optional_uint32_extension)
TestAllExtensions.RegisterExtension(optional_uint64_extension)
TestAllExtensions.RegisterExtension(optional_sint32_extension)
TestAllExtensions.RegisterExtension(optional_sint64_extension)
TestAllExtensions.RegisterExtension(optional_fixed32_extension)
TestAllExtensions.RegisterExtension(optional_fixed64_extension)
TestAllExtensions.RegisterExtension(optional_sfixed32_extension)
TestAllExtensions.RegisterExtension(optional_sfixed64_extension)
TestAllExtensions.RegisterExtension(optional_float_extension)
TestAllExtensions.RegisterExtension(optional_double_extension)
TestAllExtensions.RegisterExtension(optional_bool_extension)
TestAllExtensions.RegisterExtension(optional_string_extension)
TestAllExtensions.RegisterExtension(optional_bytes_extension)
optionalgroup_extension.message_type = _OPTIONALGROUP_EXTENSION
TestAllExtensions.RegisterExtension(optionalgroup_extension)
optional_nested_message_extension.message_type = _TESTALLTYPES_NESTEDMESSAGE
TestAllExtensions.RegisterExtension(optional_nested_message_extension)
optional_foreign_message_extension.message_type = _FOREIGNMESSAGE
TestAllExtensions.RegisterExtension(optional_foreign_message_extension)
optional_import_message_extension.message_type = google_dot_protobuf_dot_unittest__import__pb2._IMPORTMESSAGE
TestAllExtensions.RegisterExtension(optional_import_message_extension)
optional_nested_enum_extension.enum_type = _TESTALLTYPES_NESTEDENUM
TestAllExtensions.RegisterExtension(optional_nested_enum_extension)
optional_foreign_enum_extension.enum_type = _FOREIGNENUM
TestAllExtensions.RegisterExtension(optional_foreign_enum_extension)
optional_import_enum_extension.enum_type = google_dot_protobuf_dot_unittest__import__pb2._IMPORTENUM
TestAllExtensions.RegisterExtension(optional_import_enum_extension)
TestAllExtensions.RegisterExtension(optional_string_piece_extension)
TestAllExtensions.RegisterExtension(optional_cord_extension)
optional_public_import_message_extension.message_type = google_dot_protobuf_dot_unittest__import__public__pb2._PUBLICIMPORTMESSAGE
TestAllExtensions.RegisterExtension(optional_public_import_message_extension)
optional_lazy_message_extension.message_type = _TESTALLTYPES_NESTEDMESSAGE
TestAllExtensions.RegisterExtension(optional_lazy_message_extension)
TestAllExtensions.RegisterExtension(repeated_int32_extension)
TestAllExtensions.RegisterExtension(repeated_int64_extension)
TestAllExtensions.RegisterExtension(repeated_uint32_extension)
TestAllExtensions.RegisterExtension(repeated_uint64_extension)
TestAllExtensions.RegisterExtension(repeated_sint32_extension)
TestAllExtensions.RegisterExtension(repeated_sint64_extension)
TestAllExtensions.RegisterExtension(repeated_fixed32_extension)
TestAllExtensions.RegisterExtension(repeated_fixed64_extension)
TestAllExtensions.RegisterExtension(repeated_sfixed32_extension)
TestAllExtensions.RegisterExtension(repeated_sfixed64_extension)
TestAllExtensions.RegisterExtension(repeated_float_extension)
TestAllExtensions.RegisterExtension(repeated_double_extension)
TestAllExtensions.RegisterExtension(repeated_bool_extension)
TestAllExtensions.RegisterExtension(repeated_string_extension)
TestAllExtensions.RegisterExtension(repeated_bytes_extension)
repeatedgroup_extension.message_type = _REPEATEDGROUP_EXTENSION
TestAllExtensions.RegisterExtension(repeatedgroup_extension)
repeated_nested_message_extension.message_type = _TESTALLTYPES_NESTEDMESSAGE
TestAllExtensions.RegisterExtension(repeated_nested_message_extension)
repeated_foreign_message_extension.message_type = _FOREIGNMESSAGE
TestAllExtensions.RegisterExtension(repeated_foreign_message_extension)
repeated_import_message_extension.message_type = google_dot_protobuf_dot_unittest__import__pb2._IMPORTMESSAGE
TestAllExtensions.RegisterExtension(repeated_import_message_extension)
repeated_nested_enum_extension.enum_type = _TESTALLTYPES_NESTEDENUM
TestAllExtensions.RegisterExtension(repeated_nested_enum_extension)
repeated_foreign_enum_extension.enum_type = _FOREIGNENUM
TestAllExtensions.RegisterExtension(repeated_foreign_enum_extension)
repeated_import_enum_extension.enum_type = google_dot_protobuf_dot_unittest__import__pb2._IMPORTENUM
TestAllExtensions.RegisterExtension(repeated_import_enum_extension)
TestAllExtensions.RegisterExtension(repeated_string_piece_extension)
TestAllExtensions.RegisterExtension(repeated_cord_extension)
repeated_lazy_message_extension.message_type = _TESTALLTYPES_NESTEDMESSAGE
TestAllExtensions.RegisterExtension(repeated_lazy_message_extension)
TestAllExtensions.RegisterExtension(default_int32_extension)
TestAllExtensions.RegisterExtension(default_int64_extension)
TestAllExtensions.RegisterExtension(default_uint32_extension)
TestAllExtensions.RegisterExtension(default_uint64_extension)
TestAllExtensions.RegisterExtension(default_sint32_extension)
TestAllExtensions.RegisterExtension(default_sint64_extension)
TestAllExtensions.RegisterExtension(default_fixed32_extension)
TestAllExtensions.RegisterExtension(default_fixed64_extension)
TestAllExtensions.RegisterExtension(default_sfixed32_extension)
TestAllExtensions.RegisterExtension(default_sfixed64_extension)
TestAllExtensions.RegisterExtension(default_float_extension)
TestAllExtensions.RegisterExtension(default_double_extension)
TestAllExtensions.RegisterExtension(default_bool_extension)
TestAllExtensions.RegisterExtension(default_string_extension)
TestAllExtensions.RegisterExtension(default_bytes_extension)
default_nested_enum_extension.enum_type = _TESTALLTYPES_NESTEDENUM
TestAllExtensions.RegisterExtension(default_nested_enum_extension)
default_foreign_enum_extension.enum_type = _FOREIGNENUM
TestAllExtensions.RegisterExtension(default_foreign_enum_extension)
default_import_enum_extension.enum_type = google_dot_protobuf_dot_unittest__import__pb2._IMPORTENUM
TestAllExtensions.RegisterExtension(default_import_enum_extension)
TestAllExtensions.RegisterExtension(default_string_piece_extension)
TestAllExtensions.RegisterExtension(default_cord_extension)
TestAllExtensions.RegisterExtension(oneof_uint32_extension)
oneof_nested_message_extension.message_type = _TESTALLTYPES_NESTEDMESSAGE
TestAllExtensions.RegisterExtension(oneof_nested_message_extension)
TestAllExtensions.RegisterExtension(oneof_string_extension)
TestAllExtensions.RegisterExtension(oneof_bytes_extension)
TestFieldOrderings.RegisterExtension(my_extension_string)
TestFieldOrderings.RegisterExtension(my_extension_int)
TestPackedExtensions.RegisterExtension(packed_int32_extension)
TestPackedExtensions.RegisterExtension(packed_int64_extension)
TestPackedExtensions.RegisterExtension(packed_uint32_extension)
TestPackedExtensions.RegisterExtension(packed_uint64_extension)
TestPackedExtensions.RegisterExtension(packed_sint32_extension)
TestPackedExtensions.RegisterExtension(packed_sint64_extension)
TestPackedExtensions.RegisterExtension(packed_fixed32_extension)
TestPackedExtensions.RegisterExtension(packed_fixed64_extension)
TestPackedExtensions.RegisterExtension(packed_sfixed32_extension)
TestPackedExtensions.RegisterExtension(packed_sfixed64_extension)
TestPackedExtensions.RegisterExtension(packed_float_extension)
TestPackedExtensions.RegisterExtension(packed_double_extension)
TestPackedExtensions.RegisterExtension(packed_bool_extension)
packed_enum_extension.enum_type = _FOREIGNENUM
TestPackedExtensions.RegisterExtension(packed_enum_extension)
TestUnpackedExtensions.RegisterExtension(unpacked_int32_extension)
TestUnpackedExtensions.RegisterExtension(unpacked_int64_extension)
TestUnpackedExtensions.RegisterExtension(unpacked_uint32_extension)
TestUnpackedExtensions.RegisterExtension(unpacked_uint64_extension)
TestUnpackedExtensions.RegisterExtension(unpacked_sint32_extension)
TestUnpackedExtensions.RegisterExtension(unpacked_sint64_extension)
TestUnpackedExtensions.RegisterExtension(unpacked_fixed32_extension)
TestUnpackedExtensions.RegisterExtension(unpacked_fixed64_extension)
TestUnpackedExtensions.RegisterExtension(unpacked_sfixed32_extension)
TestUnpackedExtensions.RegisterExtension(unpacked_sfixed64_extension)
TestUnpackedExtensions.RegisterExtension(unpacked_float_extension)
TestUnpackedExtensions.RegisterExtension(unpacked_double_extension)
TestUnpackedExtensions.RegisterExtension(unpacked_bool_extension)
unpacked_enum_extension.enum_type = _FOREIGNENUM
TestUnpackedExtensions.RegisterExtension(unpacked_enum_extension)
test_all_types.message_type = _TESTALLTYPES
TestHugeFieldNumbers.RegisterExtension(test_all_types)
TestExtensionInsideTable.RegisterExtension(test_extension_inside_table_extension)
TestAllExtensions.RegisterExtension(_TESTNESTEDEXTENSION.extensions_by_name['test'])
TestAllExtensions.RegisterExtension(_TESTNESTEDEXTENSION.extensions_by_name['nested_string_extension'])
_TESTNESTEDEXTENSION.extensions_by_name['optionalgroup_extension'].message_type = _TESTNESTEDEXTENSION_OPTIONALGROUP_EXTENSION
TestGroupExtension.RegisterExtension(_TESTNESTEDEXTENSION.extensions_by_name['optionalgroup_extension'])
_TESTNESTEDEXTENSION.extensions_by_name['optional_foreign_enum_extension'].enum_type = _FOREIGNENUM
TestGroupExtension.RegisterExtension(_TESTNESTEDEXTENSION.extensions_by_name['optional_foreign_enum_extension'])
_TESTREQUIRED.extensions_by_name['single'].message_type = _TESTREQUIRED
TestAllExtensions.RegisterExtension(_TESTREQUIRED.extensions_by_name['single'])
_TESTREQUIRED.extensions_by_name['multi'].message_type = _TESTREQUIRED
TestAllExtensions.RegisterExtension(_TESTREQUIRED.extensions_by_name['multi'])
_TESTEXTENSIONORDERINGS1.extensions_by_name['test_ext_orderings1'].message_type = _TESTEXTENSIONORDERINGS1
TestFieldOrderings.RegisterExtension(_TESTEXTENSIONORDERINGS1.extensions_by_name['test_ext_orderings1'])
_TESTEXTENSIONORDERINGS2_TESTEXTENSIONORDERINGS3.extensions_by_name['test_ext_orderings3'].message_type = _TESTEXTENSIONORDERINGS2_TESTEXTENSIONORDERINGS3
TestFieldOrderings.RegisterExtension(_TESTEXTENSIONORDERINGS2_TESTEXTENSIONORDERINGS3.extensions_by_name['test_ext_orderings3'])
_TESTEXTENSIONORDERINGS2.extensions_by_name['test_ext_orderings2'].message_type = _TESTEXTENSIONORDERINGS2
TestFieldOrderings.RegisterExtension(_TESTEXTENSIONORDERINGS2.extensions_by_name['test_ext_orderings2'])
_TESTPARSINGMERGE.extensions_by_name['optional_ext'].message_type = _TESTALLTYPES
TestParsingMerge.RegisterExtension(_TESTPARSINGMERGE.extensions_by_name['optional_ext'])
_TESTPARSINGMERGE.extensions_by_name['repeated_ext'].message_type = _TESTALLTYPES
TestParsingMerge.RegisterExtension(_TESTPARSINGMERGE.extensions_by_name['repeated_ext'])

DESCRIPTOR._options = None
_TESTENUMWITHDUPVALUE._options = None
optional_string_piece_extension._options = None
optional_cord_extension._options = None
optional_lazy_message_extension._options = None
repeated_string_piece_extension._options = None
repeated_cord_extension._options = None
repeated_lazy_message_extension._options = None
default_string_piece_extension._options = None
default_cord_extension._options = None
packed_int32_extension._options = None
packed_int64_extension._options = None
packed_uint32_extension._options = None
packed_uint64_extension._options = None
packed_sint32_extension._options = None
packed_sint64_extension._options = None
packed_fixed32_extension._options = None
packed_fixed64_extension._options = None
packed_sfixed32_extension._options = None
packed_sfixed64_extension._options = None
packed_float_extension._options = None
packed_double_extension._options = None
packed_bool_extension._options = None
packed_enum_extension._options = None
unpacked_int32_extension._options = None
unpacked_int64_extension._options = None
unpacked_uint32_extension._options = None
unpacked_uint64_extension._options = None
unpacked_sint32_extension._options = None
unpacked_sint64_extension._options = None
unpacked_fixed32_extension._options = None
unpacked_fixed64_extension._options = None
unpacked_sfixed32_extension._options = None
unpacked_sfixed64_extension._options = None
unpacked_float_extension._options = None
unpacked_double_extension._options = None
unpacked_bool_extension._options = None
unpacked_enum_extension._options = None
_TESTALLTYPES.fields_by_name['optional_string_piece']._options = None
_TESTALLTYPES.fields_by_name['optional_cord']._options = None
_TESTALLTYPES.fields_by_name['optional_lazy_message']._options = None
_TESTALLTYPES.fields_by_name['repeated_string_piece']._options = None
_TESTALLTYPES.fields_by_name['repeated_cord']._options = None
_TESTALLTYPES.fields_by_name['repeated_lazy_message']._options = None
_TESTALLTYPES.fields_by_name['default_string_piece']._options = None
_TESTALLTYPES.fields_by_name['default_cord']._options = None
_TESTDEPRECATEDFIELDS.fields_by_name['deprecated_int32']._options = None
_TESTDEPRECATEDFIELDS.fields_by_name['deprecated_int32_in_oneof']._options = None
_TESTDEPRECATEDMESSAGE._options = None
_TESTEAGERMESSAGE.fields_by_name['sub_message']._options = None
_TESTLAZYMESSAGE.fields_by_name['sub_message']._options = None
_TESTCAMELCASEFIELDNAMES.fields_by_name['StringPieceField']._options = None
_TESTCAMELCASEFIELDNAMES.fields_by_name['CordField']._options = None
_TESTCAMELCASEFIELDNAMES.fields_by_name['RepeatedStringPieceField']._options = None
_TESTCAMELCASEFIELDNAMES.fields_by_name['RepeatedCordField']._options = None
_TESTEXTREMEDEFAULTVALUES.fields_by_name['string_piece_with_zero']._options = None
_TESTEXTREMEDEFAULTVALUES.fields_by_name['cord_with_zero']._options = None
_TESTONEOF2.fields_by_name['foo_cord']._options = None
_TESTONEOF2.fields_by_name['foo_string_piece']._options = None
_TESTONEOF2.fields_by_name['foo_lazy_message']._options = None
_TESTONEOF2.fields_by_name['bar_cord']._options = None
_TESTONEOF2.fields_by_name['bar_string_piece']._options = None
_TESTPACKEDTYPES.fields_by_name['packed_int32']._options = None
_TESTPACKEDTYPES.fields_by_name['packed_int64']._options = None
_TESTPACKEDTYPES.fields_by_name['packed_uint32']._options = None
_TESTPACKEDTYPES.fields_by_name['packed_uint64']._options = None
_TESTPACKEDTYPES.fields_by_name['packed_sint32']._options = None
_TESTPACKEDTYPES.fields_by_name['packed_sint64']._options = None
_TESTPACKEDTYPES.fields_by_name['packed_fixed32']._options = None
_TESTPACKEDTYPES.fields_by_name['packed_fixed64']._options = None
_TESTPACKEDTYPES.fields_by_name['packed_sfixed32']._options = None
_TESTPACKEDTYPES.fields_by_name['packed_sfixed64']._options = None
_TESTPACKEDTYPES.fields_by_name['packed_float']._options = None
_TESTPACKEDTYPES.fields_by_name['packed_double']._options = None
_TESTPACKEDTYPES.fields_by_name['packed_bool']._options = None
_TESTPACKEDTYPES.fields_by_name['packed_enum']._options = None
_TESTUNPACKEDTYPES.fields_by_name['unpacked_int32']._options = None
_TESTUNPACKEDTYPES.fields_by_name['unpacked_int64']._options = None
_TESTUNPACKEDTYPES.fields_by_name['unpacked_uint32']._options = None
_TESTUNPACKEDTYPES.fields_by_name['unpacked_uint64']._options = None
_TESTUNPACKEDTYPES.fields_by_name['unpacked_sint32']._options = None
_TESTUNPACKEDTYPES.fields_by_name['unpacked_sint64']._options = None
_TESTUNPACKEDTYPES.fields_by_name['unpacked_fixed32']._options = None
_TESTUNPACKEDTYPES.fields_by_name['unpacked_fixed64']._options = None
_TESTUNPACKEDTYPES.fields_by_name['unpacked_sfixed32']._options = None
_TESTUNPACKEDTYPES.fields_by_name['unpacked_sfixed64']._options = None
_TESTUNPACKEDTYPES.fields_by_name['unpacked_float']._options = None
_TESTUNPACKEDTYPES.fields_by_name['unpacked_double']._options = None
_TESTUNPACKEDTYPES.fields_by_name['unpacked_bool']._options = None
_TESTUNPACKEDTYPES.fields_by_name['unpacked_enum']._options = None
_TESTDYNAMICEXTENSIONS.fields_by_name['packed_extension']._options = None
_TESTHUGEFIELDNUMBERS_STRINGSTRINGMAPENTRY._options = None
_TESTHUGEFIELDNUMBERS.fields_by_name['repeated_int32']._options = None
_TESTHUGEFIELDNUMBERS.fields_by_name['packed_int32']._options = None

_TESTSERVICE = _descriptor.ServiceDescriptor(
  name='TestService',
  full_name='protobuf_unittest.TestService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=17615,
  serialized_end=17768,
  methods=[
  _descriptor.MethodDescriptor(
    name='Foo',
    full_name='protobuf_unittest.TestService.Foo',
    index=0,
    containing_service=None,
    input_type=_FOOREQUEST,
    output_type=_FOORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Bar',
    full_name='protobuf_unittest.TestService.Bar',
    index=1,
    containing_service=None,
    input_type=_BARREQUEST,
    output_type=_BARRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TESTSERVICE)

DESCRIPTOR.services_by_name['TestService'] = _TESTSERVICE

TestService = service_reflection.GeneratedServiceType('TestService', (_service.Service,), dict(
  DESCRIPTOR = _TESTSERVICE,
  __module__ = 'google.protobuf.unittest_pb2'
  ))

TestService_Stub = service_reflection.GeneratedServiceStubType('TestService_Stub', (TestService,), dict(
  DESCRIPTOR = _TESTSERVICE,
  __module__ = 'google.protobuf.unittest_pb2'
  ))


# @@protoc_insertion_point(module_scope)
